library(nlme);library(lmeresampler)
library(lme4);library(lmerTest)
library(boot);library(Rfit)
library(MuMIn);library(ggplot2)
library(grid);library(gridExtra)
library(gtable);library(plyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(Hmisc)
library(spdep);library(SoDA);library(ape)
library(spaMM)

absk<-fread("Hisano_et_al_Data_Submitted_to_EcolLett.csv")
absk[,":="(logSI1=log(SI1))] %>% 
  .[,":="(Long=LONG+rnorm(nrow(absk),0,0.001),
          Lat=LAT+rnorm(nrow(absk),0,0.001),
          logSI=logSI1+rnorm(nrow(absk),0,0.000000000000001))] %>% 
  .[,":="(logSI=scale(logSI,scale=F),logBio_sc=scale(log(total_Bio1)))] %>% 
  .[,":="(logSA_sc=scale(log(SA1)),
          invlogSA_sc=scale(1/log(SA1)),
          Y_sc=scale(Year),
          Sprare_nbsp_sc=scale(Sprare_nbsp1),lograre_nbsp_sc=scale(lograre_nbsp1),
          Spstd_nbsp_sc=scale(Spstd_nbsp1),logstd_nbsp_sc=scale(logstd_nbsp1),
          Spnbsp_sc=scale(SpS),lognbsp_sc=scale(log(SpS)),
          SpShann_sc=scale(SpShann1),logShann_sc=scale(log(SpShann1+1)),
          SpSimp_sc=scale(SpSimp1),logSimp_sc=scale(log(SpSimp1+1)),
          SpST_sc=scale(SpST1),logST_sc=scale(log(SpST1)),sqrtST_sc=scale(sqrt(SpST1)),quadST_sc=scale(SpST1^2),
          logSI_sc=scale(logSI))] %>% 
  .[,":="(ATA1_10=ATA1*10,
          CO21_sc=scale(CO2),ATA1_sc=scale(ATA),CMI1_sc=scale(ACMIA))]

absk_WS<-fread("absk_WS.csv")#30%
absk_TA<-fread("absk_TA.csv")#30%
absk_LP<-fread("absk_LP.csv")#22%

absk_WS[,":="(Long=LONG+rnorm(nrow(absk_WS),0,0.001),
              Lat=LAT+rnorm(nrow(absk_WS),0,0.001),
              logSI=logSI1+rnorm(nrow(absk_WS),0,0.000000000000001))] %>% 
  .[,":="(logSI=scale(logSI,scale=F),logBio_sc=scale(log(total_Bio1)))] %>% 
  .[,":="(logSA_sc=scale(log(SA1)),
          invlogSA_sc=scale(1/log(SA1)),
          Y_sc=scale(Year),
          Sprare_nbsp_sc=scale(Sprare_nbsp1),lograre_nbsp_sc=scale(lograre_nbsp1),
          Spstd_nbsp_sc=scale(Spstd_nbsp1),logstd_nbsp_sc=scale(logstd_nbsp1),
          SpST_sc=scale(SpST1),logST_sc=scale(log(SpST1)),sqrtST_sc=scale(sqrt(SpST1)),quadST_sc=scale(SpST1^2),
          logSI_sc=scale(logSI))] %>% 
  .[,":="(ForestType=absk[match(absk_WS$PLOT_MS,absk$PLOT_MS),ForestType])]

absk_TA[,":="(Long=LONG+rnorm(nrow(absk_TA),0,0.001),
              Lat=LAT+rnorm(nrow(absk_TA),0,0.001),
              logSI=logSI1+rnorm(nrow(absk_TA),0,0.000000000000001))] %>% 
  .[,":="(logSI=scale(logSI,scale=F),logBio_sc=scale(log(total_Bio1)))] %>% 
  .[,":="(logSA_sc=scale(log(SA1)),
          invlogSA_sc=scale(1/log(SA1)),
          Y_sc=scale(Year),
          Sprare_nbsp_sc=scale(Sprare_nbsp1),lograre_nbsp_sc=scale(lograre_nbsp1),
          Spstd_nbsp_sc=scale(Spstd_nbsp1),logstd_nbsp_sc=scale(logstd_nbsp1),
          SpST_sc=scale(SpST1),logST_sc=scale(log(SpST1)),sqrtST_sc=scale(sqrt(SpST1)),quadST_sc=scale(SpST1^2),
          logSI_sc=scale(logSI))] %>% 
  .[,":="(ForestType=absk[match(absk_TA$PLOT_MS,absk$PLOT_MS),ForestType])]

absk_LP[,":="(Long=LONG+rnorm(nrow(absk_LP),0,0.001),
              Lat=LAT+rnorm(nrow(absk_LP),0,0.001),
              logSI=logSI1+rnorm(nrow(absk_LP),0,0.000000000000001))] %>% 
  .[,":="(logSI=scale(logSI,scale=F),logBio_sc=scale(log(total_Bio1)))] %>% 
  .[,":="(logSA_sc=scale(log(SA1)),
          invlogSA_sc=scale(1/log(SA1)),
          Y_sc=scale(Year),
          Sprare_nbsp_sc=scale(Sprare_nbsp1),lograre_nbsp_sc=scale(lograre_nbsp1),
          Spstd_nbsp_sc=scale(Spstd_nbsp1),logstd_nbsp_sc=scale(logstd_nbsp1),
          SpST_sc=scale(SpST1),logST_sc=scale(log(SpST1)),sqrtST_sc=scale(sqrt(SpST1)),quadST_sc=scale(SpST1^2),
          logSI_sc=scale(logSI))] %>% 
  .[,":="(ForestType=absk[match(absk_LP$PLOT_MS,absk$PLOT_MS),ForestType])]

# Prepare for Moran ##############################################################################################
#Bivand (2018) http://mirror1.ku.ac.th/cran/web/packages/spdep/vignettes/nb.pdf
#To calculate upper distance bounds, prepare unique coordinates
LATLONG<-absk[,.(Plotnumber,LAT,LONG,LatLong=LAT+LONG)]
LATLONG<-unique(LATLONG,by="LatLong")

absk[,":="(x_m=geoXY(Long,Lat, unit=1000)[,1],
           y_m=geoXY(Long,Lat, unit=1000)[,2])]#Transform coordinates to distance (km) 

plot.xy_unique<-geoXY(LATLONG$LONG, LATLONG$LAT, unit=1000)# unit is 1km
k1<-knn2nb(knearneigh(plot.xy_unique,k=1))

dsts <- unlist(nbdists(k1, plot.xy_unique))
summary(dsts)
hist(dsts,breaks=200)
quant95 <- as.numeric(quantile(dsts,0.95))#follwoing Portier 2018 LandScapeEcol
#https://link.springer.com/article/10.1007/s10980-017-0578-8
#Portier 2018: "the lag is defined as the distance between two neighbors when all observations are equally spaced out."
#"the distance at which 95% of the LDs had at least one neighbor"

#Use jittered one for analysis (because doesn't run with unique coordinates - distance cannot be zero)
#but using the distance (quan95) estimated by the unique corrdinate
plot.xy<-geoXY(absk$Lat, absk$Long, unit=1000) # unit is 1km
xy.dist<-dist(plot.xy)
plot(plot.xy) #visual aid to see the clustering of plots 
nbsr1<-dnearneigh(as.matrix(plot.xy),0,quant95) # calculate the neighbours distance (based on lags)
nb.w_quan95<-nb2listw(nbsr1, glist=NULL, style="W", zero.policy=FALSE)#Bivand 2018

##########################################################################################
## Growth
newdat_mb<-absk[,.(AGBGI,logSA,Y,lograre_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp<-fitme(AGBGI~logSA+Y+lograre_nbsp+logSI+
                     (logSA:Y)+(logSA:lograre_nbsp)+
                     (Y:lograre_nbsp)+(1|Plotnumber)+
                     Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb,
                   verbose=c(TRACE=TRUE))
#save(mbrare_nbsp,file="fitme_Year_Grow_HossfeldSI.R")
load("fitme_Year_Grow_HossfeldSI.R")

mbrare_nbsp_summary<-summary(mbrare_nbsp)$beta_table
mbrare_nbsp_summary


summary(mbrare_nbsp)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(mbrare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_summary<-as.data.frame(mbrare_nbsp_summary)
mbrare_nbsp_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_summary

#moran after accounting for spatial autocor
mb_r<-resid(mbrare_nbsp)
mb_moran<-moran.test(mb_r,listw=nb2listw(nbsr1,zero.policy=TRUE),zero.policy=TRUE)
mb_moran

# Scaled Growth
newdat_mb_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mbrare_nbsp_sc<-fitme(AGBGI~logSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                        (logSA_sc:Y_sc)+(logSA_sc:lograre_nbsp_sc)+
                        (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                        Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                      verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_sc,file="fitme_Year_Grow_sc_HossfeldSI.R")
load("fitme_Year_Grow_sc_HossfeldSI.R")

mbrare_nbsp_sc_summary<-summary(mbrare_nbsp_sc)$beta_table
mbrare_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_sc_summary<-as.data.frame(mbrare_nbsp_sc_summary)
mbrare_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_sc_summary

## Mortality
newdat_mc<-absk[,.(AGBM,logSA,Y,Sprare_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp<-fitme(AGBM~logSA+Y+Sprare_nbsp+logSI+
                     (logSA:Y)+(logSA:Sprare_nbsp)+
                     (Y:Sprare_nbsp)+(1|Plotnumber)+
                     Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc,
                   verbose=c(TRACE=TRUE))
#save(mcrare_nbsp,file="fitme_Year_Mort_HossfeldSI.R")
load("fitme_Year_Mort_HossfeldSI.R")

mcrare_nbsp_summary<-summary(mcrare_nbsp)$beta_table
mcrare_nbsp_summary

#Add Pvalue
summary(mcrare_nbsp)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(mcrare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_summary<-as.data.frame(mcrare_nbsp_summary)
mcrare_nbsp_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_summary

#moran after accounting for spatial autocor
mc_r<-resid(mcrare_nbsp)
mc_moran<-moran.test(mc_r,listw=nb2listw(nbsr1,zero.policy=TRUE),zero.policy=TRUE)
mc_moran

# Scaled Mortality
newdat_mc_sc<-absk[,.(AGBM,logSA_sc,Y_sc,Sprare_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mcrare_nbsp_sc<-fitme(AGBM~logSA_sc+Y_sc+Sprare_nbsp_sc+logSI_sc+
                        (logSA_sc:Y_sc)+(logSA_sc:Sprare_nbsp_sc)+
                        (Y_sc:Sprare_nbsp_sc)+(1|Plotnumber)+
                        Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                      verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_sc,file="fitme_Year_Mort_sc_HossfeldSI.R")
load("fitme_Year_Mort_sc_HossfeldSI.R")

mcrare_nbsp_sc_summary<-summary(mcrare_nbsp_sc)$beta_table
mcrare_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_sc_summary<-as.data.frame(mcrare_nbsp_sc_summary)
mcrare_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_sc_summary

## Net change
newdat_ma<-absk[,.(AGB,logSA,Y,lograre_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
marare_nbsp<-fitme(AGB~logSA+Y+lograre_nbsp+logSI+
                     (logSA:Y)+(logSA:lograre_nbsp)+
                     (Y:lograre_nbsp)+(1|Plotnumber)+
                     Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma,
                   verbose=c(TRACE=TRUE))
#save(marare_nbsp,file="fitme_Year_NBC_HossfeldSI.R")
load("fitme_Year_NBC_HossfeldSI.R")

marare_nbsp_summary<-summary(marare_nbsp)$beta_table
marare_nbsp_summary

#Add Pvalue
summary(marare_nbsp)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(marare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_summary<-as.data.frame(marare_nbsp_summary)
marare_nbsp_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_summary

#moran after accounting for spatial autocor
ma_r<-resid(marare_nbsp)
ma_moran<-moran.test(ma_r,listw=nb2listw(nbsr1,zero.policy=TRUE),zero.policy=TRUE)
ma_moran

# Scaled Net change
newdat_ma_sc<-absk[,.(AGB,logSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

marare_nbsp_sc<-fitme(AGB~logSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                        (logSA_sc:Y_sc)+(logSA_sc:lograre_nbsp_sc)+
                        (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                        Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                      verbose=c(TRACE=TRUE))
#save(marare_nbsp_sc,file="fitme_Year_NBC_sc_HossfeldSI.R")
load("fitme_Year_NBC_sc_HossfeldSI.R")

marare_nbsp_sc_summary<-summary(marare_nbsp_sc)$beta_table
marare_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_sc_summary<-as.data.frame(marare_nbsp_sc_summary)
marare_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_sc_summary

### Without weights ###
## Growth
newdat_mb_ww<-absk[,.(AGBGI,logSA,Y,lograre_nbsp,logSI,Plotnumber,LAT,LONG)]
mb_ww_rare_nbsp<-fitme(AGBGI~logSA+Y+lograre_nbsp+logSI+
                     (logSA:Y)+(logSA:lograre_nbsp)+
                     (Y:lograre_nbsp)+(1|Plotnumber)+
                     Matern(1|LAT+LONG),data=newdat_mb_ww,
                   verbose=c(TRACE=TRUE))
#save(mb_ww_rare_nbsp,file="fitme_Year_Grow_without_weights_HossfeldSI.R")
load("fitme_Year_Grow_without_weights_HossfeldSI.R")

mb_ww_rare_nbsp_summary<-summary(mb_ww_rare_nbsp)$beta_table
mb_ww_rare_nbsp_summary


summary(mb_ww_rare_nbsp)# of obs: 2544; # of groups: Plotnumb_ww_er, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(mb_ww_rare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mb_ww_rare_nbsp_summary<-as.data.frame(mb_ww_rare_nbsp_summary)
mb_ww_rare_nbsp_summary$Pval<-Pval[[1]]
colnames(mb_ww_rare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mb_ww_rare_nbsp_summary

## Mortality
newdat_mc_ww<-absk[,.(AGBM,logSA,Y,Sprare_nbsp,logSI,Plotnumber,LAT,LONG)]
mc_ww_rare_nbsp<-fitme(AGBM~logSA+Y+Sprare_nbsp+logSI+
                     (logSA:Y)+(logSA:Sprare_nbsp)+
                     (Y:Sprare_nbsp)+(1|Plotnumber)+
                     Matern(1|LAT+LONG),data=newdat_mc_ww,
                   verbose=c(TRACE=TRUE))
#save(mc_ww_rare_nbsp,file="fitme_Year_Mort_without_weights_HossfeldSI.R")
load("fitme_Year_Mort_without_weights_HossfeldSI.R")

mc_ww_rare_nbsp_summary<-summary(mc_ww_rare_nbsp)$beta_table
mc_ww_rare_nbsp_summary

#Add Pvalue
summary(mc_ww_rare_nbsp)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(mc_ww_rare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mc_ww_rare_nbsp_summary<-as.data.frame(mc_ww_rare_nbsp_summary)
mc_ww_rare_nbsp_summary$Pval<-Pval[[1]]
colnames(mc_ww_rare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mc_ww_rare_nbsp_summary

## Net change
newdat_ma_ww<-absk[,.(AGB,logSA,Y,lograre_nbsp,logSI,Plotnumber,LAT,LONG)]
ma_ww_rare_nbsp<-fitme(AGB~logSA+Y+lograre_nbsp+logSI+
                     (logSA:Y)+(logSA:lograre_nbsp)+
                     (Y:lograre_nbsp)+(1|Plotnumber)+
                     Matern(1|LAT+LONG),data=newdat_ma_ww,
                   verbose=c(TRACE=TRUE))
#save(ma_ww_rare_nbsp,file="fitme_Year_NBC_without_weights_HossfeldSI.R")
load("fitme_Year_NBC_without_weights_HossfeldSI.R")

ma_ww_rare_nbsp_summary<-summary(ma_ww_rare_nbsp)$beta_table
ma_ww_rare_nbsp_summary

#Add Pvalue
summary(ma_ww_rare_nbsp)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(ma_ww_rare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
ma_ww_rare_nbsp_summary<-as.data.frame(ma_ww_rare_nbsp_summary)
ma_ww_rare_nbsp_summary$Pval<-Pval[[1]]
colnames(ma_ww_rare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
ma_ww_rare_nbsp_summary

#moran after accounting for spatial autocor
ma_r<-resid(marare_nbsp)
ma_moran<-moran.test(ma_r,listw=nb2listw(nbsr1,zero.policy=TRUE),zero.policy=TRUE)
ma_moran

# Scaled Net change
newdat_ma_sc<-absk[,.(AGB,logSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

marare_nbsp_sc<-fitme(AGB~logSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                        (logSA_sc:Y_sc)+(logSA_sc:lograre_nbsp_sc)+
                        (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                        Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                      verbose=c(TRACE=TRUE))
#save(marare_nbsp_sc,file="fitme_Year_NBC_sc_HossfeldSI.R")
load("fitme_Year_NBC_sc_HossfeldSI.R")

marare_nbsp_sc_summary<-summary(marare_nbsp_sc)$beta_table
marare_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_sc_summary<-as.data.frame(marare_nbsp_sc_summary)
marare_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_sc_summary

### Relative change MODELS ###
# Scaled Growth
newdat_mb_sc<-absk[,.(RAGBGI,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mbrare_nbsp_R_sc<-fitme(RAGBGI~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                          (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                          (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                          Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                        verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_R_sc,file="fitme_Year_RGrow_sc_HossfeldSI.R")
load("fitme_Year_RGrow_sc_HossfeldSI.R")

mbrare_nbsp_R_sc_summary<-summary(mbrare_nbsp_R_sc)$beta_table
mbrare_nbsp_R_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_R_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_R_sc_summary<-as.data.frame(mbrare_nbsp_R_sc_summary)
mbrare_nbsp_R_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_R_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_R_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk[,.(RAGBM,invlogSA_sc,Y_sc,Sprare_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mcrare_nbsp_R_sc<-fitme(RAGBM~invlogSA_sc+Y_sc+Sprare_nbsp_sc+logSI_sc+
                          (invlogSA_sc:Y_sc)+(invlogSA_sc:Sprare_nbsp_sc)+
                          (Y_sc:Sprare_nbsp_sc)+(1|Plotnumber)+
                          Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                        verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_R_sc,file="fitme_Year_RMort_sc_HossfeldSI.R")
load("fitme_Year_RMort_sc_HossfeldSI.R")

mcrare_nbsp_R_sc_summary<-summary(mcrare_nbsp_R_sc)$beta_table
mcrare_nbsp_R_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_R_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_R_sc_summary<-as.data.frame(mcrare_nbsp_R_sc_summary)
mcrare_nbsp_R_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_R_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_R_sc_summary

# Scaled Net change
newdat_ma_sc<-absk[,.(RAGB,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

marare_nbsp_R_sc<-fitme(RAGB~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                          (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                          (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                          Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                        verbose=c(TRACE=TRUE))
#save(marare_nbsp_R_sc,file="fitme_Year_RNBC_sc_HossfeldSI.R")
load("fitme_Year_RNBC_sc_HossfeldSI.R")

marare_nbsp_R_sc_summary<-summary(marare_nbsp_R_sc)$beta_table
marare_nbsp_R_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_R_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_R_sc_summary<-as.data.frame(marare_nbsp_R_sc_summary)
marare_nbsp_R_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_R_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_R_sc_summary

### Individual Species Analysis ###
### WS Relative change ###
# Scaled Growth
newdat_mb_sc<-absk_WS[,.(RAGBGI,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mbrare_nbsp_R_WS_sc<-fitme(RAGBGI~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                           verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_R_WS_sc,file="fitme_Year_RGrow_WS_sc_HossfeldSI.R")
load("fitme_Year_RGrow_WS_sc_HossfeldSI.R")

mbrare_nbsp_R_WS_sc_summary<-summary(mbrare_nbsp_R_WS_sc)$beta_table
mbrare_nbsp_R_WS_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_R_WS_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_R_WS_sc_summary<-as.data.frame(mbrare_nbsp_R_WS_sc_summary)
mbrare_nbsp_R_WS_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_R_WS_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_R_WS_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk_WS[,.(RAGBM,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mcrare_nbsp_R_WS_sc<-fitme(RAGBM~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                           verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_R_WS_sc,file="fitme_Year_RMort_WS_sc_HossfeldSI.R")
load("fitme_Year_RMort_WS_sc_HossfeldSI.R")

mcrare_nbsp_R_WS_sc_summary<-summary(mcrare_nbsp_R_WS_sc)$beta_table
mcrare_nbsp_R_WS_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_R_WS_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_R_WS_sc_summary<-as.data.frame(mcrare_nbsp_R_WS_sc_summary)
mcrare_nbsp_R_WS_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_R_WS_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_R_WS_sc_summary

# Scaled Net change
newdat_ma_sc<-absk_WS[,.(RAGB,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

marare_nbsp_R_WS_sc<-fitme(RAGB~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                           verbose=c(TRACE=TRUE))
#save(marare_nbsp_R_WS_sc,file="fitme_Year_RNBC_WS_sc_HossfeldSI.R")
load("fitme_Year_RNBC_WS_sc_HossfeldSI.R")

marare_nbsp_R_WS_sc_summary<-summary(marare_nbsp_R_WS_sc)$beta_table
marare_nbsp_R_WS_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_R_WS_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_R_WS_sc_summary<-as.data.frame(marare_nbsp_R_WS_sc_summary)
marare_nbsp_R_WS_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_R_WS_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_R_WS_sc_summary

### TA Relative change ###
# Scaled Growth
newdat_mb_sc<-absk_TA[,.(RAGBGI,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mbrare_nbsp_R_TA_sc<-fitme(RAGBGI~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                           verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_R_TA_sc,file="fitme_Year_RGrow_TA_sc_HossfeldSI.R")
load("fitme_Year_RGrow_TA_sc_HossfeldSI.R")

mbrare_nbsp_R_TA_sc_summary<-summary(mbrare_nbsp_R_TA_sc)$beta_table
mbrare_nbsp_R_TA_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_R_TA_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_R_TA_sc_summary<-as.data.frame(mbrare_nbsp_R_TA_sc_summary)
mbrare_nbsp_R_TA_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_R_TA_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_R_TA_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk_TA[,.(RAGBM,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mcrare_nbsp_R_TA_sc<-fitme(RAGBM~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                           verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_R_TA_sc,file="fitme_Year_RMort_TA_sc_HossfeldSI.R")
load("fitme_Year_RMort_TA_sc_HossfeldSI.R")

mcrare_nbsp_R_TA_sc_summary<-summary(mcrare_nbsp_R_TA_sc)$beta_table
mcrare_nbsp_R_TA_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_R_TA_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_R_TA_sc_summary<-as.data.frame(mcrare_nbsp_R_TA_sc_summary)
mcrare_nbsp_R_TA_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_R_TA_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_R_TA_sc_summary

# Scaled Net change
newdat_ma_sc<-absk_TA[,.(RAGB,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

marare_nbsp_R_TA_sc<-fitme(RAGB~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                           verbose=c(TRACE=TRUE))
#save(marare_nbsp_R_TA_sc,file="fitme_Year_RNBC_TA_sc_HossfeldSI.R")
load("fitme_Year_RNBC_TA_sc_HossfeldSI.R")

marare_nbsp_R_TA_sc_summary<-summary(marare_nbsp_R_TA_sc)$beta_table
marare_nbsp_R_TA_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_R_TA_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_R_TA_sc_summary<-as.data.frame(marare_nbsp_R_TA_sc_summary)
marare_nbsp_R_TA_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_R_TA_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_R_TA_sc_summary

### LP Relative change ###
# Scaled Growth
newdat_mb_sc<-absk_LP[,.(RAGBGI,invlogSA_sc,Y_sc,Sprare_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mbrare_nbsp_R_LP_sc<-fitme(RAGBGI~invlogSA_sc+Y_sc+Sprare_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:Sprare_nbsp_sc)+
                             (Y_sc:Sprare_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                           verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_R_LP_sc,file="fitme_Year_RGrow_LP_sc_HossfeldSI.R")
load("fitme_Year_RGrow_LP_sc_HossfeldSI.R")

mbrare_nbsp_R_LP_sc_summary<-summary(mbrare_nbsp_R_LP_sc)$beta_table
mbrare_nbsp_R_LP_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_R_LP_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_R_LP_sc_summary<-as.data.frame(mbrare_nbsp_R_LP_sc_summary)
mbrare_nbsp_R_LP_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_R_LP_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_R_LP_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk_LP[,.(RAGBM,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mcrare_nbsp_R_LP_sc<-fitme(RAGBM~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                           verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_R_LP_sc,file="fitme_Year_RMort_LP_sc_HossfeldSI.R")
load("fitme_Year_RMort_LP_sc_HossfeldSI.R")

mcrare_nbsp_R_LP_sc_summary<-summary(mcrare_nbsp_R_LP_sc)$beta_table
mcrare_nbsp_R_LP_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_R_LP_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_R_LP_sc_summary<-as.data.frame(mcrare_nbsp_R_LP_sc_summary)
mcrare_nbsp_R_LP_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_R_LP_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_R_LP_sc_summary

# Scaled Net change
newdat_ma_sc<-absk_LP[,.(RAGB,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

marare_nbsp_R_LP_sc<-fitme(RAGB~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                           verbose=c(TRACE=TRUE))
#save(marare_nbsp_R_LP_sc,file="fitme_Year_RNBC_LP_sc_HossfeldSI.R")
load("fitme_Year_RNBC_LP_sc_HossfeldSI.R")

marare_nbsp_R_LP_sc_summary<-summary(marare_nbsp_R_LP_sc)$beta_table
marare_nbsp_R_LP_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_R_LP_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_R_LP_sc_summary<-as.data.frame(marare_nbsp_R_LP_sc_summary)
marare_nbsp_R_LP_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_R_LP_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_R_LP_sc_summary

### BP Relative change ###
# Scaled Growth
newdat_mb_sc<-absk_BP[,.(RAGBGI,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mbrare_nbsp_R_BP_sc<-fitme(RAGBGI~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                           verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_R_BP_sc,file="fitme_Year_RGrow_BP_sc_HossfeldSI.R")
load("fitme_Year_RGrow_BP_sc_HossfeldSI.R")

mbrare_nbsp_R_BP_sc_summary<-summary(mbrare_nbsp_R_BP_sc)$beta_table
mbrare_nbsp_R_BP_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_R_BP_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_R_BP_sc_summary<-as.data.frame(mbrare_nbsp_R_BP_sc_summary)
mbrare_nbsp_R_BP_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_R_BP_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_R_BP_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk_BP[,.(RAGBM,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mcrare_nbsp_R_BP_sc<-fitme(RAGBM~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                           verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_R_BP_sc,file="fitme_Year_RMort_BP_sc_HossfeldSI.R")
load("fitme_Year_RMort_BP_sc_HossfeldSI.R")

mcrare_nbsp_R_BP_sc_summary<-summary(mcrare_nbsp_R_BP_sc)$beta_table
mcrare_nbsp_R_BP_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_R_BP_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_R_BP_sc_summary<-as.data.frame(mcrare_nbsp_R_BP_sc_summary)
mcrare_nbsp_R_BP_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_R_BP_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_R_BP_sc_summary

# Scaled Net change
newdat_ma_sc<-absk_BP[,.(RAGB,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

marare_nbsp_R_BP_sc<-fitme(RAGB~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                           verbose=c(TRACE=TRUE))
#save(marare_nbsp_R_BP_sc,file="fitme_Year_RNBC_BP_sc_HossfeldSI.R")
load("fitme_Year_RNBC_BP_sc_HossfeldSI.R")

marare_nbsp_R_BP_sc_summary<-summary(marare_nbsp_R_BP_sc)$beta_table
marare_nbsp_R_BP_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_R_BP_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_R_BP_sc_summary<-as.data.frame(marare_nbsp_R_BP_sc_summary)
marare_nbsp_R_BP_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_R_BP_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_R_BP_sc_summary

### BS Relative change ###
# Scaled Growth
newdat_mb_sc<-absk_BS[,.(RAGBGI,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_R_BS_sc<-fitme(RAGBGI~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                           verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_R_BS_sc,file="fitme_Year_RGrow_BS_sc_HossfeldSI.R")
load("fitme_Year_RGrow_BS_sc_HossfeldSI.R")

mbrare_nbsp_R_BS_sc_summary<-summary(mbrare_nbsp_R_BS_sc)$beta_table
mbrare_nbsp_R_BS_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_R_BS_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_R_BS_sc_summary<-as.data.frame(mbrare_nbsp_R_BS_sc_summary)
mbrare_nbsp_R_BS_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_R_BS_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_R_BS_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk_BS[,.(RAGBM,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_R_BS_sc<-fitme(RAGBM~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                           verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_R_BS_sc,file="fitme_Year_RMort_BS_sc_HossfeldSI.R")
load("fitme_Year_RMort_BS_sc_HossfeldSI.R")

mcrare_nbsp_R_BS_sc_summary<-summary(mcrare_nbsp_R_BS_sc)$beta_table
mcrare_nbsp_R_BS_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_R_BS_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_R_BS_sc_summary<-as.data.frame(mcrare_nbsp_R_BS_sc_summary)
mcrare_nbsp_R_BS_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_R_BS_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_R_BS_sc_summary

# Scaled Net change
newdat_ma_sc<-absk_BS[,.(RAGB,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbsp_R_BS_sc<-fitme(RAGB~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                           verbose=c(TRACE=TRUE))
#save(marare_nbsp_R_BS_sc,file="fitme_Year_RNBC_BS_sc_HossfeldSI.R")
load("fitme_Year_RNBC_BS_sc_HossfeldSI.R")

marare_nbsp_R_BS_sc_summary<-summary(marare_nbsp_R_BS_sc)$beta_table
marare_nbsp_R_BS_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_R_BS_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_R_BS_sc_summary<-as.data.frame(marare_nbsp_R_BS_sc_summary)
marare_nbsp_R_BS_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_R_BS_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_R_BS_sc_summary

### BF Relative change ###
# Scaled Growth
newdat_mb_sc<-absk_BF[,.(RAGBGI,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_R_BF_sc<-fitme(RAGBGI~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                           verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_R_BF_sc,file="fitme_Year_RGrow_BF_sc_HossfeldSI.R")
load("fitme_Year_RGrow_BF_sc_HossfeldSI.R")

mbrare_nbsp_R_BF_sc_summary<-summary(mbrare_nbsp_R_BF_sc)$beta_table
mbrare_nbsp_R_BF_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_R_BF_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_R_BF_sc_summary<-as.data.frame(mbrare_nbsp_R_BF_sc_summary)
mbrare_nbsp_R_BF_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_R_BF_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_R_BF_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk_BF[,.(RAGBM,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_R_BF_sc<-fitme(RAGBM~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                           verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_R_BF_sc,file="fitme_Year_RMort_BF_sc_HossfeldSI.R")
load("fitme_Year_RMort_BF_sc_HossfeldSI.R")

mcrare_nbsp_R_BF_sc_summary<-summary(mcrare_nbsp_R_BF_sc)$beta_table
mcrare_nbsp_R_BF_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_R_BF_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_R_BF_sc_summary<-as.data.frame(mcrare_nbsp_R_BF_sc_summary)
mcrare_nbsp_R_BF_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_R_BF_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_R_BF_sc_summary

# Scaled Net change
newdat_ma_sc<-absk_BF[,.(RAGB,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbsp_R_BF_sc<-fitme(RAGB~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                           verbose=c(TRACE=TRUE))
#save(marare_nbsp_R_BF_sc,file="fitme_Year_RNBC_BF_sc_HossfeldSI.R")
load("fitme_Year_RNBC_BF_sc_HossfeldSI.R")

marare_nbsp_R_BF_sc_summary<-summary(marare_nbsp_R_BF_sc)$beta_table
marare_nbsp_R_BF_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_R_BF_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_R_BF_sc_summary<-as.data.frame(marare_nbsp_R_BF_sc_summary)
marare_nbsp_R_BF_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_R_BF_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_R_BF_sc_summary#

### JP Relative change ###
# Scaled Growth
newdat_mb_sc<-absk_JP[,.(RAGBGI,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_R_JP_sc<-fitme(RAGBGI~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                           verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_R_JP_sc,file="fitme_Year_RGrow_JP_sc_HossfeldSI.R")
load("fitme_Year_RGrow_JP_sc_HossfeldSI.R")

mbrare_nbsp_R_JP_sc_summary<-summary(mbrare_nbsp_R_JP_sc)$beta_table
mbrare_nbsp_R_JP_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_R_JP_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_R_JP_sc_summary<-as.data.frame(mbrare_nbsp_R_JP_sc_summary)
mbrare_nbsp_R_JP_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_R_JP_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_R_JP_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk_JP[,.(RAGBM,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_R_JP_sc<-fitme(RAGBM~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                           verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_R_JP_sc,file="fitme_Year_RMort_JP_sc_HossfeldSI.R")
load("fitme_Year_RMort_JP_sc_HossfeldSI.R")

mcrare_nbsp_R_JP_sc_summary<-summary(mcrare_nbsp_R_JP_sc)$beta_table
mcrare_nbsp_R_JP_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_R_JP_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_R_JP_sc_summary<-as.data.frame(mcrare_nbsp_R_JP_sc_summary)
mcrare_nbsp_R_JP_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_R_JP_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_R_JP_sc_summary

# Scaled Net change
newdat_ma_sc<-absk_JP[,.(RAGB,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbsp_R_JP_sc<-fitme(RAGB~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                           verbose=c(TRACE=TRUE))
#save(marare_nbsp_R_JP_sc,file="fitme_Year_RNBC_JP_sc_HossfeldSI.R")
load("fitme_Year_RNBC_JP_sc_HossfeldSI.R")

marare_nbsp_R_JP_sc_summary<-summary(marare_nbsp_R_JP_sc)$beta_table
marare_nbsp_R_JP_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_R_JP_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_R_JP_sc_summary<-as.data.frame(marare_nbsp_R_JP_sc_summary)
marare_nbsp_R_JP_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_R_JP_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_R_JP_sc_summary

### WB Relative change ###
# Scaled Growth
newdat_mb_sc<-absk_WB[,.(RAGBGI,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_R_WB_sc<-fitme(RAGBGI~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                           verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_R_WB_sc,file="fitme_Year_RGrow_WB_sc_HossfeldSI.R")
load("fitme_Year_RGrow_WB_sc_HossfeldSI.R")

mbrare_nbsp_R_WB_sc_summary<-summary(mbrare_nbsp_R_WB_sc)$beta_table
mbrare_nbsp_R_WB_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_R_WB_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_R_WB_sc_summary<-as.data.frame(mbrare_nbsp_R_WB_sc_summary)
mbrare_nbsp_R_WB_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_R_WB_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_R_WB_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk_WB[,.(RAGBM,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_R_WB_sc<-fitme(RAGBM~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                           verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_R_WB_sc,file="fitme_Year_RMort_WB_sc_HossfeldSI.R")
load("fitme_Year_RMort_WB_sc_HossfeldSI.R")

mcrare_nbsp_R_WB_sc_summary<-summary(mcrare_nbsp_R_WB_sc)$beta_table
mcrare_nbsp_R_WB_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_R_WB_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_R_WB_sc_summary<-as.data.frame(mcrare_nbsp_R_WB_sc_summary)
mcrare_nbsp_R_WB_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_R_WB_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_R_WB_sc_summary

# Scaled Net change
newdat_ma_sc<-absk_WB[,.(RAGB,invlogSA_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbsp_R_WB_sc<-fitme(RAGB~invlogSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+
                             (invlogSA_sc:Y_sc)+(invlogSA_sc:lograre_nbsp_sc)+
                             (Y_sc:lograre_nbsp_sc)+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                           verbose=c(TRACE=TRUE))
#save(marare_nbsp_R_WB_sc,file="fitme_Year_RNBC_WB_sc_HossfeldSI.R")
load("fitme_Year_RNBC_WB_sc_HossfeldSI.R")

marare_nbsp_R_WB_sc_summary<-summary(marare_nbsp_R_WB_sc)$beta_table
marare_nbsp_R_WB_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_R_WB_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_R_WB_sc_summary<-as.data.frame(marare_nbsp_R_WB_sc_summary)
marare_nbsp_R_WB_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_R_WB_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_R_WB_sc_summary

### Sarea MODELS ###
# Scaled Growth
newdat_mb_Sarea_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,logstd_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mbstd_nbsp_sc<-fitme(AGBGI~logSA_sc+Y_sc+logstd_nbsp_sc+logSI_sc+
                       (logSA_sc:Y_sc)+(logSA_sc:logstd_nbsp_sc)+
                       (Y_sc:logstd_nbsp_sc)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_Sarea_sc,
                     verbose=c(TRACE=TRUE))
#save(mbstd_nbsp_sc,file="fitme_Year_Grow_Sarea_sc_HossfeldSI.R")
load("fitme_Year_Grow_Sarea_sc_HossfeldSI.R")

mbstd_nbsp_sc_summary<-summary(mbstd_nbsp_sc)$beta_table
mbstd_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbstd_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbstd_nbsp_sc_summary<-as.data.frame(mbstd_nbsp_sc_summary)
mbstd_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mbstd_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbstd_nbsp_sc_summary

# Scaled Mortality
newdat_mc_Sarea_sc<-absk[,.(AGBM,logSA_sc,Y_sc,Spstd_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mcstd_nbsp_sc<-fitme(AGBM~logSA_sc+Y_sc+Spstd_nbsp_sc+logSI_sc+
                       (logSA_sc:Y_sc)+(logSA_sc:Spstd_nbsp_sc)+
                       (Y_sc:Spstd_nbsp_sc)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_Sarea_sc,
                     verbose=c(TRACE=TRUE))
#save(mcstd_nbsp_sc,file="fitme_Year_Mort_Sarea_sc_HossfeldSI.R")
load("fitme_Year_Mort_Sarea_sc_HossfeldSI.R")

mcstd_nbsp_sc_summary<-summary(mcstd_nbsp_sc)$beta_table
mcstd_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcstd_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcstd_nbsp_sc_summary<-as.data.frame(mcstd_nbsp_sc_summary)
mcstd_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mcstd_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcstd_nbsp_sc_summary

# Scaled Net change
newdat_ma_Sarea_sc<-absk[,.(AGB,logSA_sc,Y_sc,logstd_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mastd_nbsp_sc<-fitme(AGB~logSA_sc+Y_sc+logstd_nbsp_sc+logSI_sc+
                       (logSA_sc:Y_sc)+(logSA_sc:logstd_nbsp_sc)+
                       (Y_sc:logstd_nbsp_sc)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_Sarea_sc,
                     verbose=c(TRACE=TRUE))
#save(mastd_nbsp_sc,file="fitme_Year_NBC_Sarea_sc_HossfeldSI.R")
load("fitme_Year_NBC_Sarea_sc_HossfeldSI.R")

mastd_nbsp_sc_summary<-summary(mastd_nbsp_sc)$beta_table
mastd_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbstd_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbstd_nbsp_sc_summary<-as.data.frame(mbstd_nbsp_sc_summary)
mbstd_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mbstd_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbstd_nbsp_sc_summary

### Sorg MODELS ###
# Scaled Growth
newdat_mb_Sorg_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,lognbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mbnbsp_sc<-fitme(AGBGI~logSA_sc+Y_sc+lognbsp_sc+logSI_sc+
                   (logSA_sc:Y_sc)+(logSA_sc:lognbsp_sc)+
                   (Y_sc:lognbsp_sc)+(1|Plotnumber)+
                   Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_Sorg_sc,
                 verbose=c(TRACE=TRUE))
#save(mbnbsp_sc,file="fitme_Year_Grow_Sorg_sc_HossfeldSI.R")
load("fitme_Year_Grow_Sorg_sc_HossfeldSI.R")

mbnbsp_sc_summary<-summary(mbnbsp_sc)$beta_table
mbnbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbnbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbnbsp_sc_summary<-as.data.frame(mbnbsp_sc_summary)
mbnbsp_sc_summary$Pval<-Pval[[1]]
colnames(mbnbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbnbsp_sc_summary

# Scaled Mortality
newdat_mc_Sorg_sc<-absk[,.(AGBM,logSA_sc,Y_sc,Spnbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mcnbsp_sc<-fitme(AGBM~logSA_sc+Y_sc+Spnbsp_sc+logSI_sc+
                   (logSA_sc:Y_sc)+(logSA_sc:Spnbsp_sc)+
                   (Y_sc:Spnbsp_sc)+(1|Plotnumber)+
                   Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_Sorg_sc,
                 verbose=c(TRACE=TRUE))
#save(mcnbsp_sc,file="fitme_Year_Mort_Sorg_sc_HossfeldSI.R")
load("fitme_Year_Mort_Sorg_sc_HossfeldSI.R")

mcnbsp_sc_summary<-summary(mcnbsp_sc)$beta_table
mcnbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcnbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcnbsp_sc_summary<-as.data.frame(mcnbsp_sc_summary)
mcnbsp_sc_summary$Pval<-Pval[[1]]
colnames(mcnbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcnbsp_sc_summary

# Scaled Net change
newdat_ma_Sorg_sc<-absk[,.(AGB,logSA_sc,Y_sc,lognbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

manbsp_sc<-fitme(AGB~logSA_sc+Y_sc+lognbsp_sc+logSI_sc+
                   (logSA_sc:Y_sc)+(logSA_sc:lognbsp_sc)+
                   (Y_sc:lognbsp_sc)+(1|Plotnumber)+
                   Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_Sorg_sc,
                 verbose=c(TRACE=TRUE))
#save(manbsp_sc,file="fitme_Year_NBC_Sorg_sc_HossfeldSI.R")
load("fitme_Year_NBC_Sorg_sc_HossfeldSI.R")

manbsp_sc_summary<-summary(manbsp_sc)$beta_table
manbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbnbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbnbsp_sc_summary<-as.data.frame(mbnbsp_sc_summary)
mbnbsp_sc_summary$Pval<-Pval[[1]]
colnames(mbnbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbnbsp_sc_summary

### Shann MODELS ###
# Scaled Growth
newdat_mb_Shann_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,logShann_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mbShann_sc<-fitme(AGBGI~logSA_sc+Y_sc+logShann_sc+logSI_sc+
                    (logSA_sc:Y_sc)+(logSA_sc:logShann_sc)+
                    (Y_sc:logShann_sc)+(1|Plotnumber)+
                    Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_Shann_sc,
                  verbose=c(TRACE=TRUE))
#save(mbShann_sc,file="fitme_Year_Grow_Shann_sc_HossfeldSI.R")
load("fitme_Year_Grow_Shann_sc_HossfeldSI.R")

mbShann_sc_summary<-summary(mbShann_sc)$beta_table
mbShann_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbShann_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbShann_sc_summary<-as.data.frame(mbShann_sc_summary)
mbShann_sc_summary$Pval<-Pval[[1]]
colnames(mbShann_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbShann_sc_summary

# Scaled Mortality
newdat_mc_Shann_sc<-absk[,.(AGBM,logSA_sc,Y_sc,SpShann_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mcShann_sc<-fitme(AGBM~logSA_sc+Y_sc+SpShann_sc+logSI_sc+
                    (logSA_sc:Y_sc)+(logSA_sc:SpShann_sc)+
                    (Y_sc:SpShann_sc)+(1|Plotnumber)+
                    Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_Shann_sc,
                  verbose=c(TRACE=TRUE))
#save(mcShann_sc,file="fitme_Year_Mort_Shann_sc_HossfeldSI.R")
load("fitme_Year_Mort_Shann_sc_HossfeldSI.R")

mcShann_sc_summary<-summary(mcShann_sc)$beta_table
mcShann_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcShann_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcShann_sc_summary<-as.data.frame(mcShann_sc_summary)
mcShann_sc_summary$Pval<-Pval[[1]]
colnames(mcShann_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcShann_sc_summary

# Scaled Net change
newdat_ma_Shann_sc<-absk[,.(AGB,logSA_sc,Y_sc,logShann_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

maShann_sc<-fitme(AGB~logSA_sc+Y_sc+logShann_sc+logSI_sc+
                    (logSA_sc:Y_sc)+(logSA_sc:logShann_sc)+
                    (Y_sc:logShann_sc)+(1|Plotnumber)+
                    Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_Shann_sc,
                  verbose=c(TRACE=TRUE))
#save(maShann_sc,file="fitme_Year_NBC_Shann_sc_HossfeldSI.R")
load("fitme_Year_NBC_Shann_sc_HossfeldSI.R")

maShann_sc_summary<-summary(maShann_sc)$beta_table
maShann_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(maShann_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
maShann_sc_summary<-as.data.frame(maShann_sc_summary)
maShann_sc_summary$Pval<-Pval[[1]]
colnames(maShann_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
maShann_sc_summary

### Simp MODELS ###
# Scaled Growth
newdat_mb_Simp_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,logSimp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mbSimp_sc<-fitme(AGBGI~logSA_sc+Y_sc+logSimp_sc+logSI_sc+
                   (logSA_sc:Y_sc)+(logSA_sc:logSimp_sc)+
                   (Y_sc:logSimp_sc)+(1|Plotnumber)+
                   Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_Simp_sc,
                 verbose=c(TRACE=TRUE))
#save(mbSimp_sc,file="fitme_Year_Grow_Simp_sc_HossfeldSI.R")
load("fitme_Year_Grow_Simp_sc_HossfeldSI.R")

mbSimp_sc_summary<-summary(mbSimp_sc)$beta_table
mbSimp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbSimp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbSimp_sc_summary<-as.data.frame(mbSimp_sc_summary)
mbSimp_sc_summary$Pval<-Pval[[1]]
colnames(mbSimp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbSimp_sc_summary

# Scaled Mortality
newdat_mc_Simp_sc<-absk[,.(AGBM,logSA_sc,Y_sc,SpSimp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

mcSimp_sc<-fitme(AGBM~logSA_sc+Y_sc+SpSimp_sc+logSI_sc+
                   (logSA_sc:Y_sc)+(logSA_sc:SpSimp_sc)+
                   (Y_sc:SpSimp_sc)+(1|Plotnumber)+
                   Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_Simp_sc,
                 verbose=c(TRACE=TRUE))
#save(mcSimp_sc,file="fitme_Year_Mort_Simp_sc_HossfeldSI.R")
load("fitme_Year_Mort_Simp_sc_HossfeldSI.R")

mcSimp_sc_summary<-summary(mcSimp_sc)$beta_table
mcSimp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcSimp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcSimp_sc_summary<-as.data.frame(mcSimp_sc_summary)
mcSimp_sc_summary$Pval<-Pval[[1]]
colnames(mcSimp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcSimp_sc_summary

# Scaled Net change
newdat_ma_Simp_sc<-absk[,.(AGB,logSA_sc,Y_sc,logSimp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]

maSimp_sc<-fitme(AGB~logSA_sc+Y_sc+logSimp_sc+logSI_sc+
                   (logSA_sc:Y_sc)+(logSA_sc:logSimp_sc)+
                   (Y_sc:logSimp_sc)+(1|Plotnumber)+
                   Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_Simp_sc,
                 verbose=c(TRACE=TRUE))
#save(maSimp_sc,file="fitme_Year_NBC_Simp_sc_HossfeldSI.R")
load("fitme_Year_NBC_Simp_sc_HossfeldSI.R")

maSimp_sc_summary<-summary(maSimp_sc)$beta_table
maSimp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(maSimp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
maSimp_sc_summary<-as.data.frame(maSimp_sc_summary)
maSimp_sc_summary$Pval<-Pval[[1]]
colnames(maSimp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
maSimp_sc_summary


### BA MODELS ###
## Growth
newdat_mb_BA<-absk[,.(BAGI,logSA,Y,lograre_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
BA.mbrare_nbsp<-fitme(BAGI~logSA+Y+lograre_nbsp+logSI+
                        (logSA:Y)+(logSA:lograre_nbsp)+
                        (Y:lograre_nbsp)+(1|Plotnumber)+
                        Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_BA,
                      verbose=c(TRACE=TRUE))
#save(BA.mbrare_nbsp,file="fitme_Year_Grow_BA_HossfeldSI.R")
load("fitme_Year_Grow_BA_HossfeldSI.R")

BA.mbrare_nbsp_summary<-summary(BA.mbrare_nbsp)$beta_table
BA.mbrare_nbsp_summary

#Add Pvalue
Pval<-2*pt(-abs(BA.mbrare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
BA.mbrare_nbsp_summary<-as.data.frame(BA.mbrare_nbsp_summary)
BA.mbrare_nbsp_summary$Pval<-Pval[[1]]
colnames(BA.mbrare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
BA.mbrare_nbsp_summary

#moran after accounting for spatial autocor
mb_r_BA<-resid(BA.mbrare_nbsp)
mb_moran_BA<-moran.test(mb_r_BA,listw=nb2listw(nbsr1,zero.policy=TRUE),zero.policy=TRUE)
mb_moran_BA

## Mortality
newdat_mc_BA<-absk[,.(BAM,logSA,Y,Sprare_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
BA.mcrare_nbsp<-fitme(BAM~logSA+Y+Sprare_nbsp+logSI+
                        (logSA:Y)+(logSA:Sprare_nbsp)+
                        (Y:Sprare_nbsp)+(1|Plotnumber)+
                        Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_BA,
                      verbose=c(TRACE=TRUE))
#save(BA.mcrare_nbsp,file="fitme_Year_Mort_BA_HossfeldSI.R")
load("fitme_Year_Mort_BA_HossfeldSI.R")

BA.mcrare_nbsp_summary<-summary(BA.mcrare_nbsp)$beta_table
BA.mcrare_nbsp_summary

#Add Pvalue
summary(BA.mcrare_nbsp)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(BA.mcrare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
BA.mcrare_nbsp_summary<-as.data.frame(BA.mcrare_nbsp_summary)
BA.mcrare_nbsp_summary$Pval<-Pval[[1]]
colnames(BA.mcrare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
BA.mcrare_nbsp_summary

#moran after accounting for spatial autocor
mc_r_BA<-resid(BA.mcrare_nbsp)
mc_moran_BA<-moran.test(mc_r_BA,listw=nb2listw(nbsr1,zero.policy=TRUE),zero.policy=TRUE)
mc_moran_BA

## Net change
newdat_ma_BA<-absk[,.(BA,logSA,Y,Sprare_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
BA.marare_nbsp<-fitme(BA~logSA+Y+Sprare_nbsp+logSI+
                        (logSA:Y)+(logSA:Sprare_nbsp)+
                        (Y:Sprare_nbsp)+(1|Plotnumber)+
                        Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_BA,
                      verbose=c(TRACE=TRUE))
#save(BA.marare_nbsp,file="fitme_Year_NBC_BA_HossfeldSI.R")
load("fitme_Year_NBC_BA_HossfeldSI.R")

BA.marare_nbsp_summary<-summary(BA.marare_nbsp)$beta_table
BA.marare_nbsp_summary

#Add Pvalue
summary(BA.marare_nbsp)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(BA.marare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
BA.marare_nbsp_summary<-as.data.frame(BA.marare_nbsp_summary)
BA.marare_nbsp_summary$Pval<-Pval[[1]]
colnames(BA.marare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
BA.marare_nbsp_summary

#moran after accounting for spatial autocor
ma_r_BA<-resid(BA.marare_nbsp)
ma_moran_BA<-moran.test(ma_r_BA,listw=nb2listw(nbsr1,zero.policy=TRUE),zero.policy=TRUE)
ma_moran_BA

### N MODELS ###
## Growth
newdat_mb_N<-absk[,.(NI,logSA,Y,Sprare_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
N.mbrare_nbsp<-fitme(NI~logSA+Y+Sprare_nbsp+logSI+
                       (logSA:Y)+(logSA:Sprare_nbsp)+
                       (Y:Sprare_nbsp)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_N,
                     verbose=c(TRACE=TRUE))
#save(N.mbrare_nbsp,file="fitme_Year_Grow_N_HossfeldSI.R")
load("fitme_Year_Grow_N_HossfeldSI.R")

N.mbrare_nbsp_summary<-summary(N.mbrare_nbsp)$beta_table
N.mbrare_nbsp_summary

#Add Pvalue
Pval<-2*pt(-abs(N.mbrare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
N.mbrare_nbsp_summary<-as.data.frame(N.mbrare_nbsp_summary)
N.mbrare_nbsp_summary$Pval<-Pval[[1]]
colnames(N.mbrare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
N.mbrare_nbsp_summary

#moran after accounting for spatial autocor
mb_r_N<-resid(N.mbrare_nbsp)
mb_moran_N<-moran.test(mb_r_N,listw=nb2listw(nbsr1,zero.policy=TRUE),zero.policy=TRUE)
mb_moran_N

## Mortality
newdat_mc_N<-absk[,.(NM,logSA,Y,Sprare_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
N.mcrare_nbsp<-fitme(NM~logSA+Y+Sprare_nbsp+logSI+
                       (logSA:Y)+(logSA:Sprare_nbsp)+
                       (Y:Sprare_nbsp)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_N,
                     verbose=c(TRACE=TRUE))
#save(N.mcrare_nbsp,file="fitme_Year_Mort_N_HossfeldSI.R")
load("fitme_Year_Mort_N_HossfeldSI.R")

N.mcrare_nbsp_summary<-summary(N.mcrare_nbsp)$beta_table
N.mcrare_nbsp_summary

#Add Pvalue
summary(N.mcrare_nbsp)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(N.mcrare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
N.mcrare_nbsp_summary<-as.data.frame(N.mcrare_nbsp_summary)
N.mcrare_nbsp_summary$Pval<-Pval[[1]]
colnames(N.mcrare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
N.mcrare_nbsp_summary

#moran after accounting for spatial autocor
mc_r_N<-resid(N.mcrare_nbsp)
mc_moran_N<-moran.test(mc_r_N,listw=nb2listw(nbsr1,zero.policy=TRUE),zero.policy=TRUE)
mc_moran_N

## Net change
newdat_ma_N<-absk[,.(N,logSA,Y,Sprare_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
N.marare_nbsp<-fitme(N~logSA+Y+Sprare_nbsp+logSI+
                       (logSA:Y)+(logSA:Sprare_nbsp)+
                       (Y:Sprare_nbsp)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_N,
                     verbose=c(TRACE=TRUE))
#save(N.marare_nbsp,file="fitme_Year_NBC_N_HossfeldSI.R")
load("fitme_Year_NBC_N_HossfeldSI.R")

N.marare_nbsp_summary<-summary(N.marare_nbsp)$beta_table
N.marare_nbsp_summary

#Add Pvalue
summary(N.marare_nbsp)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(N.marare_nbsp_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
N.marare_nbsp_summary<-as.data.frame(N.marare_nbsp_summary)
N.marare_nbsp_summary$Pval<-Pval[[1]]
colnames(N.marare_nbsp_summary)<-c("Estimate","Cond.SE","t-value","p-value")
N.marare_nbsp_summary

#moran after accounting for spatial autocor
ma_r_N<-resid(N.marare_nbsp)
ma_moran_N<-moran.test(ma_r_N,listw=nb2listw(nbsr1,zero.policy=TRUE),zero.policy=TRUE)
ma_moran_N

### STSB MODELS ###
#Year model
## Growth
newdat_mb_ST<-absk[,.(AGBGI,SpST_sc,quadST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_ST_sc<-fitme(AGBGI~SpST_sc+quadST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                           SpST_sc:Y_sc+quadST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_ST,
                         verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_ST_sc,file="fitme_Year_Grow_ST_sc_Hossfeld.R")
load("fitme_Year_Grow_ST_sc_Hossfeld.R")

mbrare_nbsp_ST_sc_summary<-summary(mbrare_nbsp_ST_sc)$beta_table
mbrare_nbsp_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_ST_sc_summary[,"t-value"]), df=2544-(871+681+11+1)) %>% as.data.frame()
mbrare_nbsp_ST_sc_summary<-as.data.frame(mbrare_nbsp_ST_sc_summary)
mbrare_nbsp_ST_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_ST_sc_summary

## Mortality
newdat_mc_ST<-absk[,.(AGBM,SpST_sc,logBio_sc,Y_sc,Sprare_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_ST_sc<-fitme(AGBM~SpST_sc+logBio_sc+Y_sc+Sprare_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:Sprare_nbsp_sc+
                           SpST_sc:Y_sc+Y_sc:Sprare_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_ST,
                         verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_ST_sc,file="fitme_Year_Mort_ST_sc_Hossfeld.R")
load("fitme_Year_Mort_ST_sc_Hossfeld.R")

mcrare_nbsp_ST_sc_summary<-summary(mcrare_nbsp_ST_sc)$beta_table
mcrare_nbsp_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
mcrare_nbsp_ST_sc_summary<-as.data.frame(mcrare_nbsp_ST_sc_summary)
mcrare_nbsp_ST_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_ST_sc_summary

## Net change
newdat_ma_ST<-absk[,.(AGB,logST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbsp_ST_sc<-fitme(AGB~logST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc
                         +logST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_ST,
                         verbose=c(TRACE=TRUE))
#save(marare_nbsp_ST_sc,file="fitme_Year_NBC_ST_sc_Hossfeld.R")
load("fitme_Year_NBC_ST_sc_Hossfeld.R")

marare_nbsp_ST_sc_summary<-summary(marare_nbsp_ST_sc)$beta_table
marare_nbsp_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
marare_nbsp_ST_sc_summary<-as.data.frame(marare_nbsp_ST_sc_summary)
marare_nbsp_ST_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_ST_sc_summary

## Relative Models
## Growth
newdat_mb_R_ST<-absk[,.(RAGBGI,SpST_sc,quadST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_R_ST_sc<-fitme(RAGBGI~SpST_sc+quadST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                             SpST_sc:Y_sc+quadST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_R_ST,
                           verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_R_ST_sc,file="fitme_Year_Grow_R_ST_sc_Hossfeld.R")
load("fitme_Year_Grow_R_ST_sc_Hossfeld.R")

mbrare_nbsp_R_ST_sc_summary<-summary(mbrare_nbsp_R_ST_sc)$beta_table
mbrare_nbsp_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+11+1)) %>% as.data.frame()
mbrare_nbsp_R_ST_sc_summary<-as.data.frame(mbrare_nbsp_R_ST_sc_summary)
mbrare_nbsp_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_R_ST_sc_summary

## Mortality
newdat_mc_R_ST<-absk[,.(RAGBM,SpST_sc,logBio_sc,Y_sc,Sprare_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_R_ST_sc<-fitme(RAGBM~SpST_sc+logBio_sc+Y_sc+Sprare_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:Sprare_nbsp_sc+
                             SpST_sc:Y_sc+Y_sc:Sprare_nbsp_sc+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_R_ST,
                           verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_R_ST_sc,file="fitme_Year_Mort_R_ST_sc_Hossfeld.R")
load("fitme_Year_Mort_R_ST_sc_Hossfeld.R")

mcrare_nbsp_R_ST_sc_summary<-summary(mcrare_nbsp_R_ST_sc)$beta_table
mcrare_nbsp_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
mcrare_nbsp_R_ST_sc_summary<-as.data.frame(mcrare_nbsp_R_ST_sc_summary)
mcrare_nbsp_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_R_ST_sc_summary

## Net change
newdat_ma_R_ST<-absk[,.(RAGB,logST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbsp_R_ST_sc<-fitme(RAGB~logST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                             logST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                             Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_R_ST,
                           verbose=c(TRACE=TRUE))
#save(marare_nbsp_R_ST_sc,file="fitme_Year_NBC_R_ST_sc_Hossfeld.R")
load("fitme_Year_NBC_R_ST_sc_Hossfeld.R")

marare_nbsp_R_ST_sc_summary<-summary(marare_nbsp_R_ST_sc)$beta_table
marare_nbsp_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
marare_nbsp_R_ST_sc_summary<-as.data.frame(marare_nbsp_R_ST_sc_summary)
marare_nbsp_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_R_ST_sc_summary

## WS Models
## Growth
newdat_mb_WS_R_ST<-absk_WS[,.(RAGBGI,SpST_sc,quadST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_WS_R_ST_sc<-fitme(RAGBGI~SpST_sc+quadST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                                SpST_sc:Y_sc+quadST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_WS_R_ST,
                              verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_WS_R_ST_sc,file="fitme_Year_Grow_WS_R_ST_sc_Hossfeld.R")
load("fitme_Year_Grow_WS_R_ST_sc_Hossfeld.R")

mbrare_nbsp_WS_R_ST_sc_summary<-summary(mbrare_nbsp_WS_R_ST_sc)$beta_table
mbrare_nbsp_WS_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_WS_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+11+1)) %>% as.data.frame()
mbrare_nbsp_WS_R_ST_sc_summary<-as.data.frame(mbrare_nbsp_WS_R_ST_sc_summary)
mbrare_nbsp_WS_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_WS_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_WS_R_ST_sc_summary

## Mortality
newdat_mc_WS_R_ST<-absk_WS[,.(RAGBM,SpST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_WS_R_ST_sc<-fitme(RAGBM~SpST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                                SpST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_WS_R_ST,
                              verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_WS_R_ST_sc,file="fitme_Year_Mort_WS_R_ST_sc_Hossfeld.R")
load("fitme_Year_Mort_WS_R_ST_sc_Hossfeld.R")

mcrare_nbsp_WS_R_ST_sc_summary<-summary(mcrare_nbsp_WS_R_ST_sc)$beta_table
mcrare_nbsp_WS_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_WS_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
mcrare_nbsp_WS_R_ST_sc_summary<-as.data.frame(mcrare_nbsp_WS_R_ST_sc_summary)
mcrare_nbsp_WS_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_WS_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_WS_R_ST_sc_summary

## Net change
newdat_ma_WS_R_ST<-absk_WS[,.(RAGB,SpST_sc,quadST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbsp_WS_R_ST_sc<-fitme(RAGB~SpST_sc+quadST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                                SpST_sc:Y_sc+quadST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_WS_R_ST,
                              verbose=c(TRACE=TRUE))
#save(marare_nbsp_WS_R_ST_sc,file="fitme_Year_NBC_WS_R_ST_sc_Hossfeld.R")
load("fitme_Year_NBC_WS_R_ST_sc_Hossfeld.R")

marare_nbsp_WS_R_ST_sc_summary<-summary(marare_nbsp_WS_R_ST_sc)$beta_table
marare_nbsp_WS_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_WS_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
marare_nbsp_WS_R_ST_sc_summary<-as.data.frame(marare_nbsp_WS_R_ST_sc_summary)
marare_nbsp_WS_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_WS_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_WS_R_ST_sc_summary

## TA Models
## Growth
newdat_mb_TA_R_ST<-absk_TA[,.(RAGBGI,SpST_sc,quadST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_TA_R_ST_sc<-fitme(RAGBGI~SpST_sc+quadST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                                SpST_sc:Y_sc+quadST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_TA_R_ST,
                              verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_TA_R_ST_sc,file="fitme_Year_Grow_TA_R_ST_sc_Hossfeld.R")
load("fitme_Year_Grow_TA_R_ST_sc_Hossfeld.R")

mbrare_nbsp_TA_R_ST_sc_summary<-summary(mbrare_nbsp_TA_R_ST_sc)$beta_table
mbrare_nbsp_TA_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_TA_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+11+1)) %>% as.data.frame()
mbrare_nbsp_TA_R_ST_sc_summary<-as.data.frame(mbrare_nbsp_TA_R_ST_sc_summary)
mbrare_nbsp_TA_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_TA_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_TA_R_ST_sc_summary

## Mortality
newdat_mc_TA_R_ST<-absk_TA[,.(RAGBM,SpST_sc,quadST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_TA_R_ST_sc<-fitme(RAGBM~SpST_sc+quadST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                                SpST_sc:Y_sc+quadST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_TA_R_ST,
                              verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_TA_R_ST_sc,file="fitme_Year_Mort_TA_R_ST_sc_Hossfeld.R")
load("fitme_Year_Mort_TA_R_ST_sc_Hossfeld.R")

mcrare_nbsp_TA_R_ST_sc_summary<-summary(mcrare_nbsp_TA_R_ST_sc)$beta_table
mcrare_nbsp_TA_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_TA_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
mcrare_nbsp_TA_R_ST_sc_summary<-as.data.frame(mcrare_nbsp_TA_R_ST_sc_summary)
mcrare_nbsp_TA_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_TA_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_TA_R_ST_sc_summary

## Net change
newdat_ma_TA_R_ST<-absk_TA[,.(RAGB,SpST_sc,quadST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbsp_TA_R_ST_sc<-fitme(RAGB~SpST_sc+quadST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                                SpST_sc:Y_sc+quadST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_TA_R_ST,
                              verbose=c(TRACE=TRUE))
#save(marare_nbsp_TA_R_ST_sc,file="fitme_Year_NBC_TA_R_ST_sc_Hossfeld.R")
load("fitme_Year_NBC_TA_R_ST_sc_Hossfeld.R")

marare_nbsp_TA_R_ST_sc_summary<-summary(marare_nbsp_TA_R_ST_sc)$beta_table
marare_nbsp_TA_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_TA_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
marare_nbsp_TA_R_ST_sc_summary<-as.data.frame(marare_nbsp_TA_R_ST_sc_summary)
marare_nbsp_TA_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_TA_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_TA_R_ST_sc_summary

## LP Models
## Growth
newdat_mb_LP_R_ST<-absk_LP[,.(RAGBGI,SpST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_LP_R_ST_sc<-fitme(RAGBGI~SpST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+
                                logBio_sc:lograre_nbsp_sc+SpST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_LP_R_ST,
                              verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_LP_R_ST_sc,file="fitme_Year_Grow_LP_R_ST_sc_Hossfeld.R")
load("fitme_Year_Grow_LP_R_ST_sc_Hossfeld.R")

mbrare_nbsp_LP_R_ST_sc_summary<-summary(mbrare_nbsp_LP_R_ST_sc)$beta_table
mbrare_nbsp_LP_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_LP_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+11+1)) %>% as.data.frame()
mbrare_nbsp_LP_R_ST_sc_summary<-as.data.frame(mbrare_nbsp_LP_R_ST_sc_summary)
mbrare_nbsp_LP_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_LP_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_LP_R_ST_sc_summary

## Mortality
newdat_mc_LP_R_ST<-absk_LP[,.(RAGBM,SpST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_LP_R_ST_sc<-fitme(RAGBM~SpST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                                SpST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_LP_R_ST,
                              verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_LP_R_ST_sc,file="fitme_Year_Mort_LP_R_ST_sc_Hossfeld.R")
load("fitme_Year_Mort_LP_R_ST_sc_Hossfeld.R")

mcrare_nbsp_LP_R_ST_sc_summary<-summary(mcrare_nbsp_LP_R_ST_sc)$beta_table
mcrare_nbsp_LP_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_LP_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
mcrare_nbsp_LP_R_ST_sc_summary<-as.data.frame(mcrare_nbsp_LP_R_ST_sc_summary)
mcrare_nbsp_LP_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_LP_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_LP_R_ST_sc_summary

## Net change
newdat_ma_LP_R_ST<-absk_LP[,.(RAGB,SpST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbsp_LP_R_ST_sc<-fitme(RAGB~SpST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                                SpST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_LP_R_ST,
                              verbose=c(TRACE=TRUE))
#save(marare_nbsp_LP_R_ST_sc,file="fitme_Year_NBC_LP_R_ST_sc_Hossfeld.R")
load("fitme_Year_NBC_LP_R_ST_sc_Hossfeld.R")

marare_nbsp_LP_R_ST_sc_summary<-summary(marare_nbsp_LP_R_ST_sc)$beta_table
marare_nbsp_LP_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_LP_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
marare_nbsp_LP_R_ST_sc_summary<-as.data.frame(marare_nbsp_LP_R_ST_sc_summary)
marare_nbsp_LP_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_LP_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_LP_R_ST_sc_summary

## BP Models
## Growth
newdat_mb_BP_R_ST<-absk_BP[,.(RAGBGI,SpST_sc,quadST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_BP_R_ST_sc<-fitme(RAGBGI~SpST_sc+quadST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                                SpST_sc:Y_sc+quadST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_BP_R_ST,
                              verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_BP_R_ST_sc,file="fitme_Year_Grow_BP_R_ST_sc_Hossfeld.R")
load("fitme_Year_Grow_BP_R_ST_sc_Hossfeld.R")

mbrare_nbsp_BP_R_ST_sc_summary<-summary(mbrare_nbsp_BP_R_ST_sc)$beta_table
mbrare_nbsp_BP_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_BP_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+11+1)) %>% as.data.frame()
mbrare_nbsp_BP_R_ST_sc_summary<-as.data.frame(mbrare_nbsp_BP_R_ST_sc_summary)
mbrare_nbsp_BP_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_BP_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_BP_R_ST_sc_summary

## Mortality
newdat_mc_BP_R_ST<-absk_BP[,.(RAGBM,SpST_sc,quadST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_BP_R_ST_sc<-fitme(RAGBM~SpST_sc+quadST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                                SpST_sc:Y_sc+quadST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_BP_R_ST,
                              verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_BP_R_ST_sc,file="fitme_Year_Mort_BP_R_ST_sc_Hossfeld.R")
load("fitme_Year_Mort_BP_R_ST_sc_Hossfeld.R")

mcrare_nbsp_BP_R_ST_sc_summary<-summary(mcrare_nbsp_BP_R_ST_sc)$beta_table
mcrare_nbsp_BP_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_BP_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
mcrare_nbsp_BP_R_ST_sc_summary<-as.data.frame(mcrare_nbsp_BP_R_ST_sc_summary)
mcrare_nbsp_BP_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_BP_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_BP_R_ST_sc_summary

## Net change
newdat_ma_BP_R_ST<-absk_BP[,.(RAGB,SpST_sc,quadST_sc,logBio_sc,Y_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbsp_BP_R_ST_sc<-fitme(RAGB~SpST_sc+quadST_sc+logBio_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logBio_sc:Y_sc+logBio_sc:lograre_nbsp_sc+
                                SpST_sc:Y_sc+quadST_sc:Y_sc+Y_sc:lograre_nbsp_sc+(1|Plotnumber)+
                                Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_BP_R_ST,
                              verbose=c(TRACE=TRUE))
#save(marare_nbsp_BP_R_ST_sc,file="fitme_Year_NBC_BP_R_ST_sc_Hossfeld.R")
load("fitme_Year_NBC_BP_R_ST_sc_Hossfeld.R")

marare_nbsp_BP_R_ST_sc_summary<-summary(marare_nbsp_BP_R_ST_sc)$beta_table
marare_nbsp_BP_R_ST_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_BP_R_ST_sc_summary[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
marare_nbsp_BP_R_ST_sc_summary<-as.data.frame(marare_nbsp_BP_R_ST_sc_summary)
marare_nbsp_BP_R_ST_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_BP_R_ST_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_BP_R_ST_sc_summary

### MULTI CLIMATE MODELS ###
## Growth
newdat_mb_CAC<-absk[,.(AGBGI,logSA,CO21,ATA1_10,CMI1,lograre_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
mbrare_nbspCAC<-fitme(AGBGI~logSI+logSA*CO21+logSA*ATA1_10+logSA*CMI1+logSA*lograre_nbsp+
                        CO21*lograre_nbsp+ATA1_10*lograre_nbsp+CMI1*lograre_nbsp+(1|Plotnumber)+
                        Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_CAC,
                      verbose=c(TRACE=TRUE))
save(mbrare_nbspCAC,file="fitme_MULTI_Grow_HossfeldSI.R")
load("fitme_MULTI_Grow_HossfeldSI.R")

mbrare_nbspCAC_summary<-summary(mbrare_nbspCAC)$beta_table
mbrare_nbspCAC_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(mbrare_nbspCAC_summary[,"t-value"]), df=2544-(871+681+13+1)) %>% as.data.frame()
mbrare_nbspCAC_summary<-as.data.frame(mbrare_nbspCAC_summary)
mbrare_nbspCAC_summary$Pval<-Pval[[1]]
colnames(mbrare_nbspCAC_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbspCAC_summary

# Scaled Growth
newdat_mb_CAC_sc<-absk[,.(AGBGI,logSA_sc,lograre_nbsp_sc,logSI_sc,
                          CO21_sc,ATA1_sc,CMI1_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbspCAC_sc<-fitme(AGBGI~logSI_sc+logSA_sc*CO21_sc+logSA_sc*ATA1_sc+logSA_sc*CMI1_sc+logSA_sc*lograre_nbsp_sc+
                           CO21_sc*lograre_nbsp_sc+ATA1_sc*lograre_nbsp_sc+CMI1_sc*lograre_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_CAC_sc,
                         verbose=c(TRACE=TRUE))
save(mbrare_nbspCAC_sc,file="fitme_MULTI_Grow_sc_HossfeldSI.R")
load("fitme_MULTI_Grow_sc_HossfeldSI.R")

mbrare_nbspCAC_sc_summary<-summary(mbrare_nbspCAC_sc)$beta_table
mbrare_nbspCAC_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbspCAC_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbspCAC_sc_summary<-as.data.frame(mbrare_nbspCAC_sc_summary)
mbrare_nbspCAC_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbspCAC_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbspCAC_sc_summary

## Mortality
newdat_mc_CAC<-absk[,.(AGBM,logSA,CO21,ATA1_10,CMI1,Sprare_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
mcrare_nbspCAC<-fitme(AGBM~logSI+logSA*CO21+logSA*ATA1_10+logSA*CMI1+logSA*Sprare_nbsp+
                        CO21*Sprare_nbsp+ATA1_10*Sprare_nbsp+CMI1*Sprare_nbsp+(1|Plotnumber)+
                        Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_CAC,
                      verbose=c(TRACE=TRUE))
save(mcrare_nbspCAC,file="fitme_MULTI_Mort_HossfeldSI.R")
load("fitme_MULTI_Mort_HossfeldSI.R")

mcrare_nbspCAC_summary<-summary(mcrare_nbspCAC)$beta_table
mcrare_nbspCAC_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(mcrare_nbspCAC_summary[,"t-value"]), df=2544-(871+681+13+1)) %>% as.data.frame()
mcrare_nbspCAC_summary<-as.data.frame(mcrare_nbspCAC_summary)
mcrare_nbspCAC_summary$Pval<-Pval[[1]]
colnames(mcrare_nbspCAC_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbspCAC_summary

# Scaled Mortality
newdat_mc_CAC_sc<-absk[,.(AGBM,logSA_sc,Sprare_nbsp_sc,logSI_sc,
                          CO21_sc,ATA1_sc,CMI1_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbspCAC_sc<-fitme(AGBM~logSI_sc+logSA_sc*CO21_sc+logSA_sc*ATA1_sc+logSA_sc*CMI1_sc+logSA_sc*Sprare_nbsp_sc+
                           CO21_sc*Sprare_nbsp_sc+ATA1_sc*Sprare_nbsp_sc+CMI1_sc*Sprare_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_CAC_sc,
                         verbose=c(TRACE=TRUE))
save(mcrare_nbspCAC_sc,file="fitme_MULTI_Mort_sc_HossfeldSI.R")
load("fitme_MULTI_Mort_sc_HossfeldSI.R")

mcrare_nbspCAC_sc_summary<-summary(mcrare_nbspCAC_sc)$beta_table
mcrare_nbspCAC_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbspCAC_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbspCAC_sc_summary<-as.data.frame(mcrare_nbspCAC_sc_summary)
mcrare_nbspCAC_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbspCAC_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbspCAC_sc_summary

## Net change
newdat_ma_CAC<-absk[,.(AGB,logSA,CO21,ATA1_10,CMI1,lograre_nbsp,logSI,Plotnumber,wi,LAT,LONG)]
marare_nbspCAC<-fitme(AGB~logSI+logSA*CO21+logSA*ATA1_10+logSA*CMI1+logSA*lograre_nbsp+
                        CO21*lograre_nbsp+ATA1_10*lograre_nbsp+CMI1*lograre_nbsp+(1|Plotnumber)+
                        Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_CAC,
                      verbose=c(TRACE=TRUE))
save(marare_nbspCAC,file="fitme_MULTI_NBC_HossfeldSI.R")
load("fitme_MULTI_NBC_HossfeldSI.R")

marare_nbspCAC_summary<-summary(marare_nbspCAC)$beta_table
marare_nbspCAC_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(marare_nbspCAC_summary[,"t-value"]), df=2544-(871+681+13+1)) %>% as.data.frame()
marare_nbspCAC_summary<-as.data.frame(marare_nbspCAC_summary)
marare_nbspCAC_summary$Pval<-Pval[[1]]
colnames(marare_nbspCAC_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbspCAC_summary

# Scaled Net change
newdat_ma_CAC_sc<-absk[,.(AGB,logSA_sc,lograre_nbsp_sc,logSI_sc,
                          CO21_sc,ATA1_sc,CMI1_sc,Plotnumber,wi,LAT,LONG)]
marare_nbspCAC_sc<-fitme(AGB~logSI_sc+logSA_sc*CO21_sc+logSA_sc*ATA1_sc+logSA_sc*CMI1_sc+logSA_sc*lograre_nbsp_sc+
                           CO21_sc*lograre_nbsp_sc+ATA1_sc*lograre_nbsp_sc+CMI1_sc*lograre_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_CAC_sc,
                         verbose=c(TRACE=TRUE))
save(marare_nbspCAC_sc,file="fitme_MULTI_NBC_sc_HossfeldSI.R")
load("fitme_MULTI_NBC_sc_HossfeldSI.R")

marare_nbspCAC_sc_summary<-summary(marare_nbspCAC_sc)$beta_table
marare_nbspCAC_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbspCAC_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbspCAC_sc_summary<-as.data.frame(marare_nbspCAC_sc_summary)
marare_nbspCAC_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbspCAC_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbspCAC_sc_summary

### EACH CLIMATE MODELS ###
### CO2 MODELS ###
## Growth
## scaled Growth
newdat_mb_CO2_sc<-absk[,.(AGBGI,logSA_sc,CO21_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbspCO2_sc<-fitme(AGBGI~logSI_sc+logSA_sc*CO21_sc+logSA_sc*lograre_nbsp_sc+
                           CO21_sc*lograre_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_CO2_sc,
                         verbose=c(TRACE=TRUE))
save(mbrare_nbspCO2_sc,file="fitme_CO2_Grow_sc_HossfeldSI.R")
load("fitme_CO2_Grow_sc_HossfeldSI.R")

mbrare_nbspCO2_sc_summary<-summary(mbrare_nbspCO2_sc)$beta_table
mbrare_nbspCO2_sc_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(mbrare_nbspCO2_sc_summary[,"t-value"]), df=2544-(871+681+8+1)) %>% as.data.frame()
mbrare_nbspCO2_sc_summary<-as.data.frame(mbrare_nbspCO2_sc_summary)
mbrare_nbspCO2_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbspCO2_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbspCO2_sc_summary

## scaled Mortality
newdat_mc_CO2_sc<-absk[,.(AGBM,logSA_sc,CO21_sc,Sprare_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbspCO2_sc<-fitme(AGBM~logSI_sc+logSA_sc*CO21_sc+logSA_sc*Sprare_nbsp_sc+
                           CO21_sc*Sprare_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_CO2_sc,
                         verbose=c(TRACE=TRUE))
save(mcrare_nbspCO2_sc,file="fitme_CO2_Mort_sc_HossfeldSI.R")
load("fitme_CO2_Mort_sc_HossfeldSI.R")

mcrare_nbspCO2_sc_summary<-summary(mcrare_nbspCO2_sc)$beta_table
mcrare_nbspCO2_sc_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(mcrare_nbspCO2_sc_summary[,"t-value"]), df=2544-(871+681+8+1)) %>% as.data.frame()
mcrare_nbspCO2_sc_summary<-as.data.frame(mcrare_nbspCO2_sc_summary)
mcrare_nbspCO2_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbspCO2_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbspCO2_sc_summary

## scaled NBC
newdat_ma_CO2_sc<-absk[,.(AGB,logSA_sc,CO21_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbspCO2_sc<-fitme(AGB~logSI_sc+logSA_sc*CO21_sc+logSA_sc*lograre_nbsp_sc+
                           CO21_sc*lograre_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_CO2_sc,
                         verbose=c(TRACE=TRUE))
save(marare_nbspCO2_sc,file="fitme_CO2_NBC_sc_HossfeldSI.R")
load("fitme_CO2_NBC_sc_HossfeldSI.R")

marare_nbspCO2_sc_summary<-summary(marare_nbspCO2_sc)$beta_table
marare_nbspCO2_sc_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(marare_nbspCO2_sc_summary[,"t-value"]), df=2544-(871+681+8+1)) %>% as.data.frame()
marare_nbspCO2_sc_summary<-as.data.frame(marare_nbspCO2_sc_summary)
marare_nbspCO2_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbspCO2_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbspCO2_sc_summary

### ATA MODELS ###
## scaled Growth
newdat_mb_ATA_sc<-absk[,.(AGBGI,logSA_sc,ATA1_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbspATA_sc<-fitme(AGBGI~logSI_sc+logSA_sc*ATA1_sc+logSA_sc*lograre_nbsp_sc+
                           ATA1_sc*lograre_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_ATA_sc,
                         verbose=c(TRACE=TRUE))
save(mbrare_nbspATA_sc,file="fitme_ATA_Grow_sc_HossfeldSI.R")
load("fitme_ATA_Grow_sc_HossfeldSI.R")

mbrare_nbspATA_sc_summary<-summary(mbrare_nbspATA_sc)$beta_table
mbrare_nbspATA_sc_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(mbrare_nbspATA_sc_summary[,"t-value"]), df=2544-(871+681+8+1)) %>% as.data.frame()
mbrare_nbspATA_sc_summary<-as.data.frame(mbrare_nbspATA_sc_summary)
mbrare_nbspATA_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbspATA_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbspATA_sc_summary

## scaled Mortality
newdat_mc_ATA_sc<-absk[,.(AGBM,logSA_sc,ATA1_sc,Sprare_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbspATA_sc<-fitme(AGBM~logSI_sc+logSA_sc*ATA1_sc+logSA_sc*Sprare_nbsp_sc+
                           ATA1_sc*Sprare_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_ATA_sc,
                         verbose=c(TRACE=TRUE))
save(mcrare_nbspATA_sc,file="fitme_ATA_Mort_sc_HossfeldSI.R")
load("fitme_ATA_Mort_sc_HossfeldSI.R")

mcrare_nbspATA_sc_summary<-summary(mcrare_nbspATA_sc)$beta_table
mcrare_nbspATA_sc_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(mcrare_nbspATA_sc_summary[,"t-value"]), df=2544-(871+681+8+1)) %>% as.data.frame()
mcrare_nbspATA_sc_summary<-as.data.frame(mcrare_nbspATA_sc_summary)
mcrare_nbspATA_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbspATA_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbspATA_sc_summary

## scaled NBC
newdat_ma_ATA_sc<-absk[,.(AGB,logSA_sc,ATA1_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbspATA_sc<-fitme(AGB~logSI_sc+logSA_sc*ATA1_sc+logSA_sc*lograre_nbsp_sc+
                           ATA1_sc*lograre_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_ATA_sc,
                         verbose=c(TRACE=TRUE))
save(marare_nbspATA_sc,file="fitme_ATA_NBC_sc_HossfeldSI.R")
load("fitme_ATA_NBC_sc_HossfeldSI.R")

marare_nbspATA_sc_summary<-summary(marare_nbspATA_sc)$beta_table
marare_nbspATA_sc_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(marare_nbspATA_sc_summary[,"t-value"]), df=2544-(871+681+8+1)) %>% as.data.frame()
marare_nbspATA_sc_summary<-as.data.frame(marare_nbspATA_sc_summary)
marare_nbspATA_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbspATA_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbspATA_sc_summary

### ACMIA MODELS ###
## scaled Growth
newdat_mb_CMI_sc<-absk[,.(AGBGI,logSA_sc,CMI1_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbspCMI_sc<-fitme(AGBGI~logSI_sc+logSA_sc*CMI1_sc+logSA_sc*lograre_nbsp_sc+
                           CMI1_sc*lograre_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_CMI_sc,
                         verbose=c(TRACE=TRUE))
save(mbrare_nbspCMI_sc,file="fitme_ACMIA_Grow_sc_HossfeldSI.R")
load("fitme_ACMIA_Grow_sc_HossfeldSI.R")

mbrare_nbspCMI_sc_summary<-summary(mbrare_nbspCMI_sc)$beta_table
mbrare_nbspCMI_sc_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(mbrare_nbspCMI_sc_summary[,"t-value"]), df=2544-(871+681+8+1)) %>% as.data.frame()
mbrare_nbspCMI_sc_summary<-as.data.frame(mbrare_nbspCMI_sc_summary)
mbrare_nbspCMI_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbspCMI_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbspCMI_sc_summary

## scaled Mortality
newdat_mc_CMI_sc<-absk[,.(AGBM,logSA_sc,CMI1_sc,Sprare_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbspCMI_sc<-fitme(AGBM~logSI_sc+logSA_sc*CMI1_sc+logSA_sc*Sprare_nbsp_sc+
                           CMI1_sc*Sprare_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_CMI_sc,
                         verbose=c(TRACE=TRUE))
save(mcrare_nbspCMI_sc,file="fitme_ACMIA_Mort_sc_HossfeldSI.R")
load("fitme_ACMIA_Mort_sc_HossfeldSI.R")

mcrare_nbspCMI_sc_summary<-summary(mcrare_nbspCMI_sc)$beta_table
mcrare_nbspCMI_sc_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(mcrare_nbspCMI_sc_summary[,"t-value"]), df=2544-(871+681+8+1)) %>% as.data.frame()
mcrare_nbspCMI_sc_summary<-as.data.frame(mcrare_nbspCMI_sc_summary)
mcrare_nbspCMI_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbspCMI_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbspCMI_sc_summary

## scaled NBC
newdat_ma_CMI_sc<-absk[,.(AGB,logSA_sc,CMI1_sc,lograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbspCMI_sc<-fitme(AGB~logSI_sc+logSA_sc*CMI1_sc+logSA_sc*lograre_nbsp_sc+
                           CMI1_sc*lograre_nbsp_sc+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_CMI_sc,
                         verbose=c(TRACE=TRUE))
save(marare_nbspCMI_sc,file="fitme_ACMIA_NBC_sc_HossfeldSI.R")
load("fitme_ACMIA_NBC_sc_HossfeldSI.R")

marare_nbspCMI_sc_summary<-summary(marare_nbspCMI_sc)$beta_table
marare_nbspCMI_sc_summary

#Add Pvalue
#13 fixed terms + 1 residual
Pval<-2*pt(-abs(marare_nbspCMI_sc_summary[,"t-value"]), df=2544-(871+681+8+1)) %>% as.data.frame()
marare_nbspCMI_sc_summary<-as.data.frame(marare_nbspCMI_sc_summary)
marare_nbspCMI_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbspCMI_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbspCMI_sc_summary

### Sequential Models ###
## Scaled Growth
newdat_mb_seq_sc<-absk[,.(AGBGI,logSA_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_seq_sc<-fitme(AGBGI~logSA_sc+logSI_sc+(1|Plotnumber)+
                            Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_seq_sc,
                          verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_seq_sc,file="fitme_Year_Grow_seq_sc_Hossfeld.R")
load("fitme_Year_Grow_seq_sc_Hossfeld.R")

mbrare_nbsp_seq_sc_summary<-summary(mbrare_nbsp_seq_sc)$beta_table
mbrare_nbsp_seq_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbrare_nbsp_seq_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_seq_sc_summary<-as.data.frame(mbrare_nbsp_seq_sc_summary)
mbrare_nbsp_seq_sc_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_seq_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_seq_sc_summary

## Scaled Mortality
newdat_mc_seq_sc<-absk[,.(AGBM,logSA_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_seq_sc<-fitme(AGBM~logSA_sc+logSI_sc+(1|Plotnumber)+
                            Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_seq_sc,
                          verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_seq_sc,file="fitme_Year_Mort_seq_sc_Hossfeld.R")
load("fitme_Year_Mort_seq_sc_Hossfeld.R")

mcrare_nbsp_seq_sc_summary<-summary(mcrare_nbsp_seq_sc)$beta_table
mcrare_nbsp_seq_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcrare_nbsp_seq_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_seq_sc_summary<-as.data.frame(mcrare_nbsp_seq_sc_summary)
mcrare_nbsp_seq_sc_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_seq_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_seq_sc_summary

## Scaled Net Change
newdat_ma_seq_sc<-absk[,.(AGB,logSA_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
marare_nbsp_seq_sc<-fitme(AGB~logSA_sc+logSI_sc+(1|Plotnumber)+
                            Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_seq_sc,
                          verbose=c(TRACE=TRUE))
#save(marare_nbsp_seq_sc,file="fitme_Year_NBC_seq_sc_Hossfeld.R")
load("fitme_Year_NBC_seq_sc_Hossfeld.R")

marare_nbsp_seq_sc_summary<-summary(marare_nbsp_seq_sc)$beta_table
marare_nbsp_seq_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(marare_nbsp_seq_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_seq_sc_summary<-as.data.frame(marare_nbsp_seq_sc_summary)
marare_nbsp_seq_sc_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_seq_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_seq_sc_summary

### Use Initial measurement of the two consective censuses ###
absk[,":="(Inilograre_nbsp_sc=scale(log(rare_nbsp)),
           Finlograre_nbsp_sc=scale(log(nextrare_nbsp)),
           Inilogstd_nbsp_sc=scale(log(std_nbsp)),
           Finlogstd_nbsp_sc=scale(log(nextstd_nbsp)),
           Inilognbsp_sc=scale(log(nbsp)),
           Finlognbsp_sc=scale(log(nextnbsp)),
           InilogShann_sc=scale(log(Shann+1)),
           FinlogShann_sc=scale(log(nextShann+1)),
           IniSprare_nbsp_sc=scale(rare_nbsp),
           FinSprare_nbsp_sc=scale(nextrare_nbsp),
           IniSpstd_nbsp_sc=scale(std_nbsp),
           FinSpstd_nbsp_sc=scale(nextstd_nbsp),
           IniSpnbsp_sc=scale(nbsp),
           FinSpnbsp_sc=scale(nextnbsp),
           IniSpShann_sc=scale(Shann),
           FinSpShann_sc=scale(nextShann))]

## Inirare_nbsp ##
# Scaled Growth
newdat_mb_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,Inilograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbInirare_nbsp_sc<-fitme(AGBGI~logSA_sc+Y_sc+Inilograre_nbsp_sc+logSI_sc+
                           (logSA_sc:Y_sc)+(logSA_sc:Inilograre_nbsp_sc)+
                           (Y_sc:Inilograre_nbsp_sc)+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                         verbose=c(TRACE=TRUE))
save(mbInirare_nbsp_sc,file="fitme_Year_Grow_IniS_sc_HossfeldSI.R")
load("fitme_Year_Grow_IniS_sc_HossfeldSI.R")

mbInirare_nbsp_sc_summary<-summary(mbInirare_nbsp_sc)$beta_table
mbInirare_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbInirare_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbInirare_nbsp_sc_summary<-as.data.frame(mbInirare_nbsp_sc_summary)
mbInirare_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mbInirare_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbInirare_nbsp_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk[,.(AGBM,logSA_sc,Y_sc,IniSprare_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcInirare_nbsp_sc<-fitme(AGBM~logSA_sc+Y_sc+IniSprare_nbsp_sc+logSI_sc+
                           (logSA_sc:Y_sc)+(logSA_sc:IniSprare_nbsp_sc)+
                           (Y_sc:IniSprare_nbsp_sc)+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                         verbose=c(TRACE=TRUE))
save(mcInirare_nbsp_sc,file="fitme_Year_Mort_IniS_sc_HossfeldSI.R")
load("fitme_Year_Mort_IniS_sc_HossfeldSI.R")

mcInirare_nbsp_sc_summary<-summary(mcInirare_nbsp_sc)$beta_table
mcInirare_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcInirare_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcInirare_nbsp_sc_summary<-as.data.frame(mcInirare_nbsp_sc_summary)
mcInirare_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mcInirare_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcInirare_nbsp_sc_summary

# Scaled Net change
newdat_ma_sc<-absk[,.(AGB,logSA_sc,Y_sc,Inilograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
maInirare_nbsp_sc<-fitme(AGB~logSA_sc+Y_sc+Inilograre_nbsp_sc+logSI_sc+
                           (logSA_sc:Y_sc)+(logSA_sc:Inilograre_nbsp_sc)+
                           (Y_sc:Inilograre_nbsp_sc)+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                         verbose=c(TRACE=TRUE))
save(maInirare_nbsp_sc,file="fitme_Year_NBC_IniS_sc_HossfeldSI.R")
load("fitme_Year_NBC_IniS_sc_HossfeldSI.R")

maInirare_nbsp_sc_summary<-summary(maInirare_nbsp_sc)$beta_table
maInirare_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(maInirare_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
maInirare_nbsp_sc_summary<-as.data.frame(maInirare_nbsp_sc_summary)
maInirare_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(maInirare_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
maInirare_nbsp_sc_summary

## Inistd_nbsp ##
# Scaled Growth
newdat_mb_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,Inilogstd_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbInistd_nbsp_sc<-fitme(AGBGI~logSA_sc+Y_sc+Inilogstd_nbsp_sc+logSI_sc+
                          (logSA_sc:Y_sc)+(logSA_sc:Inilogstd_nbsp_sc)+
                          (Y_sc:Inilogstd_nbsp_sc)+(1|Plotnumber)+
                          Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                        verbose=c(TRACE=TRUE))
save(mbInistd_nbsp_sc,file="fitme_Year_Grow_IniSarea_sc_HossfeldSI.R")
load("fitme_Year_Grow_IniSarea_sc_HossfeldSI.R")

mbInistd_nbsp_sc_summary<-summary(mbInistd_nbsp_sc)$beta_table
mbInistd_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbInistd_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbInistd_nbsp_sc_summary<-as.data.frame(mbInistd_nbsp_sc_summary)
mbInistd_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mbInistd_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbInistd_nbsp_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk[,.(AGBM,logSA_sc,Y_sc,IniSpstd_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcInistd_nbsp_sc<-fitme(AGBM~logSA_sc+Y_sc+IniSpstd_nbsp_sc+logSI_sc+
                          (logSA_sc:Y_sc)+(logSA_sc:IniSpstd_nbsp_sc)+
                          (Y_sc:IniSpstd_nbsp_sc)+(1|Plotnumber)+
                          Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                        verbose=c(TRACE=TRUE))
save(mcInistd_nbsp_sc,file="fitme_Year_Mort_IniSarea_sc_HossfeldSI.R")
load("fitme_Year_Mort_IniSarea_sc_HossfeldSI.R")

mcInistd_nbsp_sc_summary<-summary(mcInistd_nbsp_sc)$beta_table
mcInistd_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcInistd_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcInistd_nbsp_sc_summary<-as.data.frame(mcInistd_nbsp_sc_summary)
mcInistd_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mcInistd_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcInistd_nbsp_sc_summary

# Scaled Net change
newdat_ma_sc<-absk[,.(AGB,logSA_sc,Y_sc,Inilogstd_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
maInistd_nbsp_sc<-fitme(AGB~logSA_sc+Y_sc+Inilogstd_nbsp_sc+logSI_sc+
                          (logSA_sc:Y_sc)+(logSA_sc:Inilogstd_nbsp_sc)+
                          (Y_sc:Inilogstd_nbsp_sc)+(1|Plotnumber)+
                          Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                        verbose=c(TRACE=TRUE))
save(maInistd_nbsp_sc,file="fitme_Year_NBC_IniSarea_sc_HossfeldSI.R")
load("fitme_Year_NBC_IniSarea_sc_HossfeldSI.R")

maInistd_nbsp_sc_summary<-summary(maInistd_nbsp_sc)$beta_table
maInistd_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(maInistd_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
maInistd_nbsp_sc_summary<-as.data.frame(maInistd_nbsp_sc_summary)
maInistd_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(maInistd_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
maInistd_nbsp_sc_summary

## Ininbsp ##
# Scaled Growth
newdat_mb_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,Inilognbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbIninbsp_sc<-fitme(AGBGI~logSA_sc+Y_sc+Inilognbsp_sc+logSI_sc+
                      (logSA_sc:Y_sc)+(logSA_sc:Inilognbsp_sc)+
                      (Y_sc:Inilognbsp_sc)+(1|Plotnumber)+
                      Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                    verbose=c(TRACE=TRUE))
save(mbIninbsp_sc,file="fitme_Year_Grow_IniSorg_sc_HossfeldSI.R")
load("fitme_Year_Grow_IniSorg_sc_HossfeldSI.R")

mbIninbsp_sc_summary<-summary(mbIninbsp_sc)$beta_table
mbIninbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbIninbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbIninbsp_sc_summary<-as.data.frame(mbIninbsp_sc_summary)
mbIninbsp_sc_summary$Pval<-Pval[[1]]
colnames(mbIninbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbIninbsp_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk[,.(AGBM,logSA_sc,Y_sc,IniSpnbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcIninbsp_sc<-fitme(AGBM~logSA_sc+Y_sc+IniSpnbsp_sc+logSI_sc+
                      (logSA_sc:Y_sc)+(logSA_sc:IniSpnbsp_sc)+
                      (Y_sc:IniSpnbsp_sc)+(1|Plotnumber)+
                      Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                    verbose=c(TRACE=TRUE))
save(mcIninbsp_sc,file="fitme_Year_Mort_IniSorg_sc_HossfeldSI.R")
load("fitme_Year_Mort_IniSorg_sc_HossfeldSI.R")

mcIninbsp_sc_summary<-summary(mcIninbsp_sc)$beta_table
mcIninbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcIninbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcIninbsp_sc_summary<-as.data.frame(mcIninbsp_sc_summary)
mcIninbsp_sc_summary$Pval<-Pval[[1]]
colnames(mcIninbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcIninbsp_sc_summary

# Scaled Net change
newdat_ma_sc<-absk[,.(AGB,logSA_sc,Y_sc,Inilognbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
maIninbsp_sc<-fitme(AGB~logSA_sc+Y_sc+Inilognbsp_sc+logSI_sc+
                      (logSA_sc:Y_sc)+(logSA_sc:Inilognbsp_sc)+
                      (Y_sc:Inilognbsp_sc)+(1|Plotnumber)+
                      Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                    verbose=c(TRACE=TRUE))
save(maIninbsp_sc,file="fitme_Year_NBC_IniSorg_sc_HossfeldSI.R")
load("fitme_Year_NBC_IniSorg_sc_HossfeldSI.R")

maIninbsp_sc_summary<-summary(maIninbsp_sc)$beta_table
maIninbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(maIninbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
maIninbsp_sc_summary<-as.data.frame(maIninbsp_sc_summary)
maIninbsp_sc_summary$Pval<-Pval[[1]]
colnames(maIninbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
maIninbsp_sc_summary

## IniShann ##
# Scaled Growth
newdat_mb_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,InilogShann_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbIniShann_sc<-fitme(AGBGI~logSA_sc+Y_sc+InilogShann_sc+logSI_sc+
                       (logSA_sc:Y_sc)+(logSA_sc:InilogShann_sc)+
                       (Y_sc:InilogShann_sc)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                     verbose=c(TRACE=TRUE))
save(mbIniShann_sc,file="fitme_Year_Grow_IniShann_sc_HossfeldSI.R")
load("fitme_Year_Grow_IniShann_sc_HossfeldSI.R")

mbIniShann_sc_summary<-summary(mbIniShann_sc)$beta_table
mbIniShann_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbIniShann_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbIniShann_sc_summary<-as.data.frame(mbIniShann_sc_summary)
mbIniShann_sc_summary$Pval<-Pval[[1]]
colnames(mbIniShann_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbIniShann_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk[,.(AGBM,logSA_sc,Y_sc,IniSpShann_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcIniShann_sc<-fitme(AGBM~logSA_sc+Y_sc+IniSpShann_sc+logSI_sc+
                       (logSA_sc:Y_sc)+(logSA_sc:IniSpShann_sc)+
                       (Y_sc:IniSpShann_sc)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                     verbose=c(TRACE=TRUE))
save(mcIniShann_sc,file="fitme_Year_Mort_IniShann_sc_HossfeldSI.R")
load("fitme_Year_Mort_IniShann_sc_HossfeldSI.R")

mcIniShann_sc_summary<-summary(mcIniShann_sc)$beta_table
mcIniShann_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcIniShann_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcIniShann_sc_summary<-as.data.frame(mcIniShann_sc_summary)
mcIniShann_sc_summary$Pval<-Pval[[1]]
colnames(mcIniShann_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcIniShann_sc_summary

# Scaled Net change
newdat_ma_sc<-absk[,.(AGB,logSA_sc,Y_sc,InilogShann_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
maIniShann_sc<-fitme(AGB~logSA_sc+Y_sc+InilogShann_sc+logSI_sc+
                       (logSA_sc:Y_sc)+(logSA_sc:InilogShann_sc)+
                       (Y_sc:InilogShann_sc)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                     verbose=c(TRACE=TRUE))
save(maIniShann_sc,file="fitme_Year_NBC_IniShann_sc_HossfeldSI.R")
load("fitme_Year_NBC_IniShann_sc_HossfeldSI.R")

maIniShann_sc_summary<-summary(maIniShann_sc)$beta_table
maIniShann_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(maIniShann_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
maIniShann_sc_summary<-as.data.frame(maIniShann_sc_summary)
maIniShann_sc_summary$Pval<-Pval[[1]]
colnames(maIniShann_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
maIniShann_sc_summary

## Finrare_nbsp ##
# Scaled Growth
newdat_mb_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,Finlograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbFinrare_nbsp_sc<-fitme(AGBGI~logSA_sc+Y_sc+Finlograre_nbsp_sc+logSI_sc+
                           (logSA_sc:Y_sc)+(logSA_sc:Finlograre_nbsp_sc)+
                           (Y_sc:Finlograre_nbsp_sc)+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                         verbose=c(TRACE=TRUE))
save(mbFinrare_nbsp_sc,file="fitme_Year_Grow_FinS_sc_HossfeldSI.R")
load("fitme_Year_Grow_FinS_sc_HossfeldSI.R")

mbFinrare_nbsp_sc_summary<-summary(mbFinrare_nbsp_sc)$beta_table
mbFinrare_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbFinrare_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbFinrare_nbsp_sc_summary<-as.data.frame(mbFinrare_nbsp_sc_summary)
mbFinrare_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mbFinrare_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbFinrare_nbsp_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk[,.(AGBM,logSA_sc,Y_sc,FinSprare_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcFinrare_nbsp_sc<-fitme(AGBM~logSA_sc+Y_sc+FinSprare_nbsp_sc+logSI_sc+
                           (logSA_sc:Y_sc)+(logSA_sc:FinSprare_nbsp_sc)+
                           (Y_sc:FinSprare_nbsp_sc)+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                         verbose=c(TRACE=TRUE))
save(mcFinrare_nbsp_sc,file="fitme_Year_Mort_FinS_sc_HossfeldSI.R")
load("fitme_Year_Mort_FinS_sc_HossfeldSI.R")

mcFinrare_nbsp_sc_summary<-summary(mcFinrare_nbsp_sc)$beta_table
mcFinrare_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcFinrare_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcFinrare_nbsp_sc_summary<-as.data.frame(mcFinrare_nbsp_sc_summary)
mcFinrare_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mcFinrare_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcFinrare_nbsp_sc_summary

# Scaled Net change
newdat_ma_sc<-absk[,.(AGB,logSA_sc,Y_sc,Finlograre_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
maFinrare_nbsp_sc<-fitme(AGB~logSA_sc+Y_sc+Finlograre_nbsp_sc+logSI_sc+
                           (logSA_sc:Y_sc)+(logSA_sc:Finlograre_nbsp_sc)+
                           (Y_sc:Finlograre_nbsp_sc)+(1|Plotnumber)+
                           Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                         verbose=c(TRACE=TRUE))
save(maFinrare_nbsp_sc,file="fitme_Year_NBC_FinS_sc_HossfeldSI.R")
load("fitme_Year_NBC_FinS_sc_HossfeldSI.R")

maFinrare_nbsp_sc_summary<-summary(maFinrare_nbsp_sc)$beta_table
maFinrare_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(maFinrare_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
maFinrare_nbsp_sc_summary<-as.data.frame(maFinrare_nbsp_sc_summary)
maFinrare_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(maFinrare_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
maFinrare_nbsp_sc_summary

## Finstd_nbsp ##
# Scaled Growth
newdat_mb_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,Finlogstd_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbFinstd_nbsp_sc<-fitme(AGBGI~logSA_sc+Y_sc+Finlogstd_nbsp_sc+logSI_sc+
                          (logSA_sc:Y_sc)+(logSA_sc:Finlogstd_nbsp_sc)+
                          (Y_sc:Finlogstd_nbsp_sc)+(1|Plotnumber)+
                          Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                        verbose=c(TRACE=TRUE))
save(mbFinstd_nbsp_sc,file="fitme_Year_Grow_FinSarea_sc_HossfeldSI.R")
load("fitme_Year_Grow_FinSarea_sc_HossfeldSI.R")

mbFinstd_nbsp_sc_summary<-summary(mbFinstd_nbsp_sc)$beta_table
mbFinstd_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbFinstd_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbFinstd_nbsp_sc_summary<-as.data.frame(mbFinstd_nbsp_sc_summary)
mbFinstd_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mbFinstd_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbFinstd_nbsp_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk[,.(AGBM,logSA_sc,Y_sc,FinSpstd_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcFinstd_nbsp_sc<-fitme(AGBM~logSA_sc+Y_sc+FinSpstd_nbsp_sc+logSI_sc+
                          (logSA_sc:Y_sc)+(logSA_sc:FinSpstd_nbsp_sc)+
                          (Y_sc:FinSpstd_nbsp_sc)+(1|Plotnumber)+
                          Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                        verbose=c(TRACE=TRUE))
save(mcFinstd_nbsp_sc,file="fitme_Year_Mort_FinSarea_sc_HossfeldSI.R")
load("fitme_Year_Mort_FinSarea_sc_HossfeldSI.R")

mcFinstd_nbsp_sc_summary<-summary(mcFinstd_nbsp_sc)$beta_table
mcFinstd_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcFinstd_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcFinstd_nbsp_sc_summary<-as.data.frame(mcFinstd_nbsp_sc_summary)
mcFinstd_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(mcFinstd_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcFinstd_nbsp_sc_summary

# Scaled Net change
newdat_ma_sc<-absk[,.(AGB,logSA_sc,Y_sc,Finlogstd_nbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
maFinstd_nbsp_sc<-fitme(AGB~logSA_sc+Y_sc+Finlogstd_nbsp_sc+logSI_sc+
                          (logSA_sc:Y_sc)+(logSA_sc:Finlogstd_nbsp_sc)+
                          (Y_sc:Finlogstd_nbsp_sc)+(1|Plotnumber)+
                          Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                        verbose=c(TRACE=TRUE))
save(maFinstd_nbsp_sc,file="fitme_Year_NBC_FinSarea_sc_HossfeldSI.R")
load("fitme_Year_NBC_FinSarea_sc_HossfeldSI.R")

maFinstd_nbsp_sc_summary<-summary(maFinstd_nbsp_sc)$beta_table
maFinstd_nbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(maFinstd_nbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
maFinstd_nbsp_sc_summary<-as.data.frame(maFinstd_nbsp_sc_summary)
maFinstd_nbsp_sc_summary$Pval<-Pval[[1]]
colnames(maFinstd_nbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
maFinstd_nbsp_sc_summary

## Finnbsp ##
# Scaled Growth
newdat_mb_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,Finlognbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbFinnbsp_sc<-fitme(AGBGI~logSA_sc+Y_sc+Finlognbsp_sc+logSI_sc+
                      (logSA_sc:Y_sc)+(logSA_sc:Finlognbsp_sc)+
                      (Y_sc:Finlognbsp_sc)+(1|Plotnumber)+
                      Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                    verbose=c(TRACE=TRUE))
save(mbFinnbsp_sc,file="fitme_Year_Grow_FinSorg_sc_HossfeldSI.R")
load("fitme_Year_Grow_FinSorg_sc_HossfeldSI.R")

mbFinnbsp_sc_summary<-summary(mbFinnbsp_sc)$beta_table
mbFinnbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbFinnbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbFinnbsp_sc_summary<-as.data.frame(mbFinnbsp_sc_summary)
mbFinnbsp_sc_summary$Pval<-Pval[[1]]
colnames(mbFinnbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbFinnbsp_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk[,.(AGBM,logSA_sc,Y_sc,FinSpnbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcFinnbsp_sc<-fitme(AGBM~logSA_sc+Y_sc+FinSpnbsp_sc+logSI_sc+
                      (logSA_sc:Y_sc)+(logSA_sc:FinSpnbsp_sc)+
                      (Y_sc:FinSpnbsp_sc)+(1|Plotnumber)+
                      Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                    verbose=c(TRACE=TRUE))
save(mcFinnbsp_sc,file="fitme_Year_Mort_FinSorg_sc_HossfeldSI.R")
load("fitme_Year_Mort_FinSorg_sc_HossfeldSI.R")

mcFinnbsp_sc_summary<-summary(mcFinnbsp_sc)$beta_table
mcFinnbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcFinnbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcFinnbsp_sc_summary<-as.data.frame(mcFinnbsp_sc_summary)
mcFinnbsp_sc_summary$Pval<-Pval[[1]]
colnames(mcFinnbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcFinnbsp_sc_summary

# Scaled Net change
newdat_ma_sc<-absk[,.(AGB,logSA_sc,Y_sc,Finlognbsp_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
maFinnbsp_sc<-fitme(AGB~logSA_sc+Y_sc+Finlognbsp_sc+logSI_sc+
                      (logSA_sc:Y_sc)+(logSA_sc:Finlognbsp_sc)+
                      (Y_sc:Finlognbsp_sc)+(1|Plotnumber)+
                      Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                    verbose=c(TRACE=TRUE))
save(maFinnbsp_sc,file="fitme_Year_NBC_FinSorg_sc_HossfeldSI.R")
load("fitme_Year_NBC_FinSorg_sc_HossfeldSI.R")

maFinnbsp_sc_summary<-summary(maFinnbsp_sc)$beta_table
maFinnbsp_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(maFinnbsp_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
maFinnbsp_sc_summary<-as.data.frame(maFinnbsp_sc_summary)
maFinnbsp_sc_summary$Pval<-Pval[[1]]
colnames(maFinnbsp_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
maFinnbsp_sc_summary

## FinShann ##
# Scaled Growth
newdat_mb_sc<-absk[,.(AGBGI,logSA_sc,Y_sc,FinlogShann_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mbFinShann_sc<-fitme(AGBGI~logSA_sc+Y_sc+FinlogShann_sc+logSI_sc+
                       (logSA_sc:Y_sc)+(logSA_sc:FinlogShann_sc)+
                       (Y_sc:FinlogShann_sc)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb_sc,
                     verbose=c(TRACE=TRUE))
save(mbFinShann_sc,file="fitme_Year_Grow_FinShann_sc_HossfeldSI.R")
load("fitme_Year_Grow_FinShann_sc_HossfeldSI.R")

mbFinShann_sc_summary<-summary(mbFinShann_sc)$beta_table
mbFinShann_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mbFinShann_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbFinShann_sc_summary<-as.data.frame(mbFinShann_sc_summary)
mbFinShann_sc_summary$Pval<-Pval[[1]]
colnames(mbFinShann_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbFinShann_sc_summary

# Scaled Mortality
newdat_mc_sc<-absk[,.(AGBM,logSA_sc,Y_sc,FinSpShann_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
mcFinShann_sc<-fitme(AGBM~logSA_sc+Y_sc+FinSpShann_sc+logSI_sc+
                       (logSA_sc:Y_sc)+(logSA_sc:FinSpShann_sc)+
                       (Y_sc:FinSpShann_sc)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc_sc,
                     verbose=c(TRACE=TRUE))
save(mcFinShann_sc,file="fitme_Year_Mort_FinShann_sc_HossfeldSI.R")
load("fitme_Year_Mort_FinShann_sc_HossfeldSI.R")

mcFinShann_sc_summary<-summary(mcFinShann_sc)$beta_table
mcFinShann_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(mcFinShann_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcFinShann_sc_summary<-as.data.frame(mcFinShann_sc_summary)
mcFinShann_sc_summary$Pval<-Pval[[1]]
colnames(mcFinShann_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcFinShann_sc_summary

# Scaled Net change
newdat_ma_sc<-absk[,.(AGB,logSA_sc,Y_sc,FinlogShann_sc,logSI_sc,Plotnumber,wi,LAT,LONG)]
maFinShann_sc<-fitme(AGB~logSA_sc+Y_sc+FinlogShann_sc+logSI_sc+
                       (logSA_sc:Y_sc)+(logSA_sc:FinlogShann_sc)+
                       (Y_sc:FinlogShann_sc)+(1|Plotnumber)+
                       Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma_sc,
                     verbose=c(TRACE=TRUE))
save(maFinShann_sc,file="fitme_Year_NBC_FinShann_sc_HossfeldSI.R")
load("fitme_Year_NBC_FinShann_sc_HossfeldSI.R")

maFinShann_sc_summary<-summary(maFinShann_sc)$beta_table
maFinShann_sc_summary

#Add Pvalue
Pval<-2*pt(-abs(maFinShann_sc_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
maFinShann_sc_summary<-as.data.frame(maFinShann_sc_summary)
maFinShann_sc_summary$Pval<-Pval[[1]]
colnames(maFinShann_sc_summary)<-c("Estimate","Cond.SE","t-value","p-value")
maFinShann_sc_summary