library(nlme);library(lmeresampler)
library(lme4);library(lmerTest)
library(boot);library(Rfit)
library(MuMIn);library(ggplot2)
library(grid);library(gridExtra)
library(gtable);library(plyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(Hmisc)
library(spdep);library(SoDA);library(ape)
library(spaMM)

absk<-fread("Hisano_et_al_Data_Submitted_to_EcolLett.csv")
absk[,":="(logSI1=log(SI1))] %>% 
  .[,":="(Long=LONG+rnorm(nrow(absk),0,0.001),
          Lat=LAT+rnorm(nrow(absk),0,0.001),
          logSI=logSI1+rnorm(nrow(absk),0,0.000000000000001))] %>% 
  .[,":="(logSI=scale(logSI,scale=F),logBio_sc=scale(log(total_Bio1)))] %>% 
  .[,":="(logSA_sc=scale(log(SA1)),
          invlogSA_sc=scale(1/log(SA1)),
          Y_sc=scale(Year),
          Sprare_nbsp_sc=scale(Sprare_nbsp1),lograre_nbsp_sc=scale(lograre_nbsp1),
          Spstd_nbsp_sc=scale(Spstd_nbsp1),logstd_nbsp_sc=scale(logstd_nbsp1),
          Spnbsp_sc=scale(SpS),lognbsp_sc=scale(log(SpS)),
          SpShann_sc=scale(SpShann1),logShann_sc=scale(log(SpShann1+1)),
          SpSimp_sc=scale(SpSimp1),logSimp_sc=scale(log(SpSimp1+1)),
          SpST_sc=scale(SpST1),logST_sc=scale(log(SpST1)),sqrtST_sc=scale(sqrt(SpST1)),quadST_sc=scale(SpST1^2),
          logSI_sc=scale(logSI))] %>% 
  .[,":="(ATA1_10=ATA1*10,
          CO21_sc=scale(CO2),ATA1_sc=scale(ATA),CMI1_sc=scale(ACMIA))]

#Replace with Elevation
absk[,LAT1:=scale(LAT,center = T, scale = F)]
### YEAR MODELS ###
## Growth
newdat_mb<-absk[,.(AGBGI,logSA,Y,lograre_nbsp,LAT1,Elev,Plotnumber,wi,LAT,LONG)]
mbrare_nbsp_Elev_LAT<-fitme(AGBGI~logSA+Y+lograre_nbsp+Elev+LAT1+
                     (logSA:Y)+(logSA:lograre_nbsp)+
                     (Y:lograre_nbsp)+(1|Plotnumber)+
                     Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mb,
                   verbose=c(TRACE=TRUE))
#save(mbrare_nbsp_Elev_LAT,file="fitme_Year_Grow_Elev_LAT_HossfeldSI.R")
load("fitme_Year_Grow_Elev_LAT_HossfeldSI.R")

mbrare_nbsp_Elev_LAT_summary<-summary(mbrare_nbsp_Elev_LAT)$beta_table
mbrare_nbsp_Elev_LAT_summary


summary(mbrare_nbsp_Elev_LAT)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(mbrare_nbsp_Elev_LAT_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_Elev_LAT_summary<-as.data.frame(mbrare_nbsp_Elev_LAT_summary)
mbrare_nbsp_Elev_LAT_summary$Pval<-Pval[[1]]
colnames(mbrare_nbsp_Elev_LAT_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mbrare_nbsp_Elev_LAT_summary

## Mortality
newdat_mc<-absk[,.(AGBM,logSA,Y,Sprare_nbsp,LAT1,Elev,Plotnumber,wi,LAT,LONG)]
mcrare_nbsp_Elev_LAT<-fitme(AGBM~logSA+Y+Sprare_nbsp+Elev+LAT1+
                     (logSA:Y)+(logSA:Sprare_nbsp)+
                     (Y:Sprare_nbsp)+(1|Plotnumber)+
                     Matern(1|LAT+LONG),prior.weights=wi,data=newdat_mc,
                   verbose=c(TRACE=TRUE))
#save(mcrare_nbsp_Elev_LAT,file="fitme_Year_Mort_Elev_LAT_HossfeldSI.R")
load("fitme_Year_Mort_Elev_LAT_HossfeldSI.R")

mcrare_nbsp_Elev_LAT_summary<-summary(mcrare_nbsp_Elev_LAT)$beta_table
mcrare_nbsp_Elev_LAT_summary

#Add Pvalue
summary(mcrare_nbsp_Elev_LAT)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(mcrare_nbsp_Elev_LAT_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_Elev_LAT_summary<-as.data.frame(mcrare_nbsp_Elev_LAT_summary)
mcrare_nbsp_Elev_LAT_summary$Pval<-Pval[[1]]
colnames(mcrare_nbsp_Elev_LAT_summary)<-c("Estimate","Cond.SE","t-value","p-value")
mcrare_nbsp_Elev_LAT_summary

## Net change
newdat_ma<-absk[,.(AGB,logSA,Y,lograre_nbsp,Elev,LAT1,Plotnumber,wi,LAT,LONG)]
marare_nbsp_Elev_LAT<-fitme(AGB~logSA+Y+lograre_nbsp+Elev+LAT1+
                     (logSA:Y)+(logSA:lograre_nbsp)+
                     (Y:lograre_nbsp)+(1|Plotnumber)+
                     Matern(1|LAT+LONG),prior.weights=wi,data=newdat_ma,
                   verbose=c(TRACE=TRUE))
#save(marare_nbsp_Elev_LAT,file="fitme_Year_NBC_Elev_LAT_HossfeldSI.R")
load("fitme_Year_NBC_Elev_LAT_HossfeldSI.R")

marare_nbsp_Elev_LAT_summary<-summary(marare_nbsp_Elev_LAT)$beta_table
marare_nbsp_Elev_LAT_summary

#Add Pvalue
summary(marare_nbsp_Elev_LAT)# of obs: 2544; # of groups: Plotnumber, 871; LONG + LAT, 681
#and 7 fixed terms + 1 residual
Pval<-2*pt(-abs(marare_nbsp_Elev_LAT_summary[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_Elev_LAT_summary<-as.data.frame(marare_nbsp_Elev_LAT_summary)
marare_nbsp_Elev_LAT_summary$Pval<-Pval[[1]]
colnames(marare_nbsp_Elev_LAT_summary)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_Elev_LAT_summary

load("fitme_Year_Grow_HossfeldSI.R")
load("fitme_Year_Mort_HossfeldSI.R")
load("fitme_Year_NBC_HossfeldSI.R")
#marginal R2 and describes the proportion of variance explained by the fixed factor(s) alone
#conditional R2, which describes the proportion of variance explained by both the fixed and random factors
AIC(mbrare_nbsp_Elev_LAT)#conditional AIC: 5427.119
AIC(mbrare_nbsp)#conditional AIC: 5423.207#
AIC(mcrare_nbsp_Elev_LAT)#conditional AIC: 8994.171
AIC(mcrare_nbsp)#conditional AIC: 8927.134#
AIC(marare_nbsp_Elev_LAT)#conditional AIC: 9710.806
AIC(marare_nbsp)#conditional AIC: 9672.05#

################ Table S ################
#Model
load("fitme_Year_Grow_Elev_LAT_HossfeldSI.R")
load("fitme_Year_Mort_Elev_LAT_HossfeldSI.R")
load("fitme_Year_NBC_Elev_LAT_HossfeldSI.R")

mbrare_nbsp_Elev_LAT_Pval<-summary(mbrare_nbsp_Elev_LAT)$beta_table
Pval<-2*pt(-abs(mbrare_nbsp_Elev_LAT_Pval[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
mbrare_nbsp_Elev_LAT_Pval<-as.data.frame(mbrare_nbsp_Elev_LAT_Pval)
mbrare_nbsp_Elev_LAT_Pval$Pval<-Pval[[1]]
colnames(mbrare_nbsp_Elev_LAT_Pval)<-c("Estimbte","Cond.SE","t-value","p-value")
mbrare_nbsp_Elev_LAT_Pval

mcrare_nbsp_Elev_LAT_Pval<-summary(mcrare_nbsp_Elev_LAT)$beta_table
Pval<-2*pt(-abs(mcrare_nbsp_Elev_LAT_Pval[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
mcrare_nbsp_Elev_LAT_Pval<-as.data.frame(mcrare_nbsp_Elev_LAT_Pval)
mcrare_nbsp_Elev_LAT_Pval$Pval<-Pval[[1]]
colnames(mcrare_nbsp_Elev_LAT_Pval)<-c("Estimcte","Cond.SE","t-value","p-value")
mcrare_nbsp_Elev_LAT_Pval

marare_nbsp_Elev_LAT_Pval<-summary(marare_nbsp_Elev_LAT)$beta_table
Pval<-2*pt(-abs(marare_nbsp_Elev_LAT_Pval[,"t-value"]), df=2544-(871+681+9+1)) %>% as.data.frame()
marare_nbsp_Elev_LAT_Pval<-as.data.frame(marare_nbsp_Elev_LAT_Pval)
marare_nbsp_Elev_LAT_Pval$Pval<-Pval[[1]]
colnames(marare_nbsp_Elev_LAT_Pval)<-c("Estimate","Cond.SE","t-value","p-value")
marare_nbsp_Elev_LAT_Pval

#Table S
coefmbrare_nbsp_Elev_LAT<-mbrare_nbsp_Elev_LAT_Pval[,1]
coefmcrare_nbsp_Elev_LAT<-mcrare_nbsp_Elev_LAT_Pval[,1]
coefmarare_nbsp_Elev_LAT<-marare_nbsp_Elev_LAT_Pval[,1]
SEmbrare_nbsp_Elev_LAT<-mbrare_nbsp_Elev_LAT_Pval[,2]
SEmcrare_nbsp_Elev_LAT<-mcrare_nbsp_Elev_LAT_Pval[,2]
SEmarare_nbsp_Elev_LAT<-marare_nbsp_Elev_LAT_Pval[,2]

TS4<-data.table(Source=c(rownames(mbrare_nbsp_Elev_LAT_Pval),rownames(mcrare_nbsp_Elev_LAT_Pval),rownames(marare_nbsp_Elev_LAT_Pval)),
                coef=NA,Tval=NA,Pval=NA)

#TS4$coef<-c(c(paste(round(coefmbrare_nbsp_Elev_LAT,digits=3)," } ",round(SEmbrare_nbsp_Elev_LAT,digits=3))),
#            c(paste(round(coefmcrare_nbsp_Elev_LAT,digits=3)," } ",round(SEmcrare_nbsp_Elev_LAT,digits=3))),
#            c(paste(round(coefmarare_nbsp_Elev_LAT,digits=3)," } ",round(SEmarare_nbsp_Elev_LAT,digits=3))))

TS4$coef<-c(ifelse(abs(coefmbrare_nbsp_Elev_LAT)<0.001,
                   c(paste(round(coefmbrare_nbsp_Elev_LAT,digits=5)," } ",round(SEmbrare_nbsp_Elev_LAT,digits=5))),
                   c(paste(round(coefmbrare_nbsp_Elev_LAT,digits=3)," } ",round(SEmbrare_nbsp_Elev_LAT,digits=3)))),
            ifelse(abs(coefmcrare_nbsp_Elev_LAT)<0.001,
                   c(paste(round(coefmcrare_nbsp_Elev_LAT,digits=5)," } ",round(SEmcrare_nbsp_Elev_LAT,digits=5))),
                   c(paste(round(coefmcrare_nbsp_Elev_LAT,digits=3)," } ",round(SEmcrare_nbsp_Elev_LAT,digits=3)))),
            ifelse(abs(coefmarare_nbsp_Elev_LAT)<0.001,
                   c(paste(round(coefmarare_nbsp_Elev_LAT,digits=5)," } ",round(SEmarare_nbsp_Elev_LAT,digits=5))),
                   c(paste(round(coefmarare_nbsp_Elev_LAT,digits=3)," } ",round(SEmarare_nbsp_Elev_LAT,digits=3)))))

TS4$Tval<-c(round(mbrare_nbsp_Elev_LAT_Pval[,3],digits=3),
            round(mcrare_nbsp_Elev_LAT_Pval[,3],digits=3),
            round(marare_nbsp_Elev_LAT_Pval[,3],digits=3))

TS4$Pval<-c(round(mbrare_nbsp_Elev_LAT_Pval[,4],digits=3),
            round(mcrare_nbsp_Elev_LAT_Pval[,4],digits=3),
            round(marare_nbsp_Elev_LAT_Pval[,4],digits=3))

TS4$Pval<-ifelse(TS4$Pval<0.001,"< 0.001",TS4$Pval)

View(TS4)
