library(nlme);library(lmeresampler)
library(lme4);library(lmerTest)
library(boot);library(Rfit)
library(MuMIn);library(ggplot2)
library(grid);library(gridExtra)
library(gtable);library(plyr);library(tidyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(Hmisc)
library(spdep);library(SoDA);library(ape)
library(spaMM)

absk<-fread("Hisano_et_al_Data_Submitted_to_EcolLett.csv");absk$FT<-as.factor(absk$FT)#871 latest data
absk[,":="(Long=LONG+rnorm(nrow(absk),0,0.001),
           Lat=LAT+rnorm(nrow(absk),0,0.001),
           logSI=logSI1+rnorm(nrow(absk),0,0.000000000000001),
           Yearji=Year+rnorm(nrow(absk),0,0.000000000000001))] %>% 
  .[,logSI:=scale(logSI,scale=F)] %>% 
  .[,":="(logSA_sc=scale(log(SA1)),
          invlogSA_sc=scale(1/log(SA1)),
          Y_sc=scale(Year),
          Sprare_nbsp_sc=scale(Sprare_nbsp1),lograre_nbsp_sc=scale(lograre_nbsp1),
          Spstd_nbsp_sc=scale(Spstd_nbsp1),logstd_nbsp_sc=scale(logstd_nbsp1),
          Spnbsp_sc=scale(SpS),lognbsp_sc=scale(log(SpS)),
          SpShann_sc=scale(SpShann1),logShann_sc=scale(log(SpShann1+1)),
          logSI_sc=scale(logSI))] %>% 
  .[,":="(ATA1_10=ATA1*10,
          CO21_sc=scale(CO2),ATA1_sc=scale(ATA),CMI1_sc=scale(ACMIA))]

################## Example of temporal autocorrealtion
#Grow
mb<-lme(AGBGI~logSA+Y+lograre_nbsp+logSI+(logSA:Y)+(logSA:lograre_nbsp)+(Y:lograre_nbsp),random=~1|Plotnumber,weights=~1/wi,
         cor=corCAR1(form= ~ Y | Plotnumber),absk)
mb2<-lme(AGBGI~logSA+Y+lograre_nbsp+logSI+(logSA:Y)+(logSA:lograre_nbsp)+(Y:lograre_nbsp),random=~1|Plotnumber,weights=~1/wi,
        absk)
summary(lmer(AGBGI~logSA+Y+lograre_nbsp+logSI+(logSA:Y)+(logSA:lograre_nbsp)+(Y:lograre_nbsp)+(1|Plotnumber),weights=wi,
             absk))$co
ACF(mb2)
summary(mb)$tTable
summary(mb2)$tTable
AIC(mb)
AIC(mb2)#

#Mort
mc<-lme(AGBM~logSA+Y+Sprare_nbsp+logSI+(logSA:Y)+(logSA:Sprare_nbsp)+(Y:Sprare_nbsp),random=~1|Plotnumber,weights=~1/wi,
        cor=corCAR1(form= ~ Y | Plotnumber),absk)
mc2<-lme(AGBM~logSA+Y+Sprare_nbsp+logSI+(logSA:Y)+(logSA:Sprare_nbsp)+(Y:Sprare_nbsp),random=~1|Plotnumber,weights=~1/wi,
         absk)

summary(lmer(AGBM~logSA+Y+Sprare_nbsp+logSI+(logSA:Y)+(logSA:Sprare_nbsp)+(Y:Sprare_nbsp)+(1|Plotnumber),weights=wi,
             absk))$co
ACF(mc2)
summary(mc)$tTable
summary(mc2)$tTable
AIC(mc)
AIC(mc2)#

#NBC
ma<-lme(AGB~logSA+Y+lograre_nbsp+logSI+(logSA:Y)+(logSA:lograre_nbsp)+(Y:lograre_nbsp),random=~1|Plotnumber,weights=~1/wi,
        cor=corCAR1(form= ~ Y | Plotnumber),absk)
ma2<-lme(AGB~logSA+Y+lograre_nbsp+logSI+(logSA:Y)+(logSA:lograre_nbsp)+(Y:lograre_nbsp),random=~1|Plotnumber,weights=~1/wi,
         absk)

summary(lmer(AGB~logSA+Y+lograre_nbsp+logSI+(logSA:Y)+(logSA:lograre_nbsp)+(Y:lograre_nbsp)+(1|Plotnumber),weights=wi,
             absk))$co
ACF(ma2)
summary(ma)$tTable
summary(ma2)$tTable
AIC(ma)
AIC(ma2)#

#Although AIC is less for the model with accounted for temporal autocorr, we care more about spatial auto. but spaMM cannot account for both
#After accoting for Year and SA, there should be no temporal autocorr theoretically.
#The original model produced qualiatatively similar coefs to lme with autoregressive, as well as RAGB 

##################
dat<-data.table(count(absk$Plotnumber))
max(dat[,"freq"])

#AGBGI
mb<-lmer(AGBGI~logSA+Y+lograre_nbsp+logSI+(logSA:Y)+(logSA:lograre_nbsp)+(Y:lograre_nbsp)+(1|Plotnumber),weights=wi,absk)
absk[,AGBGI_resid:=resid(mb)]
mbR<-lmer(RAGBGI~logSA+Y+lograre_nbsp+logSI+(logSA:Y)+(logSA:lograre_nbsp)+(Y:lograre_nbsp)+(1|Plotnumber),weights=wi,absk)
absk[,RAGBGI_resid:=resid(mbR)]

acf_vec<-absk[order(Year),][,.(AGBGI_resid,AGBGI,Year)]
acf(acf_vec[,.(AGBGI_resid)])
acf(acf_vec[,.(AGBGI)])
acf(acf_vec[,.(AGBGI_resid)])

#https://stat.ethz.ch/R-manual/R-devel/library/base/html/seq.html
#"If we want to work with the acf() function wefll need to make sure that the dataset is 
#spaced appropriately. To achieve this we can add empty rows to the dataset for any missing 
#samples. In addition, we need to add rows between sample units so we donft mistakenly 
#treat them as if they were from the same time series."
newdat<-data.table(Plotnumber=rep(unique(absk$Plotnumber),length(seq(from=min(absk$Year),to=max(absk$Year),by=0.5))),
                   Year_eq=rep(seq(from=min(absk$Year),to=max(absk$Year),by=0.5),871))
newdat<-newdat[order(Plotnumber,Year_eq)] %>% 
  .[,PLOT_Year:=paste(Plotnumber,Year_eq,sep="_")] %>% 
  .[,Plotnumber:=as.factor(Plotnumber)]

absk[,PLOT_Year:=paste(Plotnumber,Year,sep="_")]
newdat[,":="(Year=absk[match(newdat$PLOT_Year,PLOT_Year),Year],
             AGBGI_resid=absk[match(newdat$PLOT_Year,PLOT_Year),AGBGI_resid],
             AGBGI=absk[match(newdat$PLOT_Year,PLOT_Year),AGBGI],
             RAGBGI_resid=absk[match(newdat$PLOT_Year,PLOT_Year),RAGBGI_resid],
             RAGBGI=absk[match(newdat$PLOT_Year,PLOT_Year),RAGBGI])]
acf_vecGI<-newdat[order(Year_eq)][,.(Plotnumber,AGBGI_resid,AGBGI,RAGBGI_resid,RAGBGI,Year_eq)]
#acf_vecGI<-newdat[order(Plotnumber,Year_eq),][,.(Plotnumber,AGBGI_resid,AGBGI,RAGBGI_resid,RAGBGI,Year_eq)]
acf(acf_vecGI[,.(AGBGI_resid)],na.action = na.pass)#Use na.pass
acf(acf_vecGI[,.(AGBGI)],na.action = na.pass)
acf(acf_vecGI[,.(RAGBGI_resid)],na.action = na.pass)#Use na.pass
acf(acf_vecGI[,.(RAGBGI)],na.action = na.pass)

#AGBM
mc<-lmer(AGBM~logSA+Y+Sprare_nbsp+logSI+(logSA:Y)+(logSA:Sprare_nbsp)+(Y:Sprare_nbsp)+(1|Plotnumber),weights=wi,absk)
absk[,AGBM_pred:=predict(mc)]

pairs(absk[,.(AGBM_pred,Year)])
absk[,AGBM_resid:=resid(mc)]
absk[,AGBM_resid:=resid(mc,type="pearson")]
acf_vec<-absk[order(Year),][,.(AGBM_resid,AGBM,Year)]
acf(acf_vec[,AGBM_resid])
acf(acf_vec[,AGBM])

newdat<-data.table(Plotnumber=rep(unique(absk$Plotnumber),length(seq(from=min(absk$Year),to=max(absk$Year),by=0.5))),
                   Year_eq=rep(seq(from=min(absk$Year),to=max(absk$Year),by=0.5),871))
newdat<-newdat[order(Plotnumber,Year_eq)] %>% 
  .[,PLOT_Year:=paste(Plotnumber,Year_eq,sep="_")]

absk[,PLOT_Year:=paste(Plotnumber,Year,sep="_")]
newdat[,":="(Year=absk[match(newdat$PLOT_Year,PLOT_Year),Year],
             AGBM_resid=absk[match(newdat$PLOT_Year,PLOT_Year),AGBM_resid],
             AGBM=absk[match(newdat$PLOT_Year,PLOT_Year),AGBM])]
acf_vecM<-newdat[order(Year_eq)][,.(AGBM_resid,AGBM,Year_eq)]
acf(acf_vecM[,.(AGBM_resid)],na.action = na.pass)#Use na.pass
acf(acf_vecM[,.(AGBM)],na.action = na.pass)

#AGB
ma<-lmer(AGB~logSA+Y+lograre_nbsp+logSI+(logSA:Y)+(logSA:lograre_nbsp)+(Y:lograre_nbsp)+(1|Plotnumber),weights=wi,absk)
absk[,AGB_pred:=predict(ma)]

pairs(absk[,.(AGB_pred,Year)])
absk[,AGB_resid:=resid(ma,type="pearson")]
acf_vec<-absk[order(Year),][,.(AGB_resid,AGB,Year)]
acf(acf_vec[,AGB_resid])
acf(acf_vec[,AGB])

newdat<-data.table(Plotnumber=rep(unique(absk$Plotnumber),length(seq(from=min(absk$Year),to=max(absk$Year),by=0.5))),
                   Year_eq=rep(seq(from=min(absk$Year),to=max(absk$Year),by=0.5),871))
newdat<-newdat[order(Plotnumber,Year_eq)] %>% 
  .[,PLOT_Year:=paste(Plotnumber,Year_eq,sep="_")]

absk[,PLOT_Year:=paste(Plotnumber,Year,sep="_")]
newdat[,":="(Year=absk[match(newdat$PLOT_Year,PLOT_Year),Year],
             AGBM_resid=absk[match(newdat$PLOT_Year,PLOT_Year),AGBM_resid],
             AGBM=absk[match(newdat$PLOT_Year,PLOT_Year),AGBM])]
acf_vecM<-newdat[order(Year_eq)][,.(AGBM_resid,AGBM,Year_eq)]
acf(acf_vecM[,.(AGBM_resid)],na.action = na.pass)#Use na.pass
acf(acf_vecM[,.(AGBM)],na.action = na.pass)
