absk<-fread("Hisano_et_al_Data_Submitted_to_EcolLett.csv")
absk[,":="(logSI1=log(SI1))] %>% 
  .[,":="(Long=LONG+rnorm(nrow(absk),0,0.001),
          Lat=LAT+rnorm(nrow(absk),0,0.001),
          logSI=logSI1+rnorm(nrow(absk),0,0.000000000000001))] %>% 
  .[,":="(logSI=scale(logSI,scale=F),logBio_sc=scale(log(total_Bio1)))] %>% 
  .[,":="(logSA_sc=scale(log(SA1)),
          invlogSA_sc=scale(1/log(SA1)),
          Y_sc=scale(Year),
          Sprare_nbsp_sc=scale(Sprare_nbsp1),lograre_nbsp_sc=scale(lograre_nbsp1),
          Spstd_nbsp_sc=scale(Spstd_nbsp1),logstd_nbsp_sc=scale(logstd_nbsp1),
          Spnbsp_sc=scale(SpS),lognbsp_sc=scale(log(SpS)),
          SpShann_sc=scale(SpShann1),logShann_sc=scale(log(SpShann1+1)),
          SpSimp_sc=scale(SpSimp1),logSimp_sc=scale(log(SpSimp1+1)),
          SpST_sc=scale(SpST1),logST_sc=scale(log(SpST1)),sqrtST_sc=scale(sqrt(SpST1)),quadST_sc=scale(SpST1^2),
          logSI_sc=scale(logSI))] %>% 
  .[,":="(ATA1_10=ATA1*10,
          CO21_sc=scale(CO2),ATA1_sc=scale(ATA),CMI1_sc=scale(ACMIA))]

#NOTE: in PiecewiseSEM, use lme instead of lmer to facilitate analysis (lme is much faster)

## Growth
#Initial model
SEM_list.G <- psem(
  lme(AGBGI~logSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logSA_sc:Y_sc+logSA_sc:lograre_nbsp_sc+Y_sc:lograre_nbsp_sc+
        logSA_sc:Y_sc:lograre_nbsp_sc,
      random=~1|Plotnumber,weights=~1/wi,absk),
  lme(lograre_nbsp_sc~logSI_sc+logSA_sc+Y_sc+logSA_sc:Y_sc,random=~1|Plotnumber,weights=~1/wi,absk)
)

AIC(SEM_list.G)

#### Criteria for the model selection (reduced model) ###
#1. Remove insignificant coefficnents;
#2. Based on AIC, remove three-way int on AGB; two-way int on Div 
#3. But priotirizsed Y:Div because want to see if coef consistent after accounting for Y-->Div effect (tempo change in Div)

#Reduced model
SEM_list.G4 <- psem(
  lme(AGBGI~logSA_sc
      +Y_sc
      +lograre_nbsp_sc
      +logSI_sc
      +logSA_sc:Y_sc
      #+logSA_sc:lograre_nbsp_sc
      +Y_sc:lograre_nbsp_sc
      #+logSA_sc:Y_sc:lograre_nbsp_sc
      ,random=~1|Plotnumber,weights=~1/wi,absk),
  lme(lograre_nbsp_sc~logSI_sc+logSA_sc+Y_sc
      #+logSA_sc:Y_sc
      ,random=~1|Plotnumber,weights=~1/wi,absk)
)

AIC(SEM_list.G4)
summary(SEM_list.G4)
SEM_list.G4_summary<-summary(SEM_list.G4)$coef[]
rsquared(SEM_list.G4)
r.squaredGLMM(lmer(lograre_nbsp_sc~logSI_sc+logSA_sc+Y_sc+(1|Plotnumber),weights=wi,absk))

## Mort
#Initial model
SEM_list.M <- psem(
  lme(AGBM~logSA_sc+Y_sc+Sprare_nbsp_sc+logSI_sc+logSA_sc:Y_sc+logSA_sc:Sprare_nbsp_sc+Y_sc:Sprare_nbsp_sc+
        logSA_sc:Y_sc:Sprare_nbsp_sc,
      random=~1|Plotnumber,weights=~1/wi,absk),
  lme(Sprare_nbsp_sc~logSI_sc+logSA_sc+Y_sc+logSA_sc:Y_sc,random=~1|Plotnumber,weights=~1/wi,absk)
)

AIC(SEM_list.M)

#Reduced model (removed insignif, or used dredge)
SEM_list.M4 <- psem(
  lme(AGBM~logSA_sc
      +Y_sc
      +Sprare_nbsp_sc
      +logSI_sc
      #+logSA_sc:Y_sc
      #+logSA_sc:Sprare_nbsp_sc
      +Y_sc:Sprare_nbsp_sc
      #+logSA_sc:Y_sc:Sprare_nbsp_sc
      ,random=~1|Plotnumber,weights=~1/wi,absk),
  lme(Sprare_nbsp_sc~logSI_sc+logSA_sc+Y_sc
      #+logSA_sc:Y_sc
      ,random=~1|Plotnumber,weights=~1/wi,absk)
)

AIC(SEM_list.M4)
summary(SEM_list.M4)
SEM_list.M4_summary<-summary(SEM_list.M4)$coef
rsquared(SEM_list.M4)
r.squaredGLMM(lmer(Sprare_nbsp_sc~logSI_sc+logSA_sc+Y_sc+(1|Plotnumber),weights=wi,absk))

## NBC
#Initial model
SEM_list.N <- psem(
  lme(AGB~logSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+logSA_sc:Y_sc+logSA_sc:lograre_nbsp_sc+Y_sc:lograre_nbsp_sc+
        logSA_sc:Y_sc:lograre_nbsp_sc,
      random=~1|Plotnumber,weights=~1/wi,absk),
  lme(lograre_nbsp_sc~logSI_sc+logSA_sc+Y_sc+logSA_sc:Y_sc,random=~1|Plotnumber,weights=~1/wi,absk)
)

AIC(SEM_list.N)

#Reduced model (removed insignif, or used dredge)
SEM_list.N4 <- psem(
  lme(AGB~logSA_sc
      +Y_sc
      +lograre_nbsp_sc
      +logSI_sc
      +logSA_sc:Y_sc
      #+logSA_sc:lograre_nbsp_sc
      +Y_sc:lograre_nbsp_sc
      #+logSA_sc:Y_sc:lograre_nbsp_sc
      ,random=~1|Plotnumber,weights=~1/wi,absk),
  lme(lograre_nbsp_sc~logSI_sc+logSA_sc+Y_sc
      #+logSA_sc:Y_sc
      ,random=~1|Plotnumber,weights=~1/wi,absk)
)

AIC(SEM_list.N4)
summary(SEM_list.N4)
SEM_list.N4_summary<-summary(SEM_list.N4)$coef
rsquared(SEM_list.N4)
r.squaredGLMM(lmer(lograre_nbsp_sc~logSI_sc+logSA_sc+Y_sc+(1|Plotnumber),weights=wi,absk))

###### Temporal change in Richness (Year --> RareS) #####
ci.fun<-function(mod,coeff){
  frame<-mod@frame
  x<-frame[,coeff]
  xsim<-seq(min(x),max(x),((max(x)-min(x))/10000))
  
  sy<-sqrt(sum((mean(resid(mod))-(resid(mod)))^2)/(nrow(frame)-nrow(summary(mod)$coefficients)))
  sx<-sqrt((1/length(x))+(((xsim-mean(x))^2)/((length(x)-1)*var(x))))
  t<-qt(0.975,length(x))
  
  mean<-summary(mod)$coefficients["(Intercept)","Estimate"]+
    summary(mod)$coefficients[coeff,"Estimate"]*xsim
  ci.up<-mean+(t*sy*sx)
  ci.low<-mean-(t*sy*sx)
  
  out<-data.frame(xsim,mean,ci.up,ci.low)
  return(out)
}##run to create data.frame to store booted CI's

## Temporal change in Sprare_nbsp1
AIC(lmer(Sprare_nbsp1~logSA+Y+(1|Plotnumber),weight=PS,absk))
AIC(lmer(Sprare_nbsp1~logSA+Y+logSA:Y+(1|Plotnumber),weight=PS,absk))
AIC(lmer(Sprare_nbsp1~logSA+Y+logSI+(1|Plotnumber),weight=PS,absk))
AIC(lmer(Sprare_nbsp1~logSA+Y+logSA:Y+logSI+(1|Plotnumber),weight=PS,absk))#

mrare<-lmer(Sprare_nbsp1~logSI+logSA+Y+logSA:Y+(1|Plotnumber),weight=PS,absk)
summary(mrare)$co

coefmean<-summary(mrare)$coefficients[ , 1]
coef_Int<-coefmean[1]
coef_Y<-coefmean["Y"]

absk$Sprare_nbsp1_Y<-resid(mrare)+coef_Int+coef_Y*absk$Y
Sprare_nbsp1_Y<-lmer(Sprare_nbsp1_Y~Y+(1|Plotnumber),weights=PS,data=absk)

allmrare<-ci.fun(mrare,"Y")
allmrare$Year<-seq(min(absk$Year),max(absk$Year),
                   ((max(absk$Year)-min(absk$Year))/10000))

Ra<-ggplot()+
  stat_summary_bin(aes(x=(absk$Year), y=absk$Sprare_nbsp1_Y),
                   fun.data = "mean_cl_boot",colour = "dodgerblue2",
                   shape=1, bins=300) +
  theme_bw() +
  theme(axis.line.x = element_line(),axis.line.y = element_line(),
        axis.title.y = element_text(size = 16),
        axis.text.y = element_text(size = 14),
        axis.title.x = element_text(size = 16),
        axis.text.x = element_text(size = 14),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank()) 
Ra<-Ra+ ylab(expression(paste("Raarefied richness")))
Ra<-Ra+ xlab(expression(paste("Calendar year")))      
Ra<-Ra+ annotate("text", x = 1990, y =3.7, label = "Slope == -0.008~yr^{-1}", parse=TRUE, size=4) 
Ra<-Ra+ annotate("text", x = 1990, y =3.4, label = "Year: italic(P) < 0.001", parse=TRUE, size=4) 
Ra<-Ra+ 
  geom_line(aes(x=(allmrare$Year),y=allmrare$mean),colour="black")+
  geom_ribbon(aes(x=(allmrare$Year),ymin=allmrare$ci.low,ymax=allmrare$ci.up), fill="grey", alpha="0.5")+
  scale_y_continuous(limits=c(1,4),breaks=c(1,2,3,4,5))
Ra

summary(mrare)$coefficients
anova(mrare)

#Save
f1 <- ggplotGrob(Ra)

tiff("Temporal_changes_in_Sprare_nbsp1_2544_Based_on_SEM.tiff",
     width=1800,height=1400,res=300,compression="lzw")
grid.draw(f1)
dev.off()
