library(nlme);library(lmeresampler)
library(lme4);library(lmerTest)
library(boot);library(Rfit)
library(MuMIn);library(ggplot2)
library(grid);library(gridExtra)
library(gtable);library(plyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(Hmisc)
library(spdep);library(SoDA);library(ape)
library(spaMM)

absk<-fread("Hisano_et_al_Data_Submitted_to_EcolLett.csv")
absk[,":="(logSI1=log(SI1))] %>% 
  .[,":="(Long=LONG+rnorm(nrow(absk),0,0.001),
          Lat=LAT+rnorm(nrow(absk),0,0.001),
          logSI=logSI1+rnorm(nrow(absk),0,0.000000000000001))] %>% 
  .[,":="(logSI=scale(logSI,scale=F),logBio_sc=scale(log(total_Bio1)))] %>% 
  .[,":="(logSA_sc=scale(log(SA1)),
          invlogSA_sc=scale(1/log(SA1)),
          Y_sc=scale(Year),
          Sprare_nbsp_sc=scale(Sprare_nbsp1),lograre_nbsp_sc=scale(lograre_nbsp1),
          Spstd_nbsp_sc=scale(Spstd_nbsp1),logstd_nbsp_sc=scale(logstd_nbsp1),
          Spnbsp_sc=scale(SpS),lognbsp_sc=scale(log(SpS)),
          SpShann_sc=scale(SpShann1),logShann_sc=scale(log(SpShann1+1)),
          SpSimp_sc=scale(SpSimp1),logSimp_sc=scale(log(SpSimp1+1)),
          SpST_sc=scale(SpST1),logST_sc=scale(log(SpST1)),sqrtST_sc=scale(sqrt(SpST1)),quadST_sc=scale(SpST1^2),
          logSI_sc=scale(logSI))] %>% 
  .[,":="(ATA1_10=ATA1*10,
          CO21_sc=scale(CO2),ATA1_sc=scale(ATA),CMI1_sc=scale(ACMIA))]

### Fig.2a ###
ci.fun<-function(mod,mod_summary,coef){
  frame<-data.frame(absk)
  x<-frame[,coef]
  xsim<-seq(min(x),max(x),((max(x)-min(x))/10000))
  
  sy<-sqrt(sum((mean(resid(mod))-(resid(mod)))^2)/(nrow(frame)-nrow(mod_summary)))
  sx<-sqrt((1/length(x))+(((xsim-mean(x))^2)/((length(x)-1)*var(x))))
  t<-qt(0.975,length(x))
  
  mean<-mod_summary["(Intercept)","Estimate"]+
    mod_summary[coef,"Estimate"]*xsim
  ci.up<-mean+(t*sy*sx)
  ci.low<-mean-(t*sy*sx)
  
  out<-data.frame(xsim,mean,ci.up,ci.low)
  return(out)
}

## Year models ##
load("fitme_Year_Grow_HossfeldSI.R")
mbrare_nbsp_summary<-summary(mbrare_nbsp)$beta

load("fitme_Year_Mort_HossfeldSI.R")
mcrare_nbsp_summary<-summary(mcrare_nbsp)$beta

load("fitme_Year_NBC_HossfeldSI.R")
marare_nbsp_summary<-summary(marare_nbsp)$beta

mbrare_nbsp_Pval<-summary(mbrare_nbsp)$beta
Pval<-2*pt(-abs(mbrare_nbsp_Pval[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mbrare_nbsp_Pval<-as.data.frame(mbrare_nbsp_Pval)
mbrare_nbsp_Pval$Pval<-Pval[[1]]

mcrare_nbsp_Pval<-summary(mcrare_nbsp)$beta
Pval<-2*pt(-abs(mcrare_nbsp_Pval[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
mcrare_nbsp_Pval<-as.data.frame(mcrare_nbsp_Pval)
mcrare_nbsp_Pval$Pval<-Pval[[1]]

marare_nbsp_Pval<-summary(marare_nbsp)$beta
Pval<-2*pt(-abs(marare_nbsp_Pval[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
marare_nbsp_Pval<-as.data.frame(marare_nbsp_Pval)
marare_nbsp_Pval$Pval<-Pval[[1]]

#Fig.2a
## Growth
coefmean<-mbrare_nbsp_summary[, 1]
SE<-mbrare_nbsp_summary[, 2]

coef_Int<-coefmean[1]
coef_lograre_nbsp<-coefmean["lograre_nbsp"]
absk$AGBGI_lograre_nbsp<-resid(mbrare_nbsp)+coef_Int+coef_lograre_nbsp*absk$lograre_nbsp

allrare_nbspmb<-ci.fun(mbrare_nbsp,mbrare_nbsp_summary,"lograre_nbsp")
allrare_nbspmb$lograre_nbsp1<-seq(min(absk$lograre_nbsp1),max(absk$lograre_nbsp1),
                                  ((max(absk$lograre_nbsp1)-min(absk$lograre_nbsp1))/10000))##switch to actual rare_nbsp("lograre_nbsp1") as opposed to scaled

absk[,index:=cut(Sprare_nbsp1,150)]
absk[,x_for_gg:=mean(exp(lograre_nbsp1)),by=index]
absk[,Plot_Bg_col:=sum(PS),by=index]
absk[,arb:=Plot_Bg_col/max(Plot_Bg_col)]

G2.1<-ggplot()+
  stat_summary(aes(x=absk$x_for_gg, y=absk$AGBGI_lograre_nbsp, color=absk$Plot_Bg_col),
               fun.data = "mean_cl_boot",
               shape=1) +
  theme_bw() +
  theme(axis.line.x = element_blank(),axis.ticks.x=element_blank(),axis.text.x=element_blank(),axis.line.y = element_line(),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"),
        panel.border = element_blank(),
        panel.background = element_blank(),
        legend.position=c(0.3,0.9))+
  guides(color=guide_colourbar(direction="horizontal",
                               title.position = "top",
                               title="Area sampled (ha)"))+##controlling legend placement and title
  scale_color_gradientn(colours=c("turquoise3","maroon1","darkgreen"),
                        values=c(0,0.4,1))##Change colours here
G2.1<-G2.1+ ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))
G2.1<-G2.1+ xlab(expression(paste("")))
G2.1<-G2.1+ annotate("text", x = 2.9, y =1, label = "Slope == 0.29~Mg~ha^{-1}~yr^{-1}~ln(italic(S))^{-1}", parse=TRUE, size=4) 
G2.1<-G2.1+ annotate("text", x = 2.9, y =0.5, label = "ln(italic(S)):~italic(P) < 0.001~(italic(t)=='4.48')", parse=TRUE, size=4)
G2.1<-G2.1+ 
  geom_ribbon(aes(x=exp(allrare_nbspmb$lograre_nbsp1),ymin=allrare_nbspmb$ci.low,ymax=allrare_nbspmb$ci.up), fill="navy", alpha=0.3)+
  geom_line(aes(x=exp(allrare_nbspmb$lograre_nbsp1),y=allrare_nbspmb$mean),colour="black")+
  scale_y_continuous(limits=c(-0.5,4),breaks=c(0,1,2,3,4))
G2.1
f1 <- ggplotGrob(G2.1)#Run this here now

round(coefmean["lograre_nbsp"],2)

mbrare_nbsp_Pval

## Mortality
coefmean<-mcrare_nbsp_summary[, 1]
SE<-mcrare_nbsp_summary[, 2]

coef_Int<-coefmean[1]
coef_Sprare_nbsp<-coefmean["Sprare_nbsp"]
absk$AGBGI_Sprare_nbsp<-resid(mcrare_nbsp)+coef_Int+coef_Sprare_nbsp*absk$Sprare_nbsp

allrare_nbspmc<-ci.fun(mcrare_nbsp,mcrare_nbsp_summary,"Sprare_nbsp")
allrare_nbspmc$Sprare_nbsp1<-seq(min(absk$Sprare_nbsp1),max(absk$Sprare_nbsp1),
                                 ((max(absk$Sprare_nbsp1)-min(absk$Sprare_nbsp1))/10000))##switch to actual rare_nbsp("Sprare_nbsp1") as opposed to scaled

absk[,index:=cut(Sprare_nbsp1,150)]
absk[,x_for_gg:=mean(Sprare_nbsp1),by=index]
absk[,Plot_Bg_col:=sum(PS),by=index]
absk[,arb:=Plot_Bg_col/max(Plot_Bg_col)]

M2.1<-ggplot()+
  stat_summary(aes(x=absk$x_for_gg, y=absk$AGBGI_Sprare_nbsp, color=absk$Plot_Bg_col),
               fun.data = "mean_cl_boot",
               shape=1) +
  theme_bw() +
  theme(axis.line.x = element_blank(),axis.ticks.x=element_blank(),axis.text.x=element_blank(),axis.line.y = element_line(),
        panel.grid.major = element_line(colour = "white"),
        panel.grid.minor = element_line(colour = "white"),
        panel.border = element_blank(),
        panel.background = element_blank(),
        legend.position=c(0.3,0.9))+
  guides(color=FALSE)+##controlling legend placement and title
  scale_color_gradientn(colours=c("turquoise3","maroon1","darkgreen"),
                        values=c(0,0.4,1))##Change colours here
M2.1<-M2.1+ ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))
M2.1<-M2.1+ xlab(expression(paste("")))
M2.1<-M2.1+ annotate("text", x = 2.9, y =3.5, label = "Slope == -0.17~Mg~ha^{-1}~yr^{-1}~italic(S)^{-1}", parse=TRUE, size=4) 
M2.1<-M2.1+ annotate("text", x = 2.9, y =3, label = "italic(S):~italic(P) < 0.001~(italic(t)=='-3.62')", parse=TRUE, size=4)
M2.1<-M2.1+ 
  geom_ribbon(aes(x=(allrare_nbspmc$Sprare_nbsp1),ymin=allrare_nbspmc$ci.low,ymax=allrare_nbspmc$ci.up), fill="navy", alpha=0.3)+
  geom_line(aes(x=(allrare_nbspmc$Sprare_nbsp1),y=allrare_nbspmc$mean),colour="black")+
  scale_y_continuous(limits=c(-0.5,4),breaks=c(0,1,2,3,4))
M2.1

round(coefmean["Sprare_nbsp"],2)

mcrare_nbsp_Pval

## Net biomass change
coefmean<-marare_nbsp_summary[, 1]
SE<-marare_nbsp_summary[, 2]

coef_Int<-coefmean[1]
coef_lograre_nbsp<-coefmean["lograre_nbsp"]
absk$AGBGI_lograre_nbsp<-resid(marare_nbsp)+coef_Int+coef_lograre_nbsp*absk$lograre_nbsp

allrare_nbspma<-ci.fun(marare_nbsp,marare_nbsp_summary,"lograre_nbsp")
allrare_nbspma$lograre_nbsp1<-seq(min(absk$lograre_nbsp1),max(absk$lograre_nbsp1),
                                  ((max(absk$lograre_nbsp1)-min(absk$lograre_nbsp1))/10000))##switch to actual rare_nbsp("lograre_nbsp1") as opposed to scaled

absk[,index:=cut(Sprare_nbsp1,150)]
absk[,x_for_gg:=mean(exp(lograre_nbsp1)),by=index]
absk[,Plot_Bg_col:=sum(PS),by=index]
absk[,arb:=Plot_Bg_col/max(Plot_Bg_col)]

NBC2.1<-ggplot()+
  stat_summary(aes(x=absk$x_for_gg, y=absk$AGBGI_lograre_nbsp, color=absk$Plot_Bg_col),
               fun.data = "mean_cl_boot",
               shape=1) +
  theme_bw() +
  theme(axis.line.x = element_line(),axis.line.y = element_line(),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.border = element_blank(),
        panel.background = element_blank())+
  guides(color=FALSE)+##controlling legend placement and title
  scale_color_gradientn(colours=c("turquoise3","maroon1","darkgreen"),
                        #"#56B4E9","#D55E00","darkgreen"),
                        values=c(0,0.4,1))##Change colours here
NBC2.1<-NBC2.1+ ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))
NBC2.1<-NBC2.1+ xlab(expression(paste("Rarefied richness")))
NBC2.1<-NBC2.1+ annotate("text", x = 2.9, y =3.5, label = "Slope == 0.59~Mg~ha^{-1}~yr^{-1}~ln(italic(S))^{-1}", parse=TRUE, size=4) 
NBC2.1<-NBC2.1+ annotate("text", x = 2.9, y =3, label = "ln(italic(S)):~italic(P) < 0.001~(italic(t)=='4.87')", parse=TRUE, size=4)
NBC2.1<-NBC2.1+ 
  geom_ribbon(aes(x=exp(allrare_nbspma$lograre_nbsp1),ymin=allrare_nbspma$ci.low,ymax=allrare_nbspma$ci.up), fill="navy", alpha=0.3)+
  geom_line(aes(x=exp(allrare_nbspma$lograre_nbsp1),y=allrare_nbspma$mean),colour="black")+
  scale_y_continuous(limits=c(-0.5,4),breaks=c(0,1,2,3,4))
NBC2.1

round(coefmean["lograre_nbsp"],2)

marare_nbsp_Pval

### Fig.2b ###
#for colour change: PS(ha)/cat_div/Year (cat_div = categorical diversity)
Rare<-seq(min(absk$Sprare_nbsp1),max(absk$Sprare_nbsp1),length=5)

absk[Sprare_nbsp1==1,cat_div:="Rare1"]##single species stands
absk[Sprare_nbsp1>1&Sprare_nbsp1<=Rare[2],cat_div:="Rare2"]
absk[Sprare_nbsp1>Rare[2]&Sprare_nbsp1<=Rare[3],cat_div:="Rare3"]
absk[Sprare_nbsp1>Rare[3]&Sprare_nbsp1<=Rare[4],cat_div:="Rare4"]
absk[Sprare_nbsp1>Rare[4],cat_div:="Rare5"]
absk[,cat_div:=factor(cat_div)]
table(absk$cat_div)

absk[,index:=cut(Year,15)]
absk[,Year3:=mean(Year),by=index]
absk$Plot_Bg_col_2<-ave(absk$PS,absk$cat_div,absk$Year3,FUN=sum)

########## Grow ##########
coefmean<-mbrare_nbsp_summary[, 1]
SE<-mbrare_nbsp_summary[, 2]
coef_rare<-function(x){
  rare=x
  data.table(mean=coefmean["(Intercept)"]+
               (coefmean["Y"]*(seq(min(absk$Y),max(absk$Y),length=600)))+
               (coefmean["lograre_nbsp"]*rare)+
               (coefmean["Y:lograre_nbsp"]*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             up=coefmean["(Intercept)"]+SE["(Intercept)"]+
               ((coefmean["Y"]+SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["lograre_nbsp"]+SE["lograre_nbsp"])*rare)+
               ((coefmean["Y:lograre_nbsp"]+SE["Y:lograre_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             low=coefmean["(Intercept)"]-SE["(Intercept)"]+
               ((coefmean["Y"]-SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["lograre_nbsp"]-SE["lograre_nbsp"])*rare)+
               ((coefmean["Y:lograre_nbsp"]-SE["Y:lograre_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             Y=seq(min(absk$Y),max(absk$Y),length=600),
             Year=seq(min(absk$Y),max(absk$Y),length=600)+mean(absk$Year),
             Rare_Spec=rare)
}

summary(absk$lograre_nbsp)
to_graph<-adply(round(c(seq(min(absk$lograre_nbsp),max(absk$lograre_nbsp),length=5),0),3),
                .margins=1,.fun=function(x)coef_rare(x))
to_graph$Rare_Spec<-as.factor(to_graph$Rare_Spec)
to_graph$cat_div<-factor(to_graph$Rare_Spec,labels=c("Rare1","Rare2","mean",
                                                     "Rare3","Rare4","Rare5"))
to_graph<-data.table(to_graph)
year_window=to_graph[,c(seq(min(Year),max(Year),by=3),max(Year)+0.5)]
year_window2=data.table::shift(year_window,1)
year_dt<-data.table(Year=year_window,prevY=year_window2)
year_dt<-year_dt[-1]
to_graph<-ddply(year_dt,1,function(x){
  to_graph[Year>=x[,"prevY"]&Year<x[,"Year"],":="(Window=x[,"Year"],
                                                  prevWindow=x[,"prevY"])]
})
to_graph<-unique(to_graph)

to_graph<-data.table(to_graph)
to_graph[,index:=paste(Window,Rare_Spec)]
to_graph[,prevY:=data.table::shift(Year),by=.(Rare_Spec)]

to_graph[is.na(prevY)==TRUE,prevY:=Year-1]
to_graph[is.na(Window)==TRUE,Window:=2005.5]
to_hmm<-to_graph[cat_div!="mean"]

year_dt<-data.table(cat_div=rep(unique(to_graph[,cat_div]),each=nrow(year_dt)),
                    Year=rep(year_dt[,Year],length(unique(to_graph[,cat_div]))),
                    prevY=rep(year_dt[,prevY],length(unique(to_graph[,cat_div]))))
year_dt<-year_dt[cat_div!="mean"]

year_dt[,weights:=apply(year_dt,1,function(x,into=absk){
  
  inside<-subset(into,Year<x["Year"]&Year>=x["prevY"]&cat_div==x["cat_div"])
  return(sum(inside[,PS]))
})]
setnames(year_dt,c("cat_div","Window","prevY","Weights"))
year_dt[,prevY:=NULL]
year_dt<-unique(year_dt)
to_hmm<-merge(to_hmm,year_dt,by=c("cat_div","Window"))

to_hmm[,index:=paste(Window,cat_div,sep="_")]
breaker=unique(to_hmm[,paste(Window,cat_div,sep="_")])
to_ribbon<-melt(to_hmm,
                measure.vars=c("Year","prevY"),
                id.vars=c("mean","low","up","Rare_Spec","Weights","index","Window"))
to_ribbon[,intense:=Weights/max(Weights)]
#to_ribbon[,intense:=intense/1.5]
#to_ribbon[intense==0,intense:=0.1]

#Graph Gro
Gro<-ggplot(to_graph,aes(x=Year,y=mean,col=Rare_Spec))+
  theme_classic()
for(i in 1:length(breaker)){
  Gro=Gro+geom_ribbon(data=to_ribbon[index==breaker[i],],
                      aes(x=value,ymin=low,ymax=up,group=Rare_Spec),
                      alpha=unique(to_ribbon[index==breaker[i],intense]),fill="#000d40",
                      inherit.aes = FALSE,col=NA)
}
Gro<-Gro+ geom_line(size=1)+
  geom_point(data=to_ribbon,aes(alpha=Weights,x=value,y=mean),size=1.1,col=NA,show.legend=FALSE)+
  scale_colour_manual(values=c("mediumpurple","cyan1","black","green1","darkorange1","deeppink"),name="",
                      labels=c("-0.7441900"="1.00","-0.3305275"="2.06","0.0831350000000001"="3.12",
                               "0.4967975"="4.17","0.91046"="5.23","0"="Mean (2.26)"),
                      guide=guide_legend(override.aes = list(colour =NA,fill=NA)))+
  xlab("")+
  ylab(expression(paste("Growth (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
Gro<-Gro+scale_alpha_continuous(name="Area sampled (ha)",breaks=c(0,10,20,29),
                                labels=c("0","10","20","30"),
                                guide=guide_legend(override.aes = list(colour =NA,fill=NA)))
Gro<-Gro + annotate("text", x = 1985, y =4.0, label = "Year:~italic(P) == 0.009~(italic(t)==-2.63)", parse=TRUE, size=4)
Gro<-Gro + annotate("text", x = 1985, y =3.8, label = "Year%*%ln(italic(S)):~italic(P) < 0.001~(italic(t)==5.92)", parse=TRUE, size=4)+
  scale_y_continuous(breaks=c(2,3,4))
Gro

mbrare_nbsp_Pval

########## Mort ##########
coefmean<-mcrare_nbsp_summary[, 1]
SE<-mcrare_nbsp_summary[, 2]
coef_rare<-function(x){
  rare=x
  data.table(mean=coefmean["(Intercept)"]+
               (coefmean["Y"]*(seq(min(absk$Y),max(absk$Y),length=600)))+
               (coefmean["Sprare_nbsp"]*rare)+
               (coefmean["Y:Sprare_nbsp"]*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             up=coefmean["(Intercept)"]+SE["(Intercept)"]+
               ((coefmean["Y"]+SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]+SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]+SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             low=coefmean["(Intercept)"]-SE["(Intercept)"]+
               ((coefmean["Y"]-SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]-SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]-SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             Y=seq(min(absk$Y),max(absk$Y),length=600),
             Year=seq(min(absk$Y),max(absk$Y),length=600)+mean(absk$Year),
             Rare_Spec=rare)
}


summary(absk$Sprare_nbsp)
to_graph<-adply(round(c(seq(min(absk$Sprare_nbsp),max(absk$Sprare_nbsp),length=5),0),3),
                .margins=1,.fun=function(x)coef_rare(x))
to_graph$Rare_Spec<-as.factor(to_graph$Rare_Spec)
to_graph$cat_div<-factor(to_graph$Rare_Spec,labels=c("Rare1","Rare2","mean",
                                                     "Rare3","Rare4","Rare5"))
to_graph<-data.table(to_graph)
year_window=to_graph[,c(seq(min(Year),max(Year),by=3),max(Year)+0.5)]
year_window2=data.table::shift(year_window,1)
year_dt<-data.table(Year=year_window,prevY=year_window2)
year_dt<-year_dt[-1]
to_graph<-ddply(year_dt,1,function(x){
  to_graph[Year>=x[,"prevY"]&Year<x[,"Year"],":="(Window=x[,"Year"],
                                                  prevWindow=x[,"prevY"])]
})
to_graph<-unique(to_graph)

to_graph<-data.table(to_graph)
to_graph[,index:=paste(Window,Rare_Spec)]
to_graph[,prevY:=data.table::shift(Year),by=.(Rare_Spec)]

to_graph[is.na(prevY)==TRUE,prevY:=Year-1]
to_graph[is.na(Window)==TRUE,Window:=2005.5]
to_hmm<-to_graph[cat_div!="mean"]

year_dt<-data.table(cat_div=rep(unique(to_graph[,cat_div]),each=nrow(year_dt)),
                    Year=rep(year_dt[,Year],length(unique(to_graph[,cat_div]))),
                    prevY=rep(year_dt[,prevY],length(unique(to_graph[,cat_div]))))
year_dt<-year_dt[cat_div!="mean"]

year_dt[,weights:=apply(year_dt,1,function(x,into=absk){
  
  inside<-subset(into,Year<x["Year"]&Year>=x["prevY"]&cat_div==x["cat_div"])
  return(sum(inside[,PS]))
})]
setnames(year_dt,c("cat_div","Window","prevY","Weights"))
year_dt[,prevY:=NULL]
year_dt<-unique(year_dt)
to_hmm<-merge(to_hmm,year_dt,by=c("cat_div","Window"))

to_hmm[,index:=paste(Window,cat_div,sep="_")]
breaker=unique(to_hmm[,paste(Window,cat_div,sep="_")])
to_ribbon<-melt(to_hmm,
                measure.vars=c("Year","prevY"),
                id.vars=c("mean","low","up","Rare_Spec","Weights","index","Window"))
to_ribbon[,intense:=Weights/max(Weights)]

round(c(seq(min(absk$Sprare_nbsp1),max(absk$Sprare_nbsp1),length=5),mean(absk$Sprare_nbsp1)),2)

#Graph Mo
Mo<-ggplot(to_graph,aes(x=Year,y=mean,col=Rare_Spec))+
  theme_classic()
for(i in 1:length(breaker)){
  Mo=Mo+geom_ribbon(data=to_ribbon[index==breaker[i],],
                    aes(x=value,ymin=low,ymax=up,group=Rare_Spec),
                    alpha=unique(to_ribbon[index==breaker[i],intense]),fill="#000d40",
                    inherit.aes = FALSE,col=NA)
}
Mo<-Mo+ geom_line(size=1,linetype="solid")+
  geom_point(data=to_ribbon,aes(alpha=Weights,x=value,y=mean),size=1.1,col=NA)+
  scale_colour_manual(values=c("mediumpurple","cyan1","black","green1","darkorange1","deeppink"),
                      name="Rarefied richness",
                      labels=c("-1.299"="1.00","-0.222"="2.08","0.856"="3.15","1.933"="4.23",
                               "3.01"="5.31","0"="Mean (2.30)"))+
  xlab("")+
  ylab(expression(paste("Mortality (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        #legend.position=c(0.75,1),
        legend.title.align  = 0)
#,legend.background = element_rect(fill = "#87CEEB30",colour = NA))

Mo<-Mo+scale_alpha_continuous(name="Area sampled (ha)",breaks=c(0,10,20,29),
                              labels=c("0","10","20","30"),
                              guide=guide_legend(override.aes = list(colour ="#000d40",fill="#000d40",
                                                                     shape=15,size=5)))+
  scale_y_continuous(breaks=c(1,2,3))
#Mo<-Mo+coord_cartesian(ylim = c(0,6),expand = FALSE)+ #to cut predicted negative values
Mo<-Mo + annotate("text", x = 1985, y =2.9, label = "Year:~italic(P) < 0.001~(italic(t)==5.96)", parse=TRUE, size=4)
Mo<-Mo + annotate("text", x = 1985, y =2.7, label = "Year%*%italic(S):~italic(P) == 0.027~(italic(t)==-2.21)", parse=TRUE, size=4)
Mo

mcrare_nbsp_Pval

########## NBC ##########
coefmean<-marare_nbsp_summary[, 1]
SE<-marare_nbsp_summary[, 2]
coef_rare<-function(x){
  rare=x
  data.table(mean=coefmean["(Intercept)"]+
               (coefmean["Y"]*(seq(min(absk$Y),max(absk$Y),length=600)))+
               (coefmean["lograre_nbsp"]*rare)+
               (coefmean["Y:lograre_nbsp"]*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             up=coefmean["(Intercept)"]+SE["(Intercept)"]+
               ((coefmean["Y"]+SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["lograre_nbsp"]+SE["lograre_nbsp"])*rare)+
               ((coefmean["Y:lograre_nbsp"]+SE["Y:lograre_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             low=coefmean["(Intercept)"]-SE["(Intercept)"]+
               ((coefmean["Y"]-SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["lograre_nbsp"]-SE["lograre_nbsp"])*rare)+
               ((coefmean["Y:lograre_nbsp"]-SE["Y:lograre_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             Y=seq(min(absk$Y),max(absk$Y),length=600),
             Year=seq(min(absk$Y),max(absk$Y),length=600)+mean(absk$Year),
             Rare_Spec=rare)
}

to_graph<-adply(round(c(seq(min(absk$lograre_nbsp),max(absk$lograre_nbsp),length=5),0),3),
                .margins=1,.fun=function(x)coef_rare(x))
to_graph$Rare_Spec<-as.factor(to_graph$Rare_Spec)
to_graph$cat_div<-factor(to_graph$Rare_Spec,labels=c("Rare1","Rare2","mean",
                                                     "Rare3","Rare4","Rare5"))
to_graph<-data.table(to_graph)
year_window=to_graph[,c(seq(min(Year),max(Year),by=3),max(Year)+0.5)]
year_window2=data.table::shift(year_window,1)
year_dt<-data.table(Year=year_window,prevY=year_window2)
year_dt<-year_dt[-1]
to_graph<-ddply(year_dt,1,function(x){
  to_graph[Year>=x[,"prevY"]&Year<x[,"Year"],":="(Window=x[,"Year"],
                                                  prevWindow=x[,"prevY"])]
})
to_graph<-unique(to_graph)

to_graph<-data.table(to_graph)
to_graph[,index:=paste(Window,Rare_Spec)]
to_graph[,prevY:=data.table::shift(Year),by=.(Rare_Spec)]

to_graph[is.na(prevY)==TRUE,prevY:=Year-1]
to_graph[is.na(Window)==TRUE,Window:=2005.5]
to_hmm<-to_graph[cat_div!="mean"]

year_dt<-data.table(cat_div=rep(unique(to_graph[,cat_div]),each=nrow(year_dt)),
                    Year=rep(year_dt[,Year],length(unique(to_graph[,cat_div]))),
                    prevY=rep(year_dt[,prevY],length(unique(to_graph[,cat_div]))))
year_dt<-year_dt[cat_div!="mean"]

year_dt[,weights:=apply(year_dt,1,function(x,into=absk){
  
  inside<-subset(into,Year<x["Year"]&Year>=x["prevY"]&cat_div==x["cat_div"])
  return(sum(inside[,PS]))
})]
setnames(year_dt,c("cat_div","Window","prevY","Weights"))
year_dt[,prevY:=NULL]
year_dt<-unique(year_dt)
to_hmm<-merge(to_hmm,year_dt,by=c("cat_div","Window"))

to_hmm[,index:=paste(Window,cat_div,sep="_")]
breaker=unique(to_hmm[,paste(Window,cat_div,sep="_")])
to_ribbon<-melt(to_hmm,
                measure.vars=c("Year","prevY"),
                id.vars=c("mean","low","up","Rare_Spec","Weights","index","Window"))
to_ribbon[,intense:=Weights/max(Weights)]

#Graph NBC
NBC<-ggplot(to_graph,aes(x=Year,y=mean,col=Rare_Spec))+
  theme_classic()
for(i in 1:length(breaker)){
  NBC=NBC+geom_ribbon(data=to_ribbon[index==breaker[i],],
                      aes(x=value,ymin=low,ymax=up,group=Rare_Spec),
                      alpha=unique(to_ribbon[index==breaker[i],intense]),fill="#000d40",
                      inherit.aes = FALSE,col=NA)
}
NBC<-NBC+ geom_line(size=1,linetype="solid")+
  geom_point(data=to_ribbon,aes(alpha=Weights,x=value,y=mean),size=1.1,col=NA,show.legend=FALSE)+
  scale_colour_manual(values=c("mediumpurple","cyan1","black","green1","darkorange1","deeppink"),name="",
                      labels=c("-0.7441900"="1.00","-0.3305275"="2.06","0.0831350000000001"="3.12",
                               "0.4967975"="4.17","0.91046"="5.23","0"="Mean (2.26)"),
                      guide=guide_legend(override.aes = list(colour =NA,fill=NA)))+
  xlab("Year")+
  ylab(expression(paste("Net biomass change (Mg ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
NBC<-NBC+scale_alpha_continuous(name="Area sampled (ha)",breaks=c(0,10,20,29),
                                labels=c("0","10","20","30"),
                                guide=guide_legend(override.aes = list(colour =NA,fill=NA)))
NBC<-NBC + annotate("text", x = 1985, y =2.5, label = "Year:~italic(P) < 0.001~(italic(t)==-6.19)", parse=TRUE, size=4)
NBC<-NBC + annotate("text", x = 1985, y =2.3, label = "Year%*%ln(italic(S)):~italic(P) < 0.001~(italic(t)==3.65)", parse=TRUE, size=4)+
  scale_y_continuous(breaks=c(0,1,2))
NBC

marare_nbsp_Pval

#### BIND Year response (Fig2b) with Main Div Effect (Fig2a) ####
rbind_gtable_max <- function(...){
  gtl <- list(...)
  stopifnot(all(sapply(gtl, is.gtable)))
  bind2 <- function (x, y) 
  {
    stopifnot(ncol(x) == ncol(y))
    if (nrow(x) == 0) 
      return(y)
    if (nrow(y) == 0) 
      return(x)
    y$layout$t <- y$layout$t + nrow(x)
    y$layout$b <- y$layout$b + nrow(x)
    x$layout <- rbind(x$layout, y$layout)
    x$heights <- gtable:::insert.unit(x$heights, y$heights)
    x$rownames <- c(x$rownames, y$rownames)
    x$widths <- grid::unit.pmax(x$widths, y$widths)
    x$grobs <- append(x$grobs, y$grobs)
    x
  }
  
  Reduce(bind2, gtl)
}

#Diversity Main Effect (2.1_ ~ 2.3_)
#f1 <- ggplotGrob(G2.1)#Do not run this after getting NBC2.1, but run right after getting G2.1
f2 <- ggplotGrob(M2.1)
f3 <- ggplotGrob(NBC2.1)
#YEAR MODEL
g1 <- ggplotGrob(Gro)
g2 <- ggplotGrob(Mo)
g3 <- ggplotGrob(NBC)

tiff("Fig2_Year_with_DivMain_SiteIndex_fitme_Hossfeld.tiff",width=2500,height=3000,res=300,compression="lzw")
grid.draw(cbind(rbind(f1,f2,f3,size="last"),rbind(g1,g2,g3,size="first"),size="first"))
grid.text("A",x=unit(0.025,"npc"),y=unit(0.987,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("B",x=unit(0.45,"npc"),y=unit(0.987,"npc"),gp=gpar(fontsize=14,font=2))

dev.off()

##############################################################################################
### Exxtended Data Fig.4 (Fig.S4)###
## BA models ##
load("fitme_Year_Grow_BA_HossfeldSI.R")
BA.mbrare_nbsp_summary<-summary(BA.mbrare_nbsp)$beta

load("fitme_Year_Mort_BA_HossfeldSI.R")
BA.mcrare_nbsp_summary<-summary(BA.mcrare_nbsp)$beta

load("fitme_Year_NBC_BA_HossfeldSI.R")
BA.marare_nbsp_summary<-summary(BA.marare_nbsp)$beta

BA.mbrare_nbsp_Pval<-summary(BA.mbrare_nbsp)$beta
Pval<-2*pt(-abs(BA.mbrare_nbsp_Pval[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
BA.mbrare_nbsp_Pval<-as.data.frame(BA.mbrare_nbsp_Pval)
BA.mbrare_nbsp_Pval$Pval<-Pval[[1]]

BA.mcrare_nbsp_Pval<-summary(BA.mcrare_nbsp)$beta
Pval<-2*pt(-abs(BA.mcrare_nbsp_Pval[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
BA.mcrare_nbsp_Pval<-as.data.frame(BA.mcrare_nbsp_Pval)
BA.mcrare_nbsp_Pval$Pval<-Pval[[1]]

BA.marare_nbsp_Pval<-summary(BA.marare_nbsp)$beta
Pval<-2*pt(-abs(BA.marare_nbsp_Pval[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
BA.marare_nbsp_Pval<-as.data.frame(BA.marare_nbsp_Pval)
BA.marare_nbsp_Pval$Pval<-Pval[[1]]

#Run this for BA, N
Rare<-seq(min(absk$Sprare_nbsp1),max(absk$Sprare_nbsp1),length=5)
absk[Sprare_nbsp1==1,cat_div:="Rare1"]##single species stands
absk[Sprare_nbsp1>1&Sprare_nbsp1<=Rare[2],cat_div:="Rare2"]
absk[Sprare_nbsp1>Rare[2]&Sprare_nbsp1<=Rare[3],cat_div:="Rare3"]
absk[Sprare_nbsp1>Rare[3]&Sprare_nbsp1<=Rare[4],cat_div:="Rare4"]
absk[Sprare_nbsp1>Rare[4],cat_div:="Rare5"]
absk[,cat_div:=factor(cat_div)]
table(absk$cat_div)

absk[,index:=cut(Year,15)]
absk[,Year3:=mean(Year),by=index]
absk$Plot_Bg_col_2<-ave(absk$PS,absk$cat_div,absk$Year3,FUN=sum)

#Growth
coefmean<-BA.mbrare_nbsp_summary[, 1]
SE<-BA.mbrare_nbsp_summary[, 2]
coef_rare<-function(x){
  rare=x
  data.table(mean=coefmean["(Intercept)"]+
               (coefmean["Y"]*(seq(min(absk$Y),max(absk$Y),length=600)))+
               (coefmean["lograre_nbsp"]*rare)+
               (coefmean["Y:lograre_nbsp"]*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             up=coefmean["(Intercept)"]+SE["(Intercept)"]+
               ((coefmean["Y"]+SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["lograre_nbsp"]+SE["lograre_nbsp"])*rare)+
               ((coefmean["Y:lograre_nbsp"]+SE["Y:lograre_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             low=coefmean["(Intercept)"]-SE["(Intercept)"]+
               ((coefmean["Y"]-SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["lograre_nbsp"]-SE["lograre_nbsp"])*rare)+
               ((coefmean["Y:lograre_nbsp"]-SE["Y:lograre_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             Y=seq(min(absk$Y),max(absk$Y),length=600),
             Year=seq(min(absk$Y),max(absk$Y),length=600)+mean(absk$Year),
             Rare_Spec=rare)
}

to_graph<-adply(round(c(seq(min(absk$lograre_nbsp),max(absk$lograre_nbsp),length=5),0),3),.margins=1,.fun=function(x)coef_rare(x))
to_graph$Rare_Spec<-as.factor(to_graph$Rare_Spec)
to_graph$cat_div<-factor(to_graph$Rare_Spec,labels=c("Rare1","Rare2","mean",
                                                     "Rare3","Rare4","Rare5"))

to_graph<-data.table(to_graph)
year_window=to_graph[,c(seq(min(Year),max(Year),by=3),max(Year)+0.5)]
year_window2=data.table::shift(year_window,1)
year_dt<-data.table(Year=year_window,prevY=year_window2)
year_dt<-year_dt[-1]
to_graph<-ddply(year_dt,1,function(x){
  to_graph[Year>=x[,"prevY"]&Year<x[,"Year"],":="(Window=x[,"Year"],
                                                  prevWindow=x[,"prevY"])]
})
to_graph<-unique(to_graph)

to_graph<-data.table(to_graph)
to_graph[,index:=paste(Window,Rare_Spec)]
to_graph[,prevY:=data.table::shift(Year),by=.(Rare_Spec)]

to_graph[is.na(prevY)==TRUE,prevY:=Year-1]
to_graph[is.na(Window)==TRUE,Window:=2005.5]
to_hmm<-to_graph[cat_div!="mean"]

year_dt<-data.table(cat_div=rep(unique(to_graph[,cat_div]),each=nrow(year_dt)),
                    Year=rep(year_dt[,Year],length(unique(to_graph[,cat_div]))),
                    prevY=rep(year_dt[,prevY],length(unique(to_graph[,cat_div]))))
year_dt<-year_dt[cat_div!="mean"]

year_dt[,weights:=apply(year_dt,1,function(x,into=absk){
  
  inside<-subset(into,Year<x["Year"]&Year>=x["prevY"]&cat_div==x["cat_div"])
  return(sum(inside[,PS]))
})]
setnames(year_dt,c("cat_div","Window","prevY","Weights"))
year_dt[,prevY:=NULL]
year_dt<-unique(year_dt)
to_hmm<-merge(to_hmm,year_dt,by=c("cat_div","Window"))

to_hmm[,index:=paste(Window,cat_div,sep="_")]
breaker=unique(to_hmm[,paste(Window,cat_div,sep="_")])
to_ribbon<-melt(to_hmm,
                measure.vars=c("Year","prevY"),
                id.vars=c("mean","low","up","Rare_Spec","Weights","index","Window"))
to_ribbon[,intense:=Weights/max(Weights)]
#to_ribbon[,intense:=intense/1.5]
#to_ribbon[intense==0,intense:=0.1]

absk[,index:=cut(lograre_nbsp1,150)]
absk[,x_for_gg:=mean(exp(lograre_nbsp1)),by=index]
absk[,Plot_Bg_col:=sum(PS),by=index]
absk[,arb:=Plot_Bg_col/max(Plot_Bg_col)]

#Graph Gro
Gro.BA<-ggplot(to_graph,aes(x=Year,y=mean,col=Rare_Spec))+
  theme_classic()
for(i in 1:length(breaker)){
  Gro.BA=Gro.BA+geom_ribbon(data=to_ribbon[index==breaker[i],],
                            aes(x=value,ymin=low,ymax=up,group=Rare_Spec),
                            alpha=unique(to_ribbon[index==breaker[i],intense]),fill="#000d40",
                            inherit.aes = FALSE,col=NA)
}
Gro.BA<-Gro.BA+ geom_line(size=1)+
  geom_point(data=to_ribbon,aes(alpha=Weights,x=value,y=mean),size=1.1,col=NA,show.legend = FALSE)+
  scale_colour_manual(values=c("mediumpurple","cyan1","black","green1","darkorange1","deeppink"),name="Rarefied richness",
                      labels=c("-0.83841231"="1.00","-0.413136035"="2.12","0.0121402399999999"="3.24",
                               "0.437416515"="4.36","0.86269279"="5.48","0"="Mean (2.31)"))+
  scale_linetype_manual(values=c("dotted","dotted","longdash","dotted","dotted","dotted"))+
  xlab("")+
  ylab(expression(paste("Growth (",m^{-2}, " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.position=c(0.25,0.825),legend.title.align  = 0)+
  guides(col=FALSE)
Gro.BA<-Gro.BA+scale_alpha_continuous(name="Area sampled (ha)",breaks=c(0,10,20,29),
                                      labels=c("0","10","20","30"),
                                      guide=guide_legend(override.aes = list(colour ="#000d40",fill="#000d40",
                                                                             shape=15,size=5)))
Gro.BA<-Gro.BA+annotate("text",x= 1984,y=0.80,label="Year:~italic(P) < 0.001~(italic(t)==-3.47)",parse=TRUE,size=4)
Gro.BA<-Gro.BA+annotate("text",x= 1984,y=0.76,label="Year%*%ln(italic(S)):~italic(P) < 0.001~(italic(t)==7.43)",parse=TRUE,size=4)+
  scale_y_continuous(breaks=c(0.4,0.6,0.8))
Gro.BA

BA.mbrare_nbsp_Pval

#Mortality
coefmean<-BA.mcrare_nbsp_summary[, 1]
SE<-BA.mcrare_nbsp_summary[, 2]
coef_rare<-function(x){
  rare=x
  data.table(mean=coefmean["(Intercept)"]+
               (coefmean["Y"]*(seq(min(absk$Y),max(absk$Y),length=600)))+
               (coefmean["Sprare_nbsp"]*rare)+
               (coefmean["Y:Sprare_nbsp"]*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             up=coefmean["(Intercept)"]+SE["(Intercept)"]+
               ((coefmean["Y"]+SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]+SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]+SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             low=coefmean["(Intercept)"]-SE["(Intercept)"]+
               ((coefmean["Y"]-SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]-SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]-SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             Y=seq(min(absk$Y),max(absk$Y),length=600),
             Year=seq(min(absk$Y),max(absk$Y),length=600)+mean(absk$Year),
             Rare_Spec=rare)
}

to_graph<-adply(round(c(seq(min(absk$Sprare_nbsp),max(absk$Sprare_nbsp),length=5),0),3),
                .margins=1,.fun=function(x)coef_rare(x))
to_graph$Rare_Spec<-as.factor(to_graph$Rare_Spec)
to_graph$cat_div<-factor(to_graph$Rare_Spec,labels=c("Rare1","Rare2","mean",
                                                     "Rare3","Rare4","Rare5"))
to_graph<-data.table(to_graph)
year_window=to_graph[,c(seq(min(Year),max(Year),by=3),max(Year)+0.5)]
year_window2=data.table::shift(year_window,1)
year_dt<-data.table(Year=year_window,prevY=year_window2)
year_dt<-year_dt[-1]
to_graph<-ddply(year_dt,1,function(x){
  to_graph[Year>=x[,"prevY"]&Year<x[,"Year"],":="(Window=x[,"Year"],
                                                  prevWindow=x[,"prevY"])]
})
to_graph<-unique(to_graph)

to_graph<-data.table(to_graph)
to_graph[,index:=paste(Window,Rare_Spec)]
to_graph[,prevY:=data.table::shift(Year),by=.(Rare_Spec)]

to_graph[is.na(prevY)==TRUE,prevY:=Year-1]
to_graph[is.na(Window)==TRUE,Window:=2005.5]
to_hmm<-to_graph[cat_div!="mean"]

year_dt<-data.table(cat_div=rep(unique(to_graph[,cat_div]),each=nrow(year_dt)),
                    Year=rep(year_dt[,Year],length(unique(to_graph[,cat_div]))),
                    prevY=rep(year_dt[,prevY],length(unique(to_graph[,cat_div]))))
year_dt<-year_dt[cat_div!="mean"]

year_dt[,weights:=apply(year_dt,1,function(x,into=absk){
  
  inside<-subset(into,Year<x["Year"]&Year>=x["prevY"]&cat_div==x["cat_div"])
  return(sum(inside[,PS]))
})]
setnames(year_dt,c("cat_div","Window","prevY","Weights"))
year_dt[,prevY:=NULL]
year_dt<-unique(year_dt)
to_hmm<-merge(to_hmm,year_dt,by=c("cat_div","Window"))

to_hmm[,index:=paste(Window,cat_div,sep="_")]
breaker=unique(to_hmm[,paste(Window,cat_div,sep="_")])
to_ribbon<-melt(to_hmm,
                measure.vars=c("Year","prevY"),
                id.vars=c("mean","low","up","Rare_Spec","Weights","index","Window"))
to_ribbon[,intense:=Weights/max(Weights)]
#to_ribbon[,intense:=intense/1.5]
#to_ribbon[intense==0,intense:=0.1]

#Graph Mort
Mort.BA<-ggplot(to_graph,aes(x=Year,y=mean,col=Rare_Spec))+
  theme_classic()
for(i in 1:length(breaker)){
  Mort.BA=Mort.BA+geom_ribbon(data=to_ribbon[index==breaker[i],],
                              aes(x=value,ymin=low,ymax=up,group=Rare_Spec),
                              alpha=unique(to_ribbon[index==breaker[i],intense]),fill="#000d40",
                              inherit.aes = FALSE,col=NA)
}
Mort.BA<-Mort.BA+ geom_line(size=1)+
  geom_point(data=to_ribbon,aes(alpha=Weights,x=value,y=mean),size=1.1,col=NA,show.legend = FALSE)+
  scale_colour_manual(values=c("mediumpurple","cyan1","black","green1","darkorange1","deeppink"),name="Rarefied richness",
                      labels=c("-0.83841231"="1.00","-0.413136035"="2.12","0.0121402399999999"="3.24",
                               "0.437416515"="4.36","0.86269279"="5.48","0"="Mean (2.31)"))+
  xlab("")+
  ylab(expression(paste("Mortality ( ", m^{-2}, " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.position=c(0.25,0.825),legend.title.align  = 0)+
  guides(col=FALSE)
Mort.BA<-Mort.BA+scale_alpha_continuous(name="Area sampled (ha)",breaks=c(0,10,20,29),
                                        labels=c("0","10","20","30"),
                                        guide=guide_legend(override.aes = list(colour ="#000d40",fill="#000d40",
                                                                               shape=15,size=5)))
Mort.BA<-Mort.BA+annotate("text",x= 1984,y=0.65,label="Year:~italic(P) < 0.001~(italic(t)==7.05)",parse=TRUE,size=4)
Mort.BA<-Mort.BA+annotate("text",x= 1984,y=0.60,label="Year%*%italic(S):~italic(P) == 0.004~(italic(t)==-2.89)",parse=TRUE,size=4)
Mort.BA

BA.mcrare_nbsp_Pval

#NBC
coefmean<-BA.marare_nbsp_summary[, 1]
SE<-BA.marare_nbsp_summary[, 2]
coef_rare<-function(x){
  rare=x
  data.table(mean=coefmean["(Intercept)"]+
               (coefmean["Y"]*(seq(min(absk$Y),max(absk$Y),length=600)))+
               (coefmean["Sprare_nbsp"]*rare)+
               (coefmean["Y:Sprare_nbsp"]*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             up=coefmean["(Intercept)"]+SE["(Intercept)"]+
               ((coefmean["Y"]+SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]+SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]+SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             low=coefmean["(Intercept)"]-SE["(Intercept)"]+
               ((coefmean["Y"]-SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]-SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]-SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             Y=seq(min(absk$Y),max(absk$Y),length=600),
             Year=seq(min(absk$Y),max(absk$Y),length=600)+mean(absk$Year),
             Rare_Spec=rare)
}

to_graph<-adply(round(c(seq(min(absk$Sprare_nbsp),max(absk$Sprare_nbsp),length=5),0),3),
                .margins=1,.fun=function(x)coef_rare(x))
to_graph$Rare_Spec<-as.factor(to_graph$Rare_Spec)
to_graph$cat_div<-factor(to_graph$Rare_Spec,labels=c("Rare1","Rare2","mean",
                                                     "Rare3","Rare4","Rare5"))
to_graph<-data.table(to_graph)
year_window=to_graph[,c(seq(min(Year),max(Year),by=3),max(Year)+0.5)]
year_window2=data.table::shift(year_window,1)
year_dt<-data.table(Year=year_window,prevY=year_window2)
year_dt<-year_dt[-1]
to_graph<-ddply(year_dt,1,function(x){
  to_graph[Year>=x[,"prevY"]&Year<x[,"Year"],":="(Window=x[,"Year"],
                                                  prevWindow=x[,"prevY"])]
})
to_graph<-unique(to_graph)

to_graph<-data.table(to_graph)
to_graph[,index:=paste(Window,Rare_Spec)]
to_graph[,prevY:=data.table::shift(Year),by=.(Rare_Spec)]

to_graph[is.na(prevY)==TRUE,prevY:=Year-1]
to_graph[is.na(Window)==TRUE,Window:=2005.5]
to_hmm<-to_graph[cat_div!="mean"]

year_dt<-data.table(cat_div=rep(unique(to_graph[,cat_div]),each=nrow(year_dt)),
                    Year=rep(year_dt[,Year],length(unique(to_graph[,cat_div]))),
                    prevY=rep(year_dt[,prevY],length(unique(to_graph[,cat_div]))))
year_dt<-year_dt[cat_div!="mean"]

year_dt[,weights:=apply(year_dt,1,function(x,into=absk){
  
  inside<-subset(into,Year<x["Year"]&Year>=x["prevY"]&cat_div==x["cat_div"])
  return(sum(inside[,PS]))
})]
setnames(year_dt,c("cat_div","Window","prevY","Weights"))
year_dt[,prevY:=NULL]
year_dt<-unique(year_dt)
to_hmm<-merge(to_hmm,year_dt,by=c("cat_div","Window"))

to_hmm[,index:=paste(Window,cat_div,sep="_")]
breaker=unique(to_hmm[,paste(Window,cat_div,sep="_")])
to_ribbon<-melt(to_hmm,
                measure.vars=c("Year","prevY"),
                id.vars=c("mean","low","up","Rare_Spec","Weights","index","Window"))
to_ribbon[,intense:=Weights/max(Weights)]
#to_ribbon[,intense:=intense/1.5]
#to_ribbon[intense==0,intense:=0.1]

#Graph Net
Net.BA<-ggplot(to_graph,aes(x=Year,y=mean,col=Rare_Spec))+
  theme_classic()
for(i in 1:length(breaker)){
  Net.BA=Net.BA+geom_ribbon(data=to_ribbon[index==breaker[i],],
                            aes(x=value,ymin=low,ymax=up,group=Rare_Spec),
                            alpha=unique(to_ribbon[index==breaker[i],intense]),fill="#000d40",
                            inherit.aes = FALSE,col=NA)
}

Net.BA<-Net.BA+ geom_line(size=1)+
  geom_point(data=to_ribbon,aes(alpha=Weights,x=value,y=mean),size=1.1,col=NA,show.legend = FALSE)+
  scale_colour_manual(values=c("mediumpurple","cyan1","black","green1","darkorange1","deeppink"),name="Rarefied richness",
                      labels=c("-0.83841231"="1.00","-0.413136035"="2.12","0.0121402399999999"="3.24",
                               "0.437416515"="4.36","0.86269279"="5.48","0"="Mean (2.31)"))+
  xlab("Year")+
  ylab(expression(paste("Net change (", m^{-2}, " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.position=c(0.25,0.825),legend.title.align  = 0)+
  guides(col=FALSE)

Net.BA<-Net.BA+scale_alpha_continuous(name="Area sampled (ha)",breaks=c(0,10,20,29),
                                      labels=c("0","10","20","30"),
                                      guide=guide_legend(override.aes = list(colour ="#000d40",fill="#000d40",
                                                                             shape=15,size=5)))
Net.BA<-Net.BA+annotate("text",x= 1984,y=0.6,label="Year:~italic(P) < 0.001~(italic(t)==-7.39)",parse=TRUE,size=4)
Net.BA<-Net.BA+annotate("text",x= 1984,y=0.52,label="Year%*%italic(S):~italic(P) < 0.001~(italic(t)==5.34)",parse=TRUE,size=4)
Net.BA

BA.marare_nbsp_Pval

##### StemN ##### 
## StemN models ##
load("fitme_Year_Grow_N_HossfeldSI.R")
N.mbrare_nbsp_summary<-summary(N.mbrare_nbsp)$beta

load("fitme_Year_Mort_N_HossfeldSI.R")
N.mcrare_nbsp_summary<-summary(N.mcrare_nbsp)$beta

load("fitme_Year_NBC_N_HossfeldSI.R")
N.marare_nbsp_summary<-summary(N.marare_nbsp)$beta

N.mbrare_nbsp_Pval<-summary(N.mbrare_nbsp)$beta
Pval<-2*pt(-abs(N.mbrare_nbsp_Pval[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
N.mbrare_nbsp_Pval<-as.data.frame(N.mbrare_nbsp_Pval)
N.mbrare_nbsp_Pval$Pval<-Pval[[1]]

N.mcrare_nbsp_Pval<-summary(N.mcrare_nbsp)$beta
Pval<-2*pt(-abs(N.mcrare_nbsp_Pval[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
N.mcrare_nbsp_Pval<-as.data.frame(N.mcrare_nbsp_Pval)
N.mcrare_nbsp_Pval$Pval<-Pval[[1]]

N.marare_nbsp_Pval<-summary(N.marare_nbsp)$beta
Pval<-2*pt(-abs(N.marare_nbsp_Pval[,"t-value"]), df=2544-(871+681+7+1)) %>% as.data.frame()
N.marare_nbsp_Pval<-as.data.frame(N.marare_nbsp_Pval)
N.marare_nbsp_Pval$Pval<-Pval[[1]]

#Growth
coefmean<-N.mbrare_nbsp_summary[, 1]
SE<-N.mbrare_nbsp_summary[, 2]
coef_rare<-function(x){
  rare=x
  data.table(mean=coefmean["(Intercept)"]+
               (coefmean["Y"]*(seq(min(absk$Y),max(absk$Y),length=600)))+
               (coefmean["Sprare_nbsp"]*rare)+
               (coefmean["Y:Sprare_nbsp"]*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             up=coefmean["(Intercept)"]+SE["(Intercept)"]+
               ((coefmean["Y"]+SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]+SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]+SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             low=coefmean["(Intercept)"]-SE["(Intercept)"]+
               ((coefmean["Y"]-SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]-SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]-SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             Y=seq(min(absk$Y),max(absk$Y),length=600),
             Year=seq(min(absk$Y),max(absk$Y),length=600)+mean(absk$Year),
             Rare_Spec=rare)
}

to_graph<-adply(round(c(seq(min(absk$Sprare_nbsp),max(absk$Sprare_nbsp),length=5),0),3),
                .margins=1,.fun=function(x)coef_rare(x))
to_graph$Rare_Spec<-as.factor(to_graph$Rare_Spec)
to_graph$cat_div<-factor(to_graph$Rare_Spec,labels=c("Rare1","Rare2","mean",
                                                     "Rare3","Rare4","Rare5"))

to_graph<-data.table(to_graph)
year_window=to_graph[,c(seq(min(Year),max(Year),by=3),max(Year)+0.5)]
year_window2=data.table::shift(year_window,1)
year_dt<-data.table(Year=year_window,prevY=year_window2)
year_dt<-year_dt[-1]
to_graph<-ddply(year_dt,1,function(x){
  to_graph[Year>=x[,"prevY"]&Year<x[,"Year"],":="(Window=x[,"Year"],
                                                  prevWindow=x[,"prevY"])]
})
to_graph<-unique(to_graph)

to_graph<-data.table(to_graph)
to_graph[,index:=paste(Window,Rare_Spec)]
to_graph[,prevY:=data.table::shift(Year),by=.(Rare_Spec)]

to_graph[is.na(prevY)==TRUE,prevY:=Year-1]
to_graph[is.na(Window)==TRUE,Window:=2005.5]
to_hmm<-to_graph[cat_div!="mean"]

year_dt<-data.table(cat_div=rep(unique(to_graph[,cat_div]),each=nrow(year_dt)),
                    Year=rep(year_dt[,Year],length(unique(to_graph[,cat_div]))),
                    prevY=rep(year_dt[,prevY],length(unique(to_graph[,cat_div]))))
year_dt<-year_dt[cat_div!="mean"]

year_dt[,weights:=apply(year_dt,1,function(x,into=absk){
  
  inside<-subset(into,Year<x["Year"]&Year>=x["prevY"]&cat_div==x["cat_div"])
  return(sum(inside[,PS]))
})]
setnames(year_dt,c("cat_div","Window","prevY","Weights"))
year_dt[,prevY:=NULL]
year_dt<-unique(year_dt)
to_hmm<-merge(to_hmm,year_dt,by=c("cat_div","Window"))

to_hmm[,index:=paste(Window,cat_div,sep="_")]
breaker=unique(to_hmm[,paste(Window,cat_div,sep="_")])
to_ribbon<-melt(to_hmm,
                measure.vars=c("Year","prevY"),
                id.vars=c("mean","low","up","Rare_Spec","Weights","index","Window"))
to_ribbon[,intense:=Weights/max(Weights)]

#Graph Gro.N
Gro.N<-ggplot(to_graph,aes(x=Year,y=mean,col=Rare_Spec))+
  theme_classic()
for(i in 1:length(breaker)){
  Gro.N=Gro.N+geom_ribbon(data=to_ribbon[index==breaker[i],],
                          aes(x=value,ymin=low,ymax=up,group=Rare_Spec),
                          alpha=unique(to_ribbon[index==breaker[i],intense]),fill="#000d40",
                          inherit.aes = FALSE,col=NA)
}
Gro.N<-Gro.N+ geom_line(size=1)+
  geom_point(data=to_ribbon,aes(alpha=Weights,x=value,y=mean),size=1.1,col=NA,show.legend=FALSE)+
  scale_colour_manual(values=c("mediumpurple","cyan1","black","green1","darkorange1","deeppink"),name="",
                      labels=c("-0.84141844"="1.00","-0.34214939"="2.12","0.07524857"="3.24",
                               "0.49264653"="4.36","0.94650033"="5.48","0"="Mean (2.30)"),
                      guide=guide_legend(override.aes = list(colour =NA,fill=NA)))+
  scale_linetype_manual(values=c("solid","solid","dotted","solid","solid","solid"))+
  xlab("")+
  ylab(expression(paste("Growth (stem ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
Gro.N<-Gro.N+scale_alpha_continuous(name="Area sampled (ha)",breaks=c(0,10,20,29),
                                    labels=c("0","10","20","30"),
                                    guide=guide_legend(override.aes = list(colour =NA,fill=NA)))
Gro.N<-Gro.N+annotate("text",x= 1984,y=8,label="Year:~italic(P) == 0.955~(italic(t)=='-0.06')",parse=TRUE,size=4)
Gro.N<-Gro.N+annotate("text",x= 1984,y=7.3,label="Year%*%italic(S):~italic(P) < 0.001~(italic(t)==8.95)",parse=TRUE,size=4)
Gro.N

N.mbrare_nbsp_Pval

#Mortality
coefmean<-N.mcrare_nbsp_summary[, 1]
SE<-N.mcrare_nbsp_summary[, 2]
coef_rare<-function(x){
  rare=x
  data.table(mean=coefmean["(Intercept)"]+
               (coefmean["Y"]*(seq(min(absk$Y),max(absk$Y),length=600)))+
               (coefmean["Sprare_nbsp"]*rare)+
               (coefmean["Y:Sprare_nbsp"]*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             up=coefmean["(Intercept)"]+SE["(Intercept)"]+
               ((coefmean["Y"]+SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]+SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]+SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             low=coefmean["(Intercept)"]-SE["(Intercept)"]+
               ((coefmean["Y"]-SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]-SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]-SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             Y=seq(min(absk$Y),max(absk$Y),length=600),
             Year=seq(min(absk$Y),max(absk$Y),length=600)+mean(absk$Year),
             Rare_Spec=rare)
}

to_graph<-adply(round(c(seq(min(absk$Sprare_nbsp),max(absk$Sprare_nbsp),length=5),0),3),
                .margins=1,.fun=function(x)coef_rare(x))
to_graph$Rare_Spec<-as.factor(to_graph$Rare_Spec)
to_graph$cat_div<-factor(to_graph$Rare_Spec,labels=c("Rare1","Rare2","mean",
                                                     "Rare3","Rare4","Rare5"))

to_graph<-data.table(to_graph)
year_window=to_graph[,c(seq(min(Year),max(Year),by=3),max(Year)+0.5)]
year_window2=data.table::shift(year_window,1)
year_dt<-data.table(Year=year_window,prevY=year_window2)
year_dt<-year_dt[-1]
to_graph<-ddply(year_dt,1,function(x){
  to_graph[Year>=x[,"prevY"]&Year<x[,"Year"],":="(Window=x[,"Year"],
                                                  prevWindow=x[,"prevY"])]
})
to_graph<-unique(to_graph)

to_graph<-data.table(to_graph)
to_graph[,index:=paste(Window,Rare_Spec)]
to_graph[,prevY:=data.table::shift(Year),by=.(Rare_Spec)]

to_graph[is.na(prevY)==TRUE,prevY:=Year-1]
to_graph[is.na(Window)==TRUE,Window:=2005.5]
to_hmm<-to_graph[cat_div!="mean"]

year_dt<-data.table(cat_div=rep(unique(to_graph[,cat_div]),each=nrow(year_dt)),
                    Year=rep(year_dt[,Year],length(unique(to_graph[,cat_div]))),
                    prevY=rep(year_dt[,prevY],length(unique(to_graph[,cat_div]))))
year_dt<-year_dt[cat_div!="mean"]

year_dt[,weights:=apply(year_dt,1,function(x,into=absk){
  
  inside<-subset(into,Year<x["Year"]&Year>=x["prevY"]&cat_div==x["cat_div"])
  return(sum(inside[,PS]))
})]
setnames(year_dt,c("cat_div","Window","prevY","Weights"))
year_dt[,prevY:=NULL]
year_dt<-unique(year_dt)
to_hmm<-merge(to_hmm,year_dt,by=c("cat_div","Window"))

to_hmm[,index:=paste(Window,cat_div,sep="_")]
breaker=unique(to_hmm[,paste(Window,cat_div,sep="_")])
to_ribbon<-melt(to_hmm,
                measure.vars=c("Year","prevY"),
                id.vars=c("mean","low","up","Rare_Spec","Weights","index","Window"))
to_ribbon[,intense:=Weights/max(Weights)]

#Graph Mortality
Mort.N<-ggplot(to_graph,aes(x=Year,y=mean,col=Rare_Spec))+
  theme_classic()
for(i in 1:length(breaker)){
  Mort.N=Mort.N+geom_ribbon(data=to_ribbon[index==breaker[i],],
                            aes(x=value,ymin=low,ymax=up,group=Rare_Spec),
                            alpha=unique(to_ribbon[index==breaker[i],intense]),fill="#000d40",
                            inherit.aes = FALSE,col=NA)
}

Mort.N<-Mort.N+ geom_line(size=1,linetype="solid")+
  geom_point(data=to_ribbon,aes(alpha=Weights,x=value,y=mean),size=1.1,col=NA)+
  scale_colour_manual(values=c("mediumpurple","cyan1","black","green1","darkorange1","deeppink"),name="Rarefied richness",
                      labels=c("-1.299"="1.00","-0.222"="2.08","0.856"="3.15","1.933"="4.23",
                               "3.01"="5.31","0"="Mean (2.30)"))+
  
  xlab("")+
  ylab(expression(paste("Mortality (stem ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.title.x=element_blank(), axis.text.x=element_blank(), axis.ticks.x=element_blank(),
        axis.line.x= element_blank(), axis.line.y = element_line(),
        #legend.position=c(0.75,1),
        legend.title.align  = 0)
#,legend.background = element_rect(fill = "#87CEEB30",colour = NA))

Mort.N<-Mort.N+scale_alpha_continuous(name="Area sampled (ha)",breaks=c(0,10,20,29),
                                      labels=c("0","10","20","30"),
                                      guide=guide_legend(override.aes = list(colour ="#000d40",fill="#000d40",
                                                                             shape=15,size=5)))

Mort.N<-Mort.N+annotate("text",x= 1984,y=5.8,label="Year:~italic(P) < 0.001~(italic(t)==3.78)",parse=TRUE,size=4)
Mort.N<-Mort.N+annotate("text",x= 1984,y=5.3,label="Year%*%italic(S):~italic(P) < 0.001~(italic(t)==-4.34)",parse=TRUE,size=4)
Mort.N

N.mcrare_nbsp_Pval

#NBC
coefmean<-N.marare_nbsp_summary[, 1]
SE<-N.marare_nbsp_summary[, 2]
coef_rare<-function(x){
  rare=x
  data.table(mean=coefmean["(Intercept)"]+
               (coefmean["Y"]*(seq(min(absk$Y),max(absk$Y),length=600)))+
               (coefmean["Sprare_nbsp"]*rare)+
               (coefmean["Y:Sprare_nbsp"]*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             up=coefmean["(Intercept)"]+SE["(Intercept)"]+
               ((coefmean["Y"]+SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]+SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]+SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             low=coefmean["(Intercept)"]-SE["(Intercept)"]+
               ((coefmean["Y"]-SE["Y"])*(seq(min(absk$Y),max(absk$Y),length=600)))+
               ((coefmean["Sprare_nbsp"]-SE["Sprare_nbsp"])*rare)+
               ((coefmean["Y:Sprare_nbsp"]-SE["Y:Sprare_nbsp"])*rare*(seq(min(absk$Y),max(absk$Y),length=600))),
             Y=seq(min(absk$Y),max(absk$Y),length=600),
             Year=seq(min(absk$Y),max(absk$Y),length=600)+mean(absk$Year),
             Rare_Spec=rare)
}

to_graph<-adply(round(c(seq(min(absk$Sprare_nbsp),max(absk$Sprare_nbsp),length=5),0),3),
                .margins=1,.fun=function(x)coef_rare(x))
to_graph$Rare_Spec<-as.factor(to_graph$Rare_Spec)
to_graph$cat_div<-factor(to_graph$Rare_Spec,labels=c("Rare1","Rare2","mean",
                                                     "Rare3","Rare4","Rare5"))

to_graph<-data.table(to_graph)
year_window=to_graph[,c(seq(min(Year),max(Year),by=3),max(Year)+0.5)]
year_window2=data.table::shift(year_window,1)
year_dt<-data.table(Year=year_window,prevY=year_window2)
year_dt<-year_dt[-1]
to_graph<-ddply(year_dt,1,function(x){
  to_graph[Year>=x[,"prevY"]&Year<x[,"Year"],":="(Window=x[,"Year"],
                                                  prevWindow=x[,"prevY"])]
})
to_graph<-unique(to_graph)

to_graph<-data.table(to_graph)
to_graph[,index:=paste(Window,Rare_Spec)]
to_graph[,prevY:=data.table::shift(Year),by=.(Rare_Spec)]

to_graph[is.na(prevY)==TRUE,prevY:=Year-1]
to_graph[is.na(Window)==TRUE,Window:=2005.5]
to_hmm<-to_graph[cat_div!="mean"]

year_dt<-data.table(cat_div=rep(unique(to_graph[,cat_div]),each=nrow(year_dt)),
                    Year=rep(year_dt[,Year],length(unique(to_graph[,cat_div]))),
                    prevY=rep(year_dt[,prevY],length(unique(to_graph[,cat_div]))))
year_dt<-year_dt[cat_div!="mean"]

year_dt[,weights:=apply(year_dt,1,function(x,into=absk){
  
  inside<-subset(into,Year<x["Year"]&Year>=x["prevY"]&cat_div==x["cat_div"])
  return(sum(inside[,PS]))
})]
setnames(year_dt,c("cat_div","Window","prevY","Weights"))
year_dt[,prevY:=NULL]
year_dt<-unique(year_dt)
to_hmm<-merge(to_hmm,year_dt,by=c("cat_div","Window"))

to_hmm[,index:=paste(Window,cat_div,sep="_")]
breaker=unique(to_hmm[,paste(Window,cat_div,sep="_")])
to_ribbon<-melt(to_hmm,
                measure.vars=c("Year","prevY"),
                id.vars=c("mean","low","up","Rare_Spec","Weights","index","Window"))
to_ribbon[,intense:=Weights/max(Weights)]

#Graph Net
Net.N<-ggplot(to_graph,aes(x=Year,y=mean,col=Rare_Spec))+
  theme_classic()
for(i in 1:length(breaker)){
  Net.N=Net.N+geom_ribbon(data=to_ribbon[index==breaker[i],],
                          aes(x=value,ymin=low,ymax=up,group=Rare_Spec),
                          alpha=unique(to_ribbon[index==breaker[i],intense]),fill="#000d40",
                          inherit.aes = FALSE,col=NA)
}
Net.N<-Net.N+ geom_line(size=1)+
  geom_point(data=to_ribbon,aes(alpha=Weights,x=value,y=mean),size=1.1,col=NA,show.legend=FALSE)+
  scale_colour_manual(values=c("mediumpurple","cyan1","black","green1","darkorange1","deeppink"),name="",
                      labels=c("-0.84141844"="1.00","-0.34214939"="2.12","0.07524857"="3.24",
                               "0.49264653"="4.36","0.94650033"="5.48","0"="Mean (2.30)"),
                      guide=guide_legend(override.aes = list(colour =NA,fill=NA)))+
  scale_linetype_manual(values=c("solid","solid","dotted","solid","solid","solid"))+
  xlab("Year")+
  ylab(expression(paste("Net change (stem ", " ", ha^{-1}, " ", yr^{-1},")")))+
  theme(axis.line.y = element_line(),
        legend.title.align  = 0,
        legend.background = element_rect(fill = NA,colour = NA),legend.text = element_text(colour=NA))
Net.N<-Net.N+scale_alpha_continuous(name="Area sampled (ha)",breaks=c(0,10,20,29),
                                    labels=c("0","10","20","30"),
                                    guide=guide_legend(override.aes = list(colour =NA,fill=NA)))
Net.N<-Net.N+annotate("text",x= 1980,y=7,label="Year:~italic(P) == 0.001~(italic(t)=='-3.26')",parse=TRUE,size=4)
Net.N<-Net.N+annotate("text",x= 1980,y=6,label="Year%*%italic(S):~italic(P) < 0.001~(italic(t)==8.81)",parse=TRUE,size=4)+
  scale_y_continuous(breaks=c(-6,-3,0,3,6))
Net.N

N.marare_nbsp_Pval

#### BIND BA StemN ####
rbind_gtable_max <- function(...){
  gtl <- list(...)
  stopifnot(all(sapply(gtl, is.gtable)))
  bind2 <- function (x, y) 
  {
    stopifnot(ncol(x) == ncol(y))
    if (nrow(x) == 0) 
      return(y)
    if (nrow(y) == 0) 
      return(x)
    y$layout$t <- y$layout$t + nrow(x)
    y$layout$b <- y$layout$b + nrow(x)
    x$layout <- rbind(x$layout, y$layout)
    x$heights <- gtable:::insert.unit(x$heights, y$heights)
    x$rownames <- c(x$rownames, y$rownames)
    x$widths <- grid::unit.pmax(x$widths, y$widths)
    x$grobs <- append(x$grobs, y$grobs)
    x
  }
  
  Reduce(bind2, gtl)
}

#Diversity Main Effect (2.1_ ~ 2.3_)
f1 <- ggplotGrob(Gro.BA)
f2 <- ggplotGrob(Mort.BA)
f3 <- ggplotGrob(Net.BA)
#YEAR MODEL
g1 <- ggplotGrob(Gro.N)
g2 <- ggplotGrob(Mort.N)
g3 <- ggplotGrob(Net.N)

tiff("FigS3_BA_StemN_SiteIndex_fitme_Hossfeld.tiff",width=2500,height=3000,res=300,compression="lzw")
grid.draw(cbind(rbind(f1,f2,f3,size="last"),rbind(g1,g2,g3,size="first"),size="first"))
grid.text("A",x=unit(0.025,"npc"),y=unit(0.987,"npc"),gp=gpar(fontsize=14,font=2))
grid.text("B",x=unit(0.45,"npc"),y=unit(0.987,"npc"),gp=gpar(fontsize=14,font=2))

dev.off()
