#VIF
library(MASS);library(clusterGeneration);library(fmsb)

#Create function
vif_func<-function(in_frame,thresh=10,trace=T,...){
  
  require(fmsb)
  
  if(class(in_frame) != 'data.frame') in_frame<-data.frame(in_frame)
  
  #get initial vif value for all comparisons of variables
  vif_init<-NULL
  var_names <- names(in_frame)
  for(val in var_names){
    regressors <- var_names[-which(var_names == val)]
    form <- paste(regressors, collapse = '+')
    form_in <- formula(paste(val, '~', form))
    vif_init<-rbind(vif_init, c(val, VIF(lm(form_in, data = in_frame, ...))))
  }
  vif_max<-max(as.numeric(vif_init[,2]), na.rm = TRUE)
  
  if(vif_max < thresh){
    if(trace==T){ #print output of each iteration
      prmatrix(vif_init,collab=c('var','vif'),rowlab=rep('',nrow(vif_init)),quote=F)
      cat('\n')
      cat(paste('All variables have VIF < ', thresh,', max VIF ',round(vif_max,2), sep=''),'\n\n')
    }
    return(var_names)
  }
  else{
    
    in_dat<-in_frame
    
    #backwards selection of explanatory variables, stops when all VIF values are below 'thresh'
    while(vif_max >= thresh){
      
      vif_vals<-NULL
      var_names <- names(in_dat)
      
      for(val in var_names){
        regressors <- var_names[-which(var_names == val)]
        form <- paste(regressors, collapse = '+')
        form_in <- formula(paste(val, '~', form))
        vif_add<-VIF(lm(form_in, data = in_dat, ...))
        vif_vals<-rbind(vif_vals,c(val,vif_add))
      }
      max_row<-which(vif_vals[,2] == max(as.numeric(vif_vals[,2]), na.rm = TRUE))[1]
      
      vif_max<-as.numeric(vif_vals[max_row,2])
      
      if(vif_max<thresh) break
      
      if(trace==T){ #print output of each iteration
        prmatrix(vif_vals,collab=c('var','vif'),rowlab=rep('',nrow(vif_vals)),quote=F)
        cat('\n')
        cat('removed: ',vif_vals[max_row,1],vif_max,'\n\n')
        flush.console()
      }
      
      in_dat<-in_dat[,!names(in_dat) %in% vif_vals[max_row,1]]
      
    }
    
    return(names(in_dat))
    
  }
  
}

## lograre_nbsp
absk[,":="(logSA.Y=logSA*Y,logSA.lograre=logSA*lograre_nbsp,Y.lograre=Y*lograre_nbsp,
           logSA.CO21=logSA*CO21,CO21.lograre=CO21*lograre_nbsp,
           logSA.ATA1=logSA*ATA1,ATA1.lograre=ATA1*lograre_nbsp,
           logSA.CMI1=logSA*CMI1,CMI1.lograre=CMI1*lograre_nbsp)]

ex.var<-absk[,.(Y,logSA,lograre_nbsp,logSI,logSA.Y,logSA.lograre,Y.lograre)]%>%as.matrix#main
ex.var<-absk[,.(Y,logSA,lograre_nbsp,Elev,LAT,logSA.Y,logSA.lograre,Y.lograre)]%>%as.matrix#with LAT Elev instead of SI
vif_func(in_frame=ex.var,thresh=4,trace=T)

ex.var.climate<-absk[,.(logSA,lograre_nbsp,CO21,ATA1,CMI1,
                        logSA.CO21,CO21.lograre,
                        logSA.ATA1,ATA1.lograre,
                        logSA.CMI1,CMI1.lograre)]%>%as.matrix#Multi
vif_func(in_frame=ex.var.climate,thresh=4,trace=T)

cor(absk$lograre_nbsp1,absk$logSI)^2

## Sprare_nbsp
absk[,":="(logSA.Y=logSA*Y,logSA.Sprare=logSA*Sprare_nbsp,Y.Sprare=Y*Sprare_nbsp,
           logSA.CO21=logSA*CO21,CO21.Sprare=CO21*Sprare_nbsp,
           logSA.ATA1=logSA*ATA1,ATA1.Sprare=ATA1*Sprare_nbsp,
           logSA.CMI1=logSA*CMI1,CMI1.Sprare=CMI1*Sprare_nbsp)]

ex.var<-absk[,.(Y,logSA,Sprare_nbsp,logSI,logSA.Y,logSA.Sprare,Y.Sprare)]%>%as.matrix
vif_func(in_frame=ex.var,thresh=4,trace=T)

ex.var.climate<-absk[,.(logSA,Sprare_nbsp,CO21,ATA1,CMI1,
                        logSA.CO21,CO21.Sprare,
                        logSA.ATA1,ATA1.Sprare,
                        logSA.CMI1,CMI1.Sprare)]%>%as.matrix
vif_func(in_frame=ex.var.climate,thresh=4,trace=T)

cor(absk$Sprare_nbsp1,absk$logSI)


