library(nlme);library(lmeresampler)
library(lme4);library(lmerTest)
library(boot);library(Rfit)
library(MuMIn);library(ggplot2)
library(grid);library(gridExtra)
library(gtable);library(plyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(Hmisc)
library(spdep);library(SoDA);library(ape)
library(spaMM)

absk<-fread("Hisano_et_al_Data_Submitted_to_EcolLett.csv")
absk[,":="(logSI1=log(SI1))] %>% 
  .[,":="(Long=LONG+rnorm(nrow(absk),0,0.001),
          Lat=LAT+rnorm(nrow(absk),0,0.001),
          logSI=logSI1+rnorm(nrow(absk),0,0.000000000000001))] %>% 
  .[,":="(logSI=scale(logSI,scale=F),logBio_sc=scale(log(total_Bio1)))] %>% 
  .[,":="(logSA_sc=scale(log(SA1)),
          invlogSA_sc=scale(1/log(SA1)),
          Y_sc=scale(Year),
          Sprare_nbsp_sc=scale(Sprare_nbsp1),lograre_nbsp_sc=scale(lograre_nbsp1),
          Spstd_nbsp_sc=scale(Spstd_nbsp1),logstd_nbsp_sc=scale(logstd_nbsp1),
          Spnbsp_sc=scale(SpS),lognbsp_sc=scale(log(SpS)),
          SpShann_sc=scale(SpShann1),logShann_sc=scale(log(SpShann1+1)),
          SpSimp_sc=scale(SpSimp1),logSimp_sc=scale(log(SpSimp1+1)),
          SpST_sc=scale(SpST1),logST_sc=scale(log(SpST1)),sqrtST_sc=scale(sqrt(SpST1)),quadST_sc=scale(SpST1^2),
          logSI_sc=scale(logSI))] %>% 
  .[,":="(ATA1_10=ATA1*10,
          CO21_sc=scale(CO2),ATA1_sc=scale(ATA),CMI1_sc=scale(ACMIA))]

absk[,rare_nbsp_ave:=mean(rare_nbsp),by=Plotnumber]
length(unique(absk$rare_nbsp_ave))

absk[,SpST1_ave:=mean(SpST1),by=Plotnumber]
length(unique(absk$SpST1_ave))

#Table S2
#Rarefied species richness in relation to elevation and site index.
#The model is resulted from AIC selection from the full model
#(rarefied species richness = latitude + longitude + elevation + site index). All predictors are scaled.
absk[,":="(LAT_sc=scale(LAT,center = T, scale = T),
           LONG_sc=scale(LONG,center = T, scale = T),
           Elev_sc=scale(Elev1,center = T, scale = T),
           logSI_sc=scale(logSI1,center = T, scale = T))]
full<-lm(Sprare_nbsp1~LAT_sc+LONG_sc+Elev_sc+logSI_sc,absk)
dredge(full)#model selection by AIC and removing insignificant predictor (LONG)

final<-lm(Sprare_nbsp1~logSI_sc+Elev_sc+LAT_sc,absk)
summary(final)$coef#Report this
summary(final)#Report this (df)
anova(final)#Report this

library(asbio)
final_SI<-update(final, ~. - logSI_sc)
partial.R2(final_SI,final)#partial r2 for logSI_sc
cor(absk$logSI_sc,absk$Sprare_nbsp1)^2#compare

final_Elev<-update(final, ~. - Elev_sc)
partial.R2(final_Elev,final)#partial r2 for Elev_sc
cor(absk$Elev_sc,absk$Sprare_nbsp1)^2#compare

final_LAT<-update(final, ~. - LAT_sc)
partial.R2(final_LAT,final)#partial r2 for LAT_sc
cor(absk$LAT_sc,absk$Sprare_nbsp1)^2#compare

