rm(list=ls())
library(nlme);library(lmeresampler)
library(lme4);library(lmerTest)
library(boot);library(Rfit)
library(MuMIn);library(ggplot2)
library(grid);library(gridExtra)
library(gtable);library(plyr)
library(dplyr);library(data.table)
library(MuMIn);options(na.action = "na.fail")
library(glmnet);library(glmnetUtils)
library(Hmisc)
library(spdep);library(SoDA);library(ape)
library(spaMM)

absk<-fread("Hisano_et_al_Data_Submitted_to_EcolLett.csv")
absk[,":="(logSI1=log(SI1))] %>% 
  .[,":="(Long=LONG+rnorm(nrow(absk),0,0.001),
          Lat=LAT+rnorm(nrow(absk),0,0.001),
          logSI=logSI1+rnorm(nrow(absk),0,0.000000000000001))] %>% 
  .[,":="(logSI=scale(logSI,scale=F),logBio_sc=scale(log(total_Bio1)))] %>% 
  .[,":="(logSA_sc=scale(log(SA1)),
          invlogSA_sc=scale(1/log(SA1)),
          Y_sc=scale(Year),
          Sprare_nbsp_sc=scale(Sprare_nbsp1),lograre_nbsp_sc=scale(lograre_nbsp1),
          Spstd_nbsp_sc=scale(Spstd_nbsp1),logstd_nbsp_sc=scale(logstd_nbsp1),
          Spnbsp_sc=scale(SpS),lognbsp_sc=scale(log(SpS)),
          SpShann_sc=scale(SpShann1),logShann_sc=scale(log(SpShann1+1)),
          SpSimp_sc=scale(SpSimp1),logSimp_sc=scale(log(SpSimp1+1)),
          SpST_sc=scale(SpST1),logST_sc=scale(log(SpST1)),sqrtST_sc=scale(sqrt(SpST1)),quadST_sc=scale(SpST1^2),
          logSI_sc=scale(logSI))] %>% 
  .[,":="(ATA1_10=ATA1*10,
          CO21_sc=scale(CO2),ATA1_sc=scale(ATA),CMI1_sc=scale(ACMIA))]

### Ridge Regression ###

### Fig.S5,S6) ###
## YEAR
################################## Grow ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,lograre_nbsp=lograre_nbsp,logSI=logSI,Div_SA=lograre_nbsp*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*lograre_nbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_Grow_sc_HossfeldSI.R")
glmnet.dat[,AGBGI_corr:=residuals(mbrare_nbsp_sc,type="response")+
             mbrare_nbsp_sc$fixef[1]+
             (mbrare_nbsp_sc$fixef[2]*logSA)+
             (mbrare_nbsp_sc$fixef[3]*Y)+
             (mbrare_nbsp_sc$fixef[4]*lograre_nbsp)+
             (mbrare_nbsp_sc$fixef[5]*logSI)+
             (mbrare_nbsp_sc$fixef[6]*logSA*Y)+
             (mbrare_nbsp_sc$fixef[7]*logSA*lograre_nbsp)+
             (mbrare_nbsp_sc$fixef[8]*Y*lograre_nbsp)]

mod_lm_corr<-lm(AGBGI_corr~logSA+Y+lograre_nbsp+logSI+
                  (logSA:Y)+(logSA:lograre_nbsp)+
                  (Y:lograre_nbsp),glmnet.dat,weights=wi)
summary(residuals(mbrare_nbsp_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,lograre_nbsp,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGBGI_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

grow.gl<-glmnet(AGBGI_corr~logSA+Y+lograre_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                weights=wi,data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(grow.gl)
check<-coef(grow.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  grow.gl2<-glmnet(AGBGI_corr~logSA+Y+lograre_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(grow.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          lograre_nbsp=unlist(apply(coeff.se[,grep("^lograre_nbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

growT_1se<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                      mean.gr=NA,up.gr=NA,low.gr=NA)

growT_1se$mean.gr<-apply(coeff.se_tidy,2,mean)
growT_1se$up.gr<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
growT_1se$low.gr<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
mbrare_nbsp_sc_summary<-summary(mbrare_nbsp_sc)$beta
growT_multi<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                        mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi$mean.gr<-mbrare_nbsp_sc_summary[,1]
growT_multi$up.gr<-mbrare_nbsp_sc_summary[,1]+mbrare_nbsp_sc_summary[,2]
growT_multi$low.gr<-mbrare_nbsp_sc_summary[,1]-mbrare_nbsp_sc_summary[,2]

#Temporal autoregressive
mbrare_nbsp_Tmp_sc<-lme(AGBGI~logSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:lograre_nbsp_sc)+(Y_sc:lograre_nbsp_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
growT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_Tmp$mean.gr<-summary(mbrare_nbsp_Tmp_sc)$tTable[,1]
growT_multi_Tmp$up.gr<-summary(mbrare_nbsp_Tmp_sc)$tTable[,1]+summary(mbrare_nbsp_Tmp_sc)$tTable[,2]
growT_multi_Tmp$low.gr<-summary(mbrare_nbsp_Tmp_sc)$tTable[,1]-summary(mbrare_nbsp_Tmp_sc)$tTable[,2]

#lmer
mbrare_nbsp_lmer_sc<-lmer(AGBGI~logSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:lograre_nbsp_sc)+(Y_sc:lograre_nbsp_sc)+
                            (1|Plotnumber),weights=wi,absk)
growT_multi_lmer<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                             mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_lmer$mean.gr<-summary(mbrare_nbsp_lmer_sc)$co[,1]
growT_multi_lmer$up.gr<-summary(mbrare_nbsp_lmer_sc)$co[,1]+summary(mbrare_nbsp_lmer_sc)$co[,2]
growT_multi_lmer$low.gr<-summary(mbrare_nbsp_lmer_sc)$co[,1]-summary(mbrare_nbsp_lmer_sc)$co[,2]

#nonpara
nmbrare_nbsp<-rfit(AGBGI_corr~logSA+Y+lograre_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=glmnet.dat)
summary(nmbrare_nbsp)$co
growT_multi_NP<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_NP$mean.gr<-summary(nmbrare_nbsp)$co[,1]
growT_multi_NP$up.gr<-summary(nmbrare_nbsp)$co[,1]+summary(nmbrare_nbsp)$co[,2]
growT_multi_NP$low.gr<-summary(nmbrare_nbsp)$co[,1]-summary(nmbrare_nbsp)$co[,2]

#Sequential
load("fitme_Year_Grow_seq_sc_Hossfeld.R")
mb_seq_sc_summary<-summary(mbrare_nbsp_seq_sc)$beta_table

mbrare_nbsp_resid1<-lm(resid(mbrare_nbsp_seq_sc)~Y+lograre_nbsp+(logSA:Y)+(logSA:lograre_nbsp)+(Y:lograre_nbsp),
                       weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(mbrare_nbsp_resid1))

growT_multi_seq<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"))

growT_multi_seq[Source=="logSA",mean.gr:=mb_seq_sc_summary["logSA_sc",1]]
growT_multi_seq[Source=="Y",mean.gr:=coef(summary(mbrare_nbsp_resid1))["Y",1]]
growT_multi_seq[Source=="lograre_nbsp",mean.gr:=coef(summary(mbrare_nbsp_resid1))["lograre_nbsp",1]]
growT_multi_seq[Source=="logSI",mean.gr:=mb_seq_sc_summary["logSI_sc",1]]
growT_multi_seq[Source=="SA_Y",mean.gr:=coef(summary(mbrare_nbsp_resid1))["Y:logSA",1]]
growT_multi_seq[Source=="Div_SA",mean.gr:=coef(summary(mbrare_nbsp_resid1))["lograre_nbsp:logSA",1]]
growT_multi_seq[Source=="Div_Y",mean.gr:=coef(summary(mbrare_nbsp_resid1))["Y:lograre_nbsp",1]]

growT_multi_seq[Source=="logSA",up.gr:=mb_seq_sc_summary["logSA_sc",1]+
                  mb_seq_sc_summary["logSA_sc",2]]
growT_multi_seq[Source=="Y",up.gr:=coef(summary(mbrare_nbsp_resid1))["Y",1]+
                  coef(summary(mbrare_nbsp_resid1))["Y",2]]
growT_multi_seq[Source=="lograre_nbsp",up.gr:=coef(summary(mbrare_nbsp_resid1))["lograre_nbsp",1]+
                  coef(summary(mbrare_nbsp_resid1))["lograre_nbsp",2]]
growT_multi_seq[Source=="logSI",up.gr:=mb_seq_sc_summary["logSI_sc",1]+
                  mb_seq_sc_summary["logSI_sc",2]]
growT_multi_seq[Source=="SA_Y",up.gr:=coef(summary(mbrare_nbsp_resid1))["Y:logSA",1]+
                  coef(summary(mbrare_nbsp_resid1))["Y:logSA",2]]
growT_multi_seq[Source=="Div_SA",up.gr:=coef(summary(mbrare_nbsp_resid1))["lograre_nbsp:logSA",1]+
                  coef(summary(mbrare_nbsp_resid1))["lograre_nbsp:logSA",2]]
growT_multi_seq[Source=="Div_Y",up.gr:=coef(summary(mbrare_nbsp_resid1))["Y:lograre_nbsp",1]+
                  coef(summary(mbrare_nbsp_resid1))["Y:lograre_nbsp",2]]

growT_multi_seq[Source=="logSA",low.gr:=mb_seq_sc_summary["logSA_sc",1]-
                  mb_seq_sc_summary["logSA_sc",2]]
growT_multi_seq[Source=="Y",low.gr:=coef(summary(mbrare_nbsp_resid1))["Y",1]-
                  coef(summary(mbrare_nbsp_resid1))["Y",2]]
growT_multi_seq[Source=="lograre_nbsp",low.gr:=coef(summary(mbrare_nbsp_resid1))["lograre_nbsp",1]-
                  coef(summary(mbrare_nbsp_resid1))["lograre_nbsp",2]]
growT_multi_seq[Source=="logSI",low.gr:=mb_seq_sc_summary["logSI_sc",1]-
                  mb_seq_sc_summary["logSI_sc",2]]
growT_multi_seq[Source=="SA_Y",low.gr:=coef(summary(mbrare_nbsp_resid1))["Y:logSA",1]-
                  coef(summary(mbrare_nbsp_resid1))["Y:logSA",2]]
growT_multi_seq[Source=="Div_SA",low.gr:=coef(summary(mbrare_nbsp_resid1))["lograre_nbsp:logSA",1]-
                  coef(summary(mbrare_nbsp_resid1))["lograre_nbsp:logSA",2]]
growT_multi_seq[Source=="Div_Y",low.gr:=coef(summary(mbrare_nbsp_resid1))["Y:lograre_nbsp",1]-
                  coef(summary(mbrare_nbsp_resid1))["Y:lograre_nbsp",2]]

#Bind
growT_multi_lmer$model<-"Linear mixed effects"
growT_multi_Tmp$model<-"Temporal autoregressive"
growT_multi$model<-"Spatial autoregressive"
growT_1se$model<-"Ridge regression"
growT_multi_NP$model<-"Nonparametric"
growT_multi_seq$model<-"Sequential"

to_gg<-rbind(growT_multi_lmer,growT_multi_Tmp,growT_multi,growT_1se,growT_multi_NP,growT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="lograre_nbsp",Source:="logS"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*logS"];to_gg[Source=="Div_Y",Source:="Y*logS"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","logS","logSA*Y","logSA*logS","Y*logS"))

Grow<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.gr,ymin=low.gr,ymax=up.gr,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.7),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+
  guides(col=FALSE)
Grow

################################## Mortality ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,Sprare_nbsp=Sprare_nbsp,logSI=logSI,Div_SA=Sprare_nbsp*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*Sprare_nbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_Mort_sc_HossfeldSI.R")
glmnet.dat[,AGBM_corr:=residuals(mcrare_nbsp_sc,type="response")+
             mcrare_nbsp_sc$fixef[1]+
             (mcrare_nbsp_sc$fixef[2]*logSA)+
             (mcrare_nbsp_sc$fixef[3]*Y)+
             (mcrare_nbsp_sc$fixef[4]*Sprare_nbsp)+
             (mcrare_nbsp_sc$fixef[5]*logSI)+
             (mcrare_nbsp_sc$fixef[6]*logSA*Y)+
             (mcrare_nbsp_sc$fixef[7]*logSA*Sprare_nbsp)+
             (mcrare_nbsp_sc$fixef[8]*Y*Sprare_nbsp)]

mod_lm_corr<-lm(AGBM_corr~logSA+Y+Sprare_nbsp+logSI+
                  (logSA:Y)+(logSA:Sprare_nbsp)+
                  (Y:Sprare_nbsp),glmnet.dat,weights=wi)
summary(residuals(mcrare_nbsp_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,Sprare_nbsp,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGBM_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

mort.gl<-glmnet(AGBM_corr~logSA+Y+Sprare_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                weights=wi,data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(mort.gl)
check<-coef(mort.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  mort.gl2<-glmnet(AGBM_corr~logSA+Y+Sprare_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(mort.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","Sprare_nbsp","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Sprare_nbsp=unlist(apply(coeff.se[,grep("^Sprare_nbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

mortT_1se<-data.table(Source=c("Int","logSA","Y","Sprare_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                      mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_1se$mean.mort<-apply(coeff.se_tidy,2,mean)
mortT_1se$up.mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
mortT_1se$low.mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
mcrare_nbsp_sc_summary<-summary(mcrare_nbsp_sc)$beta
mortT_multi<-data.table(Source=c("Int","logSA","Y","Sprare_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                        mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi$mean.mort<-mcrare_nbsp_sc_summary[,1]
mortT_multi$up.mort<-mcrare_nbsp_sc_summary[,1]+mcrare_nbsp_sc_summary[,2]
mortT_multi$low.mort<-mcrare_nbsp_sc_summary[,1]-mcrare_nbsp_sc_summary[,2]

#Temporal autoregressive
mcrare_nbsp_Tmp_sc<-lme(AGBM~logSA_sc+Y_sc+Sprare_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:Sprare_nbsp_sc)+(Y_sc:Sprare_nbsp_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
mortT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","Sprare_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_Tmp$mean.mort<-summary(mcrare_nbsp_Tmp_sc)$tTable[,1]
mortT_multi_Tmp$up.mort<-summary(mcrare_nbsp_Tmp_sc)$tTable[,1]+summary(mcrare_nbsp_Tmp_sc)$tTable[,2]
mortT_multi_Tmp$low.mort<-summary(mcrare_nbsp_Tmp_sc)$tTable[,1]-summary(mcrare_nbsp_Tmp_sc)$tTable[,2]

#lmer
mcrare_nbsp_lmer_sc<-lmer(AGBM~logSA_sc+Y_sc+Sprare_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:Sprare_nbsp_sc)+(Y_sc:Sprare_nbsp_sc)+
                            (1|Plotnumber),weights=wi,absk)
mortT_multi_lmer<-data.table(Source=c("Int","logSA","Y","Sprare_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                             mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_lmer$mean.mort<-summary(mcrare_nbsp_lmer_sc)$co[,1]
mortT_multi_lmer$up.mort<-summary(mcrare_nbsp_lmer_sc)$co[,1]+summary(mcrare_nbsp_lmer_sc)$co[,2]
mortT_multi_lmer$low.mort<-summary(mcrare_nbsp_lmer_sc)$co[,1]-summary(mcrare_nbsp_lmer_sc)$co[,2]

#nonpara
nmcrare_nbsp<-rfit(AGBM_corr~logSA+Y+Sprare_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=glmnet.dat)
summary(nmcrare_nbsp)$co

mortT_multi_NP<-data.table(Source=c("Int","logSA","Y","Sprare_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_NP$mean.mort<-summary(nmcrare_nbsp)$co[,1]
mortT_multi_NP$up.mort<-summary(nmcrare_nbsp)$co[,1]+summary(nmcrare_nbsp)$co[,2]
mortT_multi_NP$low.mort<-summary(nmcrare_nbsp)$co[,1]-summary(nmcrare_nbsp)$co[,2]

#Sequential
load("fitme_Year_Mort_seq_sc_Hossfeld.R")
mc_seq_sc_summary<-summary(mcrare_nbsp_seq_sc)$beta_table

mcrare_nbsp_resid1<-lm(resid(mcrare_nbsp_seq_sc)~Y+Sprare_nbsp+(logSA:Y)+(logSA:Sprare_nbsp)+(Y:Sprare_nbsp),
                       weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(mcrare_nbsp_resid1))

mortT_multi_seq<-data.table(Source=c("Int","logSA","Y","Sprare_nbsp","logSI","SA_Y","Div_SA","Div_Y"))

mortT_multi_seq[Source=="logSA",mean.mort:=mc_seq_sc_summary["logSA_sc",1]]
mortT_multi_seq[Source=="Y",mean.mort:=coef(summary(mcrare_nbsp_resid1))["Y",1]]
mortT_multi_seq[Source=="Sprare_nbsp",mean.mort:=coef(summary(mcrare_nbsp_resid1))["Sprare_nbsp",1]]
mortT_multi_seq[Source=="logSI",mean.mort:=mc_seq_sc_summary["logSI_sc",1]]
mortT_multi_seq[Source=="SA_Y",mean.mort:=coef(summary(mcrare_nbsp_resid1))["Y:logSA",1]]
mortT_multi_seq[Source=="Div_SA",mean.mort:=coef(summary(mcrare_nbsp_resid1))["Sprare_nbsp:logSA",1]]
mortT_multi_seq[Source=="Div_Y",mean.mort:=coef(summary(mcrare_nbsp_resid1))["Y:Sprare_nbsp",1]]

mortT_multi_seq[Source=="logSA",up.mort:=mc_seq_sc_summary["logSA_sc",1]+
                  mc_seq_sc_summary["logSA_sc",2]]
mortT_multi_seq[Source=="Y",up.mort:=coef(summary(mcrare_nbsp_resid1))["Y",1]+
                  coef(summary(mcrare_nbsp_resid1))["Y",2]]
mortT_multi_seq[Source=="Sprare_nbsp",up.mort:=coef(summary(mcrare_nbsp_resid1))["Sprare_nbsp",1]+
                  coef(summary(mcrare_nbsp_resid1))["Sprare_nbsp",2]]
mortT_multi_seq[Source=="logSI",up.mort:=mc_seq_sc_summary["logSI_sc",1]+
                  mc_seq_sc_summary["logSI_sc",2]]
mortT_multi_seq[Source=="SA_Y",up.mort:=coef(summary(mcrare_nbsp_resid1))["Y:logSA",1]+
                  coef(summary(mcrare_nbsp_resid1))["Y:logSA",2]]
mortT_multi_seq[Source=="Div_SA",up.mort:=coef(summary(mcrare_nbsp_resid1))["Sprare_nbsp:logSA",1]+
                  coef(summary(mcrare_nbsp_resid1))["Sprare_nbsp:logSA",2]]
mortT_multi_seq[Source=="Div_Y",up.mort:=coef(summary(mcrare_nbsp_resid1))["Y:Sprare_nbsp",1]+
                  coef(summary(mcrare_nbsp_resid1))["Y:Sprare_nbsp",2]]

mortT_multi_seq[Source=="logSA",low.mort:=mc_seq_sc_summary["logSA_sc",1]-
                  mc_seq_sc_summary["logSA_sc",2]]
mortT_multi_seq[Source=="Y",low.mort:=coef(summary(mcrare_nbsp_resid1))["Y",1]-
                  coef(summary(mcrare_nbsp_resid1))["Y",2]]
mortT_multi_seq[Source=="Sprare_nbsp",low.mort:=coef(summary(mcrare_nbsp_resid1))["Sprare_nbsp",1]-
                  coef(summary(mcrare_nbsp_resid1))["Sprare_nbsp",2]]
mortT_multi_seq[Source=="logSI",low.mort:=mc_seq_sc_summary["logSI_sc",1]-
                  mc_seq_sc_summary["logSI_sc",2]]
mortT_multi_seq[Source=="SA_Y",low.mort:=coef(summary(mcrare_nbsp_resid1))["Y:logSA",1]-
                  coef(summary(mcrare_nbsp_resid1))["Y:logSA",2]]
mortT_multi_seq[Source=="Div_SA",low.mort:=coef(summary(mcrare_nbsp_resid1))["Sprare_nbsp:logSA",1]-
                  coef(summary(mcrare_nbsp_resid1))["Sprare_nbsp:logSA",2]]
mortT_multi_seq[Source=="Div_Y",low.mort:=coef(summary(mcrare_nbsp_resid1))["Y:Sprare_nbsp",1]-
                  coef(summary(mcrare_nbsp_resid1))["Y:Sprare_nbsp",2]]

#Bind
mortT_multi_lmer$model<-"Linear mixed effects"
mortT_multi_Tmp$model<-"Temporal autoregressive"
mortT_multi$model<-"Spatial autoregressive"
mortT_1se$model<-"Ridge regression"
mortT_multi_NP$model<-"Nonparametric"
mortT_multi_seq$model<-"Sequential"

to_gg<-rbind(mortT_multi_lmer,mortT_multi_Tmp,mortT_multi,mortT_1se,mortT_multi_NP,mortT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="lograre_nbsp",Source:="logS"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*logS"];to_gg[Source=="Div_Y",Source:="Y*logS"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","logS","logSA*Y","logSA*logS","Y*logS"))

Mort<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.mort,ymin=low.mort,ymax=up.mort,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.7),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+
  guides(col=FALSE)
Mort

################################## NBC ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,lograre_nbsp=lograre_nbsp,logSI=logSI,Div_SA=lograre_nbsp*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*lograre_nbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_NBC_sc_HossfeldSI.R")
glmnet.dat[,AGB_corr:=residuals(marare_nbsp_sc,type="response")+
             marare_nbsp_sc$fixef[1]+
             (marare_nbsp_sc$fixef[2]*logSA)+
             (marare_nbsp_sc$fixef[3]*Y)+
             (marare_nbsp_sc$fixef[4]*lograre_nbsp)+
             (marare_nbsp_sc$fixef[5]*logSI)+
             (marare_nbsp_sc$fixef[6]*logSA*Y)+
             (marare_nbsp_sc$fixef[7]*logSA*lograre_nbsp)+
             (marare_nbsp_sc$fixef[8]*Y*lograre_nbsp)]

mod_lm_corr<-lm(AGB_corr~logSA+Y+lograre_nbsp+logSI+
                  (logSA:Y)+(logSA:lograre_nbsp)+
                  (Y:lograre_nbsp),glmnet.dat,weights=wi)
summary(residuals(marare_nbsp_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,lograre_nbsp,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGB_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

nbc.gl<-glmnet(AGB_corr~logSA+Y+lograre_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                weights=wi,data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(nbc.gl)
check<-coef(nbc.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  nbc.gl2<-glmnet(AGB_corr~logSA+Y+lograre_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(nbc.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          lograre_nbsp=unlist(apply(coeff.se[,grep("^lograre_nbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

nbcT_1se<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                      mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_1se$mean.nbc<-apply(coeff.se_tidy,2,mean)
nbcT_1se$up.nbc<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
nbcT_1se$low.nbc<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
marare_nbsp_sc_summary<-summary(marare_nbsp_sc)$beta
nbcT_multi<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                        mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi$mean.nbc<-marare_nbsp_sc_summary[,1]
nbcT_multi$up.nbc<-marare_nbsp_sc_summary[,1]+marare_nbsp_sc_summary[,2]
nbcT_multi$low.nbc<-marare_nbsp_sc_summary[,1]-marare_nbsp_sc_summary[,2]

#Temporal autoregressive
marare_nbsp_Tmp_sc<-lme(AGB~logSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:lograre_nbsp_sc)+(Y_sc:lograre_nbsp_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
nbcT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_Tmp$mean.nbc<-summary(marare_nbsp_Tmp_sc)$tTable[,1]
nbcT_multi_Tmp$up.nbc<-summary(marare_nbsp_Tmp_sc)$tTable[,1]+summary(marare_nbsp_Tmp_sc)$tTable[,2]
nbcT_multi_Tmp$low.nbc<-summary(marare_nbsp_Tmp_sc)$tTable[,1]-summary(marare_nbsp_Tmp_sc)$tTable[,2]

#lmer
marare_nbsp_lmer_sc<-lmer(AGB~logSA_sc+Y_sc+lograre_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:lograre_nbsp_sc)+(Y_sc:lograre_nbsp_sc)+
                            (1|Plotnumber),weights=wi,absk)
nbcT_multi_lmer<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                             mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_lmer$mean.nbc<-summary(marare_nbsp_lmer_sc)$co[,1]
nbcT_multi_lmer$up.nbc<-summary(marare_nbsp_lmer_sc)$co[,1]+summary(marare_nbsp_lmer_sc)$co[,2]
nbcT_multi_lmer$low.nbc<-summary(marare_nbsp_lmer_sc)$co[,1]-summary(marare_nbsp_lmer_sc)$co[,2]

#nonpara
nmarare_nbsp<-rfit(AGB_corr~logSA+Y+lograre_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=glmnet.dat)
summary(nmarare_nbsp)$co

nbcT_multi_NP<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_NP$mean.nbc<-summary(nmarare_nbsp)$co[,1]
nbcT_multi_NP$up.nbc<-summary(nmarare_nbsp)$co[,1]+summary(nmarare_nbsp)$co[,2]
nbcT_multi_NP$low.nbc<-summary(nmarare_nbsp)$co[,1]-summary(nmarare_nbsp)$co[,2]

#Sequential
load("fitme_Year_NBC_seq_sc_Hossfeld.R")
ma_seq_sc_summary<-summary(marare_nbsp_seq_sc)$beta_table

marare_nbsp_resid1<-lm(resid(marare_nbsp_seq_sc)~Y+lograre_nbsp+(logSA:Y)+(logSA:lograre_nbsp)+(Y:lograre_nbsp),
                       weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(marare_nbsp_resid1))

nbcT_multi_seq<-data.table(Source=c("Int","logSA","Y","lograre_nbsp","logSI","SA_Y","Div_SA","Div_Y"))

nbcT_multi_seq[Source=="logSA",mean.nbc:=ma_seq_sc_summary["logSA_sc",1]]
nbcT_multi_seq[Source=="Y",mean.nbc:=coef(summary(marare_nbsp_resid1))["Y",1]]
nbcT_multi_seq[Source=="lograre_nbsp",mean.nbc:=coef(summary(marare_nbsp_resid1))["lograre_nbsp",1]]
nbcT_multi_seq[Source=="logSI",mean.nbc:=ma_seq_sc_summary["logSI_sc",1]]
nbcT_multi_seq[Source=="SA_Y",mean.nbc:=coef(summary(marare_nbsp_resid1))["Y:logSA",1]]
nbcT_multi_seq[Source=="Div_SA",mean.nbc:=coef(summary(marare_nbsp_resid1))["lograre_nbsp:logSA",1]]
nbcT_multi_seq[Source=="Div_Y",mean.nbc:=coef(summary(marare_nbsp_resid1))["Y:lograre_nbsp",1]]

nbcT_multi_seq[Source=="logSA",up.nbc:=ma_seq_sc_summary["logSA_sc",1]+
                  ma_seq_sc_summary["logSA_sc",2]]
nbcT_multi_seq[Source=="Y",up.nbc:=coef(summary(marare_nbsp_resid1))["Y",1]+
                  coef(summary(marare_nbsp_resid1))["Y",2]]
nbcT_multi_seq[Source=="lograre_nbsp",up.nbc:=coef(summary(marare_nbsp_resid1))["lograre_nbsp",1]+
                  coef(summary(marare_nbsp_resid1))["lograre_nbsp",2]]
nbcT_multi_seq[Source=="logSI",up.nbc:=ma_seq_sc_summary["logSI_sc",1]+
                  ma_seq_sc_summary["logSI_sc",2]]
nbcT_multi_seq[Source=="SA_Y",up.nbc:=coef(summary(marare_nbsp_resid1))["Y:logSA",1]+
                  coef(summary(marare_nbsp_resid1))["Y:logSA",2]]
nbcT_multi_seq[Source=="Div_SA",up.nbc:=coef(summary(marare_nbsp_resid1))["lograre_nbsp:logSA",1]+
                  coef(summary(marare_nbsp_resid1))["lograre_nbsp:logSA",2]]
nbcT_multi_seq[Source=="Div_Y",up.nbc:=coef(summary(marare_nbsp_resid1))["Y:lograre_nbsp",1]+
                  coef(summary(marare_nbsp_resid1))["Y:lograre_nbsp",2]]

nbcT_multi_seq[Source=="logSA",low.nbc:=ma_seq_sc_summary["logSA_sc",1]-
                  ma_seq_sc_summary["logSA_sc",2]]
nbcT_multi_seq[Source=="Y",low.nbc:=coef(summary(marare_nbsp_resid1))["Y",1]-
                  coef(summary(marare_nbsp_resid1))["Y",2]]
nbcT_multi_seq[Source=="lograre_nbsp",low.nbc:=coef(summary(marare_nbsp_resid1))["lograre_nbsp",1]-
                  coef(summary(marare_nbsp_resid1))["lograre_nbsp",2]]
nbcT_multi_seq[Source=="logSI",low.nbc:=ma_seq_sc_summary["logSI_sc",1]-
                  ma_seq_sc_summary["logSI_sc",2]]
nbcT_multi_seq[Source=="SA_Y",low.nbc:=coef(summary(marare_nbsp_resid1))["Y:logSA",1]-
                  coef(summary(marare_nbsp_resid1))["Y:logSA",2]]
nbcT_multi_seq[Source=="Div_SA",low.nbc:=coef(summary(marare_nbsp_resid1))["lograre_nbsp:logSA",1]-
                  coef(summary(marare_nbsp_resid1))["lograre_nbsp:logSA",2]]
nbcT_multi_seq[Source=="Div_Y",low.nbc:=coef(summary(marare_nbsp_resid1))["Y:lograre_nbsp",1]-
                  coef(summary(marare_nbsp_resid1))["Y:lograre_nbsp",2]]

#Bind
nbcT_multi_lmer$model<-"Linear mixed effects"
nbcT_multi_Tmp$model<-"Temporal autoregressive"
nbcT_multi$model<-"Spatial autoregressive"
nbcT_1se$model<-"Ridge regression"
nbcT_multi_NP$model<-"Nonparametric"
nbcT_multi_seq$model<-"Sequential"

to_gg<-rbind(nbcT_multi_lmer,nbcT_multi_Tmp,nbcT_multi,nbcT_1se,nbcT_multi_NP,nbcT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="lograre_nbsp",Source:="logS"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*logS"];to_gg[Source=="Div_Y",Source:="Y*logS"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","logS","logSA*Y","logSA*logS","Y*logS"))

NBC<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.nbc,ymin=low.nbc,ymax=up.nbc,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.7),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+
  guides(col=FALSE)
NBC

## Sorg (Original richness)
mb_seq_sc<-mbrare_nbsp_seq_sc
mc_seq_sc<-mcrare_nbsp_seq_sc
ma_seq_sc<-marare_nbsp_seq_sc
################################## Grow ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,lognbsp=lognbsp,logSI=logSI,Div_SA=lognbsp*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*lognbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_Grow_Sorg_sc_HossfeldSI.R")
glmnet.dat[,AGBGI_corr:=residuals(mbnbsp_sc,type="response")+
             mbnbsp_sc$fixef[1]+
             (mbnbsp_sc$fixef[2]*logSA)+
             (mbnbsp_sc$fixef[3]*Y)+
             (mbnbsp_sc$fixef[4]*lognbsp)+
             (mbnbsp_sc$fixef[5]*logSI)+
             (mbnbsp_sc$fixef[6]*logSA*Y)+
             (mbnbsp_sc$fixef[7]*logSA*lognbsp)+
             (mbnbsp_sc$fixef[8]*Y*lognbsp)]

mod_lm_corr<-lm(AGBGI_corr~logSA+Y+lognbsp+logSI+
                  (logSA:Y)+(logSA:lognbsp)+
                  (Y:lognbsp),glmnet.dat,weights=wi)
summary(residuals(mbnbsp_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,lognbsp,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGBGI_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

grow.gl<-glmnet(AGBGI_corr~logSA+Y+lognbsp+logSI+SA_Y+Div_SA+Div_Y,
                weights=wi,data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(grow.gl)
check<-coef(grow.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  grow.gl2<-glmnet(AGBGI_corr~logSA+Y+lognbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(grow.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          lognbsp=unlist(apply(coeff.se[,grep("^lognbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

growT_1se<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),
                      mean.gr=NA,up.gr=NA,low.gr=NA)

growT_1se$mean.gr<-apply(coeff.se_tidy,2,mean)
growT_1se$up.gr<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
growT_1se$low.gr<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
mbnbsp_sc_summary<-summary(mbnbsp_sc)$beta
growT_multi<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),
                        mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi$mean.gr<-mbnbsp_sc_summary[,1]
growT_multi$up.gr<-mbnbsp_sc_summary[,1]+mbnbsp_sc_summary[,2]
growT_multi$low.gr<-mbnbsp_sc_summary[,1]-mbnbsp_sc_summary[,2]

#Temporal autoregressive
mbnbsp_Tmp_sc<-lme(AGBGI~logSA_sc+Y_sc+lognbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:lognbsp_sc)+(Y_sc:lognbsp_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
growT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_Tmp$mean.gr<-summary(mbnbsp_Tmp_sc)$tTable[,1]
growT_multi_Tmp$up.gr<-summary(mbnbsp_Tmp_sc)$tTable[,1]+summary(mbnbsp_Tmp_sc)$tTable[,2]
growT_multi_Tmp$low.gr<-summary(mbnbsp_Tmp_sc)$tTable[,1]-summary(mbnbsp_Tmp_sc)$tTable[,2]

#lmer
mbnbsp_lmer_sc<-lmer(AGBGI~logSA_sc+Y_sc+lognbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:lognbsp_sc)+(Y_sc:lognbsp_sc)+
                            (1|Plotnumber),weights=wi,absk)
growT_multi_lmer<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),
                             mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_lmer$mean.gr<-summary(mbnbsp_lmer_sc)$co[,1]
growT_multi_lmer$up.gr<-summary(mbnbsp_lmer_sc)$co[,1]+summary(mbnbsp_lmer_sc)$co[,2]
growT_multi_lmer$low.gr<-summary(mbnbsp_lmer_sc)$co[,1]-summary(mbnbsp_lmer_sc)$co[,2]

#nonpara
nmbnbsp<-rfit(AGBGI_corr~logSA+Y+lognbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=glmnet.dat)
summary(nmbnbsp)$co

growT_multi_NP<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_NP$mean.gr<-summary(nmbnbsp)$co[,1]
growT_multi_NP$up.gr<-summary(nmbnbsp)$co[,1]+summary(nmbnbsp)$co[,2]
growT_multi_NP$low.gr<-summary(nmbnbsp)$co[,1]-summary(nmbnbsp)$co[,2]

#Sequential
mbnbsp_resid1<-lm(resid(mb_seq_sc)~Y+lognbsp+(logSA:Y)+(logSA:lognbsp)+(Y:lognbsp),
                       weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(mbnbsp_resid1))

growT_multi_seq<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"))

growT_multi_seq[Source=="logSA",mean.gr:=mb_seq_sc_summary["logSA_sc",1]]
growT_multi_seq[Source=="Y",mean.gr:=coef(summary(mbnbsp_resid1))["Y",1]]
growT_multi_seq[Source=="lognbsp",mean.gr:=coef(summary(mbnbsp_resid1))["lognbsp",1]]
growT_multi_seq[Source=="logSI",mean.gr:=mb_seq_sc_summary["logSI_sc",1]]
growT_multi_seq[Source=="SA_Y",mean.gr:=coef(summary(mbnbsp_resid1))["Y:logSA",1]]
growT_multi_seq[Source=="Div_SA",mean.gr:=coef(summary(mbnbsp_resid1))["lognbsp:logSA",1]]
growT_multi_seq[Source=="Div_Y",mean.gr:=coef(summary(mbnbsp_resid1))["Y:lognbsp",1]]

growT_multi_seq[Source=="logSA",up.gr:=mb_seq_sc_summary["logSA_sc",1]+
                  mb_seq_sc_summary["logSA_sc",2]]
growT_multi_seq[Source=="Y",up.gr:=coef(summary(mbnbsp_resid1))["Y",1]+
                  coef(summary(mbnbsp_resid1))["Y",2]]
growT_multi_seq[Source=="lognbsp",up.gr:=coef(summary(mbnbsp_resid1))["lognbsp",1]+
                  coef(summary(mbnbsp_resid1))["lognbsp",2]]
growT_multi_seq[Source=="logSI",up.gr:=mb_seq_sc_summary["logSI_sc",1]+
                  mb_seq_sc_summary["logSI_sc",2]]
growT_multi_seq[Source=="SA_Y",up.gr:=coef(summary(mbnbsp_resid1))["Y:logSA",1]+
                  coef(summary(mbnbsp_resid1))["Y:logSA",2]]
growT_multi_seq[Source=="Div_SA",up.gr:=coef(summary(mbnbsp_resid1))["lognbsp:logSA",1]+
                  coef(summary(mbnbsp_resid1))["lognbsp:logSA",2]]
growT_multi_seq[Source=="Div_Y",up.gr:=coef(summary(mbnbsp_resid1))["Y:lognbsp",1]+
                  coef(summary(mbnbsp_resid1))["Y:lognbsp",2]]

growT_multi_seq[Source=="logSA",low.gr:=mb_seq_sc_summary["logSA_sc",1]-
                  mb_seq_sc_summary["logSA_sc",2]]
growT_multi_seq[Source=="Y",low.gr:=coef(summary(mbnbsp_resid1))["Y",1]-
                  coef(summary(mbnbsp_resid1))["Y",2]]
growT_multi_seq[Source=="lognbsp",low.gr:=coef(summary(mbnbsp_resid1))["lognbsp",1]-
                  coef(summary(mbnbsp_resid1))["lognbsp",2]]
growT_multi_seq[Source=="logSI",low.gr:=mb_seq_sc_summary["logSI_sc",1]-
                  mb_seq_sc_summary["logSI_sc",2]]
growT_multi_seq[Source=="SA_Y",low.gr:=coef(summary(mbnbsp_resid1))["Y:logSA",1]-
                  coef(summary(mbnbsp_resid1))["Y:logSA",2]]
growT_multi_seq[Source=="Div_SA",low.gr:=coef(summary(mbnbsp_resid1))["lognbsp:logSA",1]-
                  coef(summary(mbnbsp_resid1))["lognbsp:logSA",2]]
growT_multi_seq[Source=="Div_Y",low.gr:=coef(summary(mbnbsp_resid1))["Y:lognbsp",1]-
                  coef(summary(mbnbsp_resid1))["Y:lognbsp",2]]

#Bind
growT_multi_lmer$model<-"Linear mixed effects"
growT_multi_Tmp$model<-"Temporal autoregressive"
growT_multi$model<-"Spatial autoregressive"
growT_1se$model<-"Ridge regression"
growT_multi_NP$model<-"Nonparametric"
growT_multi_seq$model<-"Sequential"

to_gg<-rbind(growT_multi_lmer,growT_multi_Tmp,growT_multi,growT_1se,growT_multi_NP,growT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="lognbsp",Source:="logSorg"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*logSorg"];to_gg[Source=="Div_Y",Source:="Y*logSorg"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","logSorg","logSA*Y","logSA*logSorg","Y*logSorg"))

GrowSorg<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.gr,ymin=low.gr,ymax=up.gr,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.7),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+
  guides(col=FALSE)
GrowSorg

################################## Mortality ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,Spnbsp=Spnbsp,logSI=logSI,Div_SA=Spnbsp*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*Spnbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_Mort_Sorg_sc_HossfeldSI.R")
glmnet.dat[,AGBM_corr:=residuals(mcnbsp_sc,type="response")+
             mcnbsp_sc$fixef[1]+
             (mcnbsp_sc$fixef[2]*logSA)+
             (mcnbsp_sc$fixef[3]*Y)+
             (mcnbsp_sc$fixef[4]*Spnbsp)+
             (mcnbsp_sc$fixef[5]*logSI)+
             (mcnbsp_sc$fixef[6]*logSA*Y)+
             (mcnbsp_sc$fixef[7]*logSA*Spnbsp)+
             (mcnbsp_sc$fixef[8]*Y*Spnbsp)]

mod_lm_corr<-lm(AGBM_corr~logSA+Y+Spnbsp+logSI+
                  (logSA:Y)+(logSA:Spnbsp)+
                  (Y:Spnbsp),glmnet.dat,weights=wi)
summary(residuals(mcnbsp_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,Spnbsp,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGBM_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

mort.gl<-glmnet(AGBM_corr~logSA+Y+Spnbsp+logSI+SA_Y+Div_SA+Div_Y,
                weights=wi,data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(mort.gl)
check<-coef(mort.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  mort.gl2<-glmnet(AGBM_corr~logSA+Y+Spnbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(mort.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","Spnbsp","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Spnbsp=unlist(apply(coeff.se[,grep("^Spnbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

mortT_1se<-data.table(Source=c("Int","logSA","Y","Spnbsp","logSI","SA_Y","Div_SA","Div_Y"),
                      mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_1se$mean.mort<-apply(coeff.se_tidy,2,mean)
mortT_1se$up.mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
mortT_1se$low.mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
mcnbsp_sc_summary<-summary(mcnbsp_sc)$beta
mortT_multi<-data.table(Source=c("Int","logSA","Y","Spnbsp","logSI","SA_Y","Div_SA","Div_Y"),
                        mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi$mean.mort<-mcnbsp_sc_summary[,1]
mortT_multi$up.mort<-mcnbsp_sc_summary[,1]+mcnbsp_sc_summary[,2]
mortT_multi$low.mort<-mcnbsp_sc_summary[,1]-mcnbsp_sc_summary[,2]

#Temporal autoregressive
mcnbsp_Tmp_sc<-lme(AGBM~logSA_sc+Y_sc+Spnbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:Spnbsp_sc)+(Y_sc:Spnbsp_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
mortT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","Spnbsp","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_Tmp$mean.mort<-summary(mcnbsp_Tmp_sc)$tTable[,1]
mortT_multi_Tmp$up.mort<-summary(mcnbsp_Tmp_sc)$tTable[,1]+summary(mcnbsp_Tmp_sc)$tTable[,2]
mortT_multi_Tmp$low.mort<-summary(mcnbsp_Tmp_sc)$tTable[,1]-summary(mcnbsp_Tmp_sc)$tTable[,2]

#lmer
mcnbsp_lmer_sc<-lmer(AGBM~logSA_sc+Y_sc+Spnbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:Spnbsp_sc)+(Y_sc:Spnbsp_sc)+
                            (1|Plotnumber),weights=wi,absk)
mortT_multi_lmer<-data.table(Source=c("Int","logSA","Y","Spnbsp","logSI","SA_Y","Div_SA","Div_Y"),
                             mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_lmer$mean.mort<-summary(mcnbsp_lmer_sc)$co[,1]
mortT_multi_lmer$up.mort<-summary(mcnbsp_lmer_sc)$co[,1]+summary(mcnbsp_lmer_sc)$co[,2]
mortT_multi_lmer$low.mort<-summary(mcnbsp_lmer_sc)$co[,1]-summary(mcnbsp_lmer_sc)$co[,2]

#nonpara
nmcnbsp<-rfit(AGBM_corr~logSA+Y+Spnbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=glmnet.dat)
summary(nmcnbsp)$co

mortT_multi_NP<-data.table(Source=c("Int","logSA","Y","Spnbsp","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_NP$mean.mort<-summary(nmcnbsp)$co[,1]
mortT_multi_NP$up.mort<-summary(nmcnbsp)$co[,1]+summary(nmcnbsp)$co[,2]
mortT_multi_NP$low.mort<-summary(nmcnbsp)$co[,1]-summary(nmcnbsp)$co[,2]

#Sequential
mcnbsp_resid1<-lm(resid(mc_seq_sc)~Y+Spnbsp+(logSA:Y)+(logSA:Spnbsp)+(Y:Spnbsp),
                  weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(mcnbsp_resid1))

mortT_multi_seq<-data.table(Source=c("Int","logSA","Y","Spnbsp","logSI","SA_Y","Div_SA","Div_Y"))

mortT_multi_seq[Source=="logSA",mean.mort:=mc_seq_sc_summary["logSA_sc",1]]
mortT_multi_seq[Source=="Y",mean.mort:=coef(summary(mcnbsp_resid1))["Y",1]]
mortT_multi_seq[Source=="Spnbsp",mean.mort:=coef(summary(mcnbsp_resid1))["Spnbsp",1]]
mortT_multi_seq[Source=="logSI",mean.mort:=mc_seq_sc_summary["logSI_sc",1]]
mortT_multi_seq[Source=="SA_Y",mean.mort:=coef(summary(mcnbsp_resid1))["Y:logSA",1]]
mortT_multi_seq[Source=="Div_SA",mean.mort:=coef(summary(mcnbsp_resid1))["Spnbsp:logSA",1]]
mortT_multi_seq[Source=="Div_Y",mean.mort:=coef(summary(mcnbsp_resid1))["Y:Spnbsp",1]]

mortT_multi_seq[Source=="logSA",up.mort:=mc_seq_sc_summary["logSA_sc",1]+
                  mc_seq_sc_summary["logSA_sc",2]]
mortT_multi_seq[Source=="Y",up.mort:=coef(summary(mcnbsp_resid1))["Y",1]+
                  coef(summary(mcnbsp_resid1))["Y",2]]
mortT_multi_seq[Source=="Spnbsp",up.mort:=coef(summary(mcnbsp_resid1))["Spnbsp",1]+
                  coef(summary(mcnbsp_resid1))["Spnbsp",2]]
mortT_multi_seq[Source=="logSI",up.mort:=mc_seq_sc_summary["logSI_sc",1]+
                  mc_seq_sc_summary["logSI_sc",2]]
mortT_multi_seq[Source=="SA_Y",up.mort:=coef(summary(mcnbsp_resid1))["Y:logSA",1]+
                  coef(summary(mcnbsp_resid1))["Y:logSA",2]]
mortT_multi_seq[Source=="Div_SA",up.mort:=coef(summary(mcnbsp_resid1))["Spnbsp:logSA",1]+
                  coef(summary(mcnbsp_resid1))["Spnbsp:logSA",2]]
mortT_multi_seq[Source=="Div_Y",up.mort:=coef(summary(mcnbsp_resid1))["Y:Spnbsp",1]+
                  coef(summary(mcnbsp_resid1))["Y:Spnbsp",2]]

mortT_multi_seq[Source=="logSA",low.mort:=mc_seq_sc_summary["logSA_sc",1]-
                  mc_seq_sc_summary["logSA_sc",2]]
mortT_multi_seq[Source=="Y",low.mort:=coef(summary(mcnbsp_resid1))["Y",1]-
                  coef(summary(mcnbsp_resid1))["Y",2]]
mortT_multi_seq[Source=="Spnbsp",low.mort:=coef(summary(mcnbsp_resid1))["Spnbsp",1]-
                  coef(summary(mcnbsp_resid1))["Spnbsp",2]]
mortT_multi_seq[Source=="logSI",low.mort:=mc_seq_sc_summary["logSI_sc",1]-
                  mc_seq_sc_summary["logSI_sc",2]]
mortT_multi_seq[Source=="SA_Y",low.mort:=coef(summary(mcnbsp_resid1))["Y:logSA",1]-
                  coef(summary(mcnbsp_resid1))["Y:logSA",2]]
mortT_multi_seq[Source=="Div_SA",low.mort:=coef(summary(mcnbsp_resid1))["Spnbsp:logSA",1]-
                  coef(summary(mcnbsp_resid1))["Spnbsp:logSA",2]]
mortT_multi_seq[Source=="Div_Y",low.mort:=coef(summary(mcnbsp_resid1))["Y:Spnbsp",1]-
                  coef(summary(mcnbsp_resid1))["Y:Spnbsp",2]]

#Bind
mortT_multi_lmer$model<-"Linear mixed effects"
mortT_multi_Tmp$model<-"Temporal autoregressive"
mortT_multi$model<-"Spatial autoregressive"
mortT_1se$model<-"Ridge regression"
mortT_multi_NP$model<-"Nonparametric"
mortT_multi_seq$model<-"Sequential"

to_gg<-rbind(mortT_multi_lmer,mortT_multi_Tmp,mortT_multi,mortT_1se,mortT_multi_NP,mortT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="Spnbsp",Source:="Sorg"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*Sorg"];to_gg[Source=="Div_Y",Source:="Y*Sorg"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","Sorg","logSA*Y","logSA*Sorg","Y*Sorg"))

MortSorg<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.mort,ymin=low.mort,ymax=up.mort,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.7),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+
  guides(col=FALSE)
MortSorg

################################## NBC ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,lognbsp=lognbsp,logSI=logSI,Div_SA=lognbsp*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*lognbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_NBC_Sorg_sc_HossfeldSI.R")
glmnet.dat[,AGB_corr:=residuals(manbsp_sc,type="response")+
             manbsp_sc$fixef[1]+
             (manbsp_sc$fixef[2]*logSA)+
             (manbsp_sc$fixef[3]*Y)+
             (manbsp_sc$fixef[4]*lognbsp)+
             (manbsp_sc$fixef[5]*logSI)+
             (manbsp_sc$fixef[6]*logSA*Y)+
             (manbsp_sc$fixef[7]*logSA*lognbsp)+
             (manbsp_sc$fixef[8]*Y*lognbsp)]

mod_lm_corr<-lm(AGB_corr~logSA+Y+lognbsp+logSI+
                  (logSA:Y)+(logSA:lognbsp)+
                  (Y:lognbsp),glmnet.dat,weights=wi)
summary(residuals(manbsp_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,lognbsp,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGB_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

nbc.gl<-glmnet(AGB_corr~logSA+Y+lognbsp+logSI+SA_Y+Div_SA+Div_Y,
               weights=wi,data=glmnet.dat,
               lambda=lambda_values,#covers range of no suppression to max of 1se
               alpha=0)#0=ridge regression
coef(nbc.gl)
check<-coef(nbc.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  nbc.gl2<-glmnet(AGB_corr~logSA+Y+lognbsp+logSI+SA_Y+Div_SA+Div_Y,
                  weights=wi,data=newdat,
                  lambda=lambda_values,
                  alpha=0)
  coef(nbc.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          lognbsp=unlist(apply(coeff.se[,grep("^lognbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

nbcT_1se<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),
                     mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_1se$mean.nbc<-apply(coeff.se_tidy,2,mean)
nbcT_1se$up.nbc<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
nbcT_1se$low.nbc<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
manbsp_sc_summary<-summary(manbsp_sc)$beta
nbcT_multi<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),
                       mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi$mean.nbc<-manbsp_sc_summary[,1]
nbcT_multi$up.nbc<-manbsp_sc_summary[,1]+manbsp_sc_summary[,2]
nbcT_multi$low.nbc<-manbsp_sc_summary[,1]-manbsp_sc_summary[,2]

#Temporal autoregressive
manbsp_Tmp_sc<-lme(AGB~logSA_sc+Y_sc+lognbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:lognbsp_sc)+(Y_sc:lognbsp_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
nbcT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_Tmp$mean.nbc<-summary(manbsp_Tmp_sc)$tTable[,1]
nbcT_multi_Tmp$up.nbc<-summary(manbsp_Tmp_sc)$tTable[,1]+summary(manbsp_Tmp_sc)$tTable[,2]
nbcT_multi_Tmp$low.nbc<-summary(manbsp_Tmp_sc)$tTable[,1]-summary(manbsp_Tmp_sc)$tTable[,2]

#lmer
manbsp_lmer_sc<-lmer(AGB~logSA_sc+Y_sc+lognbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:lognbsp_sc)+(Y_sc:lognbsp_sc)+
                            (1|Plotnumber),weights=wi,absk)
nbcT_multi_lmer<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_lmer$mean.nbc<-summary(manbsp_lmer_sc)$co[,1]
nbcT_multi_lmer$up.nbc<-summary(manbsp_lmer_sc)$co[,1]+summary(manbsp_lmer_sc)$co[,2]
nbcT_multi_lmer$low.nbc<-summary(manbsp_lmer_sc)$co[,1]-summary(manbsp_lmer_sc)$co[,2]

#nonpara
nmanbsp<-rfit(AGB_corr~logSA+Y+lognbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=glmnet.dat)
summary(nmanbsp)$co

nbcT_multi_NP<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"),
                          mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_NP$mean.nbc<-summary(nmanbsp)$co[,1]
nbcT_multi_NP$up.nbc<-summary(nmanbsp)$co[,1]+summary(nmanbsp)$co[,2]
nbcT_multi_NP$low.nbc<-summary(nmanbsp)$co[,1]-summary(nmanbsp)$co[,2]

#Sequential
manbsp_resid1<-lm(resid(ma_seq_sc)~Y+lognbsp+(logSA:Y)+(logSA:lognbsp)+(Y:lognbsp),
                  weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(manbsp_resid1))

nbcT_multi_seq<-data.table(Source=c("Int","logSA","Y","lognbsp","logSI","SA_Y","Div_SA","Div_Y"))

nbcT_multi_seq[Source=="logSA",mean.nbc:=ma_seq_sc_summary["logSA_sc",1]]
nbcT_multi_seq[Source=="Y",mean.nbc:=coef(summary(manbsp_resid1))["Y",1]]
nbcT_multi_seq[Source=="lognbsp",mean.nbc:=coef(summary(manbsp_resid1))["lognbsp",1]]
nbcT_multi_seq[Source=="logSI",mean.nbc:=ma_seq_sc_summary["logSI_sc",1]]
nbcT_multi_seq[Source=="SA_Y",mean.nbc:=coef(summary(manbsp_resid1))["Y:logSA",1]]
nbcT_multi_seq[Source=="Div_SA",mean.nbc:=coef(summary(manbsp_resid1))["lognbsp:logSA",1]]
nbcT_multi_seq[Source=="Div_Y",mean.nbc:=coef(summary(manbsp_resid1))["Y:lognbsp",1]]

nbcT_multi_seq[Source=="logSA",up.nbc:=ma_seq_sc_summary["logSA_sc",1]+
                  ma_seq_sc_summary["logSA_sc",2]]
nbcT_multi_seq[Source=="Y",up.nbc:=coef(summary(manbsp_resid1))["Y",1]+
                  coef(summary(manbsp_resid1))["Y",2]]
nbcT_multi_seq[Source=="lognbsp",up.nbc:=coef(summary(manbsp_resid1))["lognbsp",1]+
                  coef(summary(manbsp_resid1))["lognbsp",2]]
nbcT_multi_seq[Source=="logSI",up.nbc:=ma_seq_sc_summary["logSI_sc",1]+
                  ma_seq_sc_summary["logSI_sc",2]]
nbcT_multi_seq[Source=="SA_Y",up.nbc:=coef(summary(manbsp_resid1))["Y:logSA",1]+
                  coef(summary(manbsp_resid1))["Y:logSA",2]]
nbcT_multi_seq[Source=="Div_SA",up.nbc:=coef(summary(manbsp_resid1))["lognbsp:logSA",1]+
                  coef(summary(manbsp_resid1))["lognbsp:logSA",2]]
nbcT_multi_seq[Source=="Div_Y",up.nbc:=coef(summary(manbsp_resid1))["Y:lognbsp",1]+
                  coef(summary(manbsp_resid1))["Y:lognbsp",2]]

nbcT_multi_seq[Source=="logSA",low.nbc:=ma_seq_sc_summary["logSA_sc",1]-
                  ma_seq_sc_summary["logSA_sc",2]]
nbcT_multi_seq[Source=="Y",low.nbc:=coef(summary(manbsp_resid1))["Y",1]-
                  coef(summary(manbsp_resid1))["Y",2]]
nbcT_multi_seq[Source=="lognbsp",low.nbc:=coef(summary(manbsp_resid1))["lognbsp",1]-
                  coef(summary(manbsp_resid1))["lognbsp",2]]
nbcT_multi_seq[Source=="logSI",low.nbc:=ma_seq_sc_summary["logSI_sc",1]-
                  ma_seq_sc_summary["logSI_sc",2]]
nbcT_multi_seq[Source=="SA_Y",low.nbc:=coef(summary(manbsp_resid1))["Y:logSA",1]-
                  coef(summary(manbsp_resid1))["Y:logSA",2]]
nbcT_multi_seq[Source=="Div_SA",low.nbc:=coef(summary(manbsp_resid1))["lognbsp:logSA",1]-
                  coef(summary(manbsp_resid1))["lognbsp:logSA",2]]
nbcT_multi_seq[Source=="Div_Y",low.nbc:=coef(summary(manbsp_resid1))["Y:lognbsp",1]-
                  coef(summary(manbsp_resid1))["Y:lognbsp",2]]

#Bind
nbcT_multi_lmer$model<-"Linear mixed effects"
nbcT_multi_Tmp$model<-"Temporal autoregressive"
nbcT_multi$model<-"Spatial autoregressive"
nbcT_1se$model<-"Ridge regression"
nbcT_multi_NP$model<-"Nonparametric"
nbcT_multi_seq$model<-"Sequential"

to_gg<-rbind(nbcT_multi_lmer,nbcT_multi_Tmp,nbcT_multi,nbcT_1se,nbcT_multi_NP,nbcT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="lognbsp",Source:="logSorg"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*logSorg"];to_gg[Source=="Div_Y",Source:="Y*logSorg"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","logSorg","logSA*Y","logSA*logSorg","Y*logSorg"))

NBCSorg<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.nbc,ymin=low.nbc,ymax=up.nbc,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.7),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+
  guides(col=FALSE)
NBCSorg

## Sarea (std)
################################## Grow ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,logstd_nbsp=logstd_nbsp,logSI=logSI,Div_SA=logstd_nbsp*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*logstd_nbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_Grow_Sarea_sc_HossfeldSI.R")
glmnet.dat[,AGBGI_corr:=residuals(mbstd_nbsp_sc,type="response")+
             mbstd_nbsp_sc$fixef[1]+
             (mbstd_nbsp_sc$fixef[2]*logSA)+
             (mbstd_nbsp_sc$fixef[3]*Y)+
             (mbstd_nbsp_sc$fixef[4]*logstd_nbsp)+
             (mbstd_nbsp_sc$fixef[5]*logSI)+
             (mbstd_nbsp_sc$fixef[6]*logSA*Y)+
             (mbstd_nbsp_sc$fixef[7]*logSA*logstd_nbsp)+
             (mbstd_nbsp_sc$fixef[8]*Y*logstd_nbsp)]

mod_lm_corr<-lm(AGBGI_corr~logSA+Y+logstd_nbsp+logSI+
                  (logSA:Y)+(logSA:logstd_nbsp)+
                  (Y:logstd_nbsp),glmnet.dat,weights=wi)
summary(residuals(mbstd_nbsp_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,logstd_nbsp,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGBGI_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

grow.gl<-glmnet(AGBGI_corr~logSA+Y+logstd_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                weights=wi,data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(grow.gl)
check<-coef(grow.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  grow.gl2<-glmnet(AGBGI_corr~logSA+Y+logstd_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(grow.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          logstd_nbsp=unlist(apply(coeff.se[,grep("^logstd_nbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

growT_1se<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                      mean.gr=NA,up.gr=NA,low.gr=NA)

growT_1se$mean.gr<-apply(coeff.se_tidy,2,mean)
growT_1se$up.gr<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
growT_1se$low.gr<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
mbstd_nbsp_sc_summary<-summary(mbstd_nbsp_sc)$beta
growT_multi<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                        mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi$mean.gr<-mbstd_nbsp_sc_summary[,1]
growT_multi$up.gr<-mbstd_nbsp_sc_summary[,1]+mbstd_nbsp_sc_summary[,2]
growT_multi$low.gr<-mbstd_nbsp_sc_summary[,1]-mbstd_nbsp_sc_summary[,2]

#Temporal autoregressive
mbstd_nbsp_Tmp_sc<-lme(AGBGI~logSA_sc+Y_sc+logstd_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:logstd_nbsp_sc)+(Y_sc:logstd_nbsp_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
growT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_Tmp$mean.gr<-summary(mbstd_nbsp_Tmp_sc)$tTable[,1]
growT_multi_Tmp$up.gr<-summary(mbstd_nbsp_Tmp_sc)$tTable[,1]+summary(mbstd_nbsp_Tmp_sc)$tTable[,2]
growT_multi_Tmp$low.gr<-summary(mbstd_nbsp_Tmp_sc)$tTable[,1]-summary(mbstd_nbsp_Tmp_sc)$tTable[,2]

#lmer
mbstd_nbsp_lmer_sc<-lmer(AGBGI~logSA_sc+Y_sc+logstd_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:logstd_nbsp_sc)+(Y_sc:logstd_nbsp_sc)+
                            (1|Plotnumber),weights=wi,absk)
growT_multi_lmer<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                             mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_lmer$mean.gr<-summary(mbstd_nbsp_lmer_sc)$co[,1]
growT_multi_lmer$up.gr<-summary(mbstd_nbsp_lmer_sc)$co[,1]+summary(mbstd_nbsp_lmer_sc)$co[,2]
growT_multi_lmer$low.gr<-summary(mbstd_nbsp_lmer_sc)$co[,1]-summary(mbstd_nbsp_lmer_sc)$co[,2]

#nonpara
nmbstd_nbsp<-rfit(AGBGI_corr~logSA+Y+logstd_nbsp+logSI+SA_Y+Div_SA+Div_Y,
              weights=wi,data=glmnet.dat)
summary(nmbstd_nbsp)$co

growT_multi_NP<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_NP$mean.gr<-summary(nmbstd_nbsp)$co[,1]
growT_multi_NP$up.gr<-summary(nmbstd_nbsp)$co[,1]+summary(nmbstd_nbsp)$co[,2]
growT_multi_NP$low.gr<-summary(nmbstd_nbsp)$co[,1]-summary(nmbstd_nbsp)$co[,2]

#Sequential
mbstd_nbsp_resid1<-lm(resid(mb_seq_sc)~Y+logstd_nbsp+(logSA:Y)+(logSA:logstd_nbsp)+(Y:logstd_nbsp),
                  weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(mbstd_nbsp_resid1))

growT_multi_seq<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"))

growT_multi_seq[Source=="logSA",mean.gr:=mb_seq_sc_summary["logSA_sc",1]]
growT_multi_seq[Source=="Y",mean.gr:=coef(summary(mbstd_nbsp_resid1))["Y",1]]
growT_multi_seq[Source=="logstd_nbsp",mean.gr:=coef(summary(mbstd_nbsp_resid1))["logstd_nbsp",1]]
growT_multi_seq[Source=="logSI",mean.gr:=mb_seq_sc_summary["logSI_sc",1]]
growT_multi_seq[Source=="SA_Y",mean.gr:=coef(summary(mbstd_nbsp_resid1))["Y:logSA",1]]
growT_multi_seq[Source=="Div_SA",mean.gr:=coef(summary(mbstd_nbsp_resid1))["logstd_nbsp:logSA",1]]
growT_multi_seq[Source=="Div_Y",mean.gr:=coef(summary(mbstd_nbsp_resid1))["Y:logstd_nbsp",1]]

growT_multi_seq[Source=="logSA",up.gr:=mb_seq_sc_summary["logSA_sc",1]+
                  mb_seq_sc_summary["logSA_sc",2]]
growT_multi_seq[Source=="Y",up.gr:=coef(summary(mbstd_nbsp_resid1))["Y",1]+
                  coef(summary(mbstd_nbsp_resid1))["Y",2]]
growT_multi_seq[Source=="logstd_nbsp",up.gr:=coef(summary(mbstd_nbsp_resid1))["logstd_nbsp",1]+
                  coef(summary(mbstd_nbsp_resid1))["logstd_nbsp",2]]
growT_multi_seq[Source=="logSI",up.gr:=mb_seq_sc_summary["logSI_sc",1]+
                  mb_seq_sc_summary["logSI_sc",2]]
growT_multi_seq[Source=="SA_Y",up.gr:=coef(summary(mbstd_nbsp_resid1))["Y:logSA",1]+
                  coef(summary(mbstd_nbsp_resid1))["Y:logSA",2]]
growT_multi_seq[Source=="Div_SA",up.gr:=coef(summary(mbstd_nbsp_resid1))["logstd_nbsp:logSA",1]+
                  coef(summary(mbstd_nbsp_resid1))["logstd_nbsp:logSA",2]]
growT_multi_seq[Source=="Div_Y",up.gr:=coef(summary(mbstd_nbsp_resid1))["Y:logstd_nbsp",1]+
                  coef(summary(mbstd_nbsp_resid1))["Y:logstd_nbsp",2]]

growT_multi_seq[Source=="logSA",low.gr:=mb_seq_sc_summary["logSA_sc",1]-
                  mb_seq_sc_summary["logSA_sc",2]]
growT_multi_seq[Source=="Y",low.gr:=coef(summary(mbstd_nbsp_resid1))["Y",1]-
                  coef(summary(mbstd_nbsp_resid1))["Y",2]]
growT_multi_seq[Source=="logstd_nbsp",low.gr:=coef(summary(mbstd_nbsp_resid1))["logstd_nbsp",1]-
                  coef(summary(mbstd_nbsp_resid1))["logstd_nbsp",2]]
growT_multi_seq[Source=="logSI",low.gr:=mb_seq_sc_summary["logSI_sc",1]-
                  mb_seq_sc_summary["logSI_sc",2]]
growT_multi_seq[Source=="SA_Y",low.gr:=coef(summary(mbstd_nbsp_resid1))["Y:logSA",1]-
                  coef(summary(mbstd_nbsp_resid1))["Y:logSA",2]]
growT_multi_seq[Source=="Div_SA",low.gr:=coef(summary(mbstd_nbsp_resid1))["logstd_nbsp:logSA",1]-
                  coef(summary(mbstd_nbsp_resid1))["logstd_nbsp:logSA",2]]
growT_multi_seq[Source=="Div_Y",low.gr:=coef(summary(mbstd_nbsp_resid1))["Y:logstd_nbsp",1]-
                  coef(summary(mbstd_nbsp_resid1))["Y:logstd_nbsp",2]]

#Bind
growT_multi_lmer$model<-"Linear mixed effects"
growT_multi_Tmp$model<-"Temporal autoregressive"
growT_multi$model<-"Spatial autoregressive"
growT_1se$model<-"Ridge regression"
growT_multi_NP$model<-"Nonparametric"
growT_multi_seq$model<-"Sequential"

to_gg<-rbind(growT_multi_lmer,growT_multi_Tmp,growT_multi,growT_1se,growT_multi_NP,growT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="logstd_nbsp",Source:="logSarea"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*logSarea"];to_gg[Source=="Div_Y",Source:="Y*logSarea"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","logSarea","logSA*Y","logSA*logSarea","Y*logSarea"))

GrowSarea<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.gr,ymin=low.gr,ymax=up.gr,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.7),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+
  guides(col=FALSE)
GrowSarea

################################## Mortality ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,Spstd_nbsp=Spstd_nbsp,logSI=logSI,Div_SA=Spstd_nbsp*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*Spstd_nbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_Mort_Sarea_sc_HossfeldSI.R")
glmnet.dat[,AGBM_corr:=residuals(mcstd_nbsp_sc,type="response")+
             mcstd_nbsp_sc$fixef[1]+
             (mcstd_nbsp_sc$fixef[2]*logSA)+
             (mcstd_nbsp_sc$fixef[3]*Y)+
             (mcstd_nbsp_sc$fixef[4]*Spstd_nbsp)+
             (mcstd_nbsp_sc$fixef[5]*logSI)+
             (mcstd_nbsp_sc$fixef[6]*logSA*Y)+
             (mcstd_nbsp_sc$fixef[7]*logSA*Spstd_nbsp)+
             (mcstd_nbsp_sc$fixef[8]*Y*Spstd_nbsp)]

mod_lm_corr<-lm(AGBM_corr~logSA+Y+Spstd_nbsp+logSI+
                  (logSA:Y)+(logSA:Spstd_nbsp)+
                  (Y:Spstd_nbsp),glmnet.dat,weights=wi)
summary(residuals(mcstd_nbsp_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,Spstd_nbsp,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGBM_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

mort.gl<-glmnet(AGBM_corr~logSA+Y+Spstd_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                weights=wi,data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(mort.gl)
check<-coef(mort.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  mort.gl2<-glmnet(AGBM_corr~logSA+Y+Spstd_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(mort.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","Spstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Spstd_nbsp=unlist(apply(coeff.se[,grep("^Spstd_nbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

mortT_1se<-data.table(Source=c("Int","logSA","Y","Spstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                      mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_1se$mean.mort<-apply(coeff.se_tidy,2,mean)
mortT_1se$up.mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
mortT_1se$low.mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
mcstd_nbsp_sc_summary<-summary(mcstd_nbsp_sc)$beta
mortT_multi<-data.table(Source=c("Int","logSA","Y","Spstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                        mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi$mean.mort<-mcstd_nbsp_sc_summary[,1]
mortT_multi$up.mort<-mcstd_nbsp_sc_summary[,1]+mcstd_nbsp_sc_summary[,2]
mortT_multi$low.mort<-mcstd_nbsp_sc_summary[,1]-mcstd_nbsp_sc_summary[,2]

#Temporal autoregressive
mcstd_nbsp_Tmp_sc<-lme(AGBM~logSA_sc+Y_sc+Spstd_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:Spstd_nbsp_sc)+(Y_sc:Spstd_nbsp_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
mortT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","Spstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_Tmp$mean.mort<-summary(mcstd_nbsp_Tmp_sc)$tTable[,1]
mortT_multi_Tmp$up.mort<-summary(mcstd_nbsp_Tmp_sc)$tTable[,1]+summary(mcstd_nbsp_Tmp_sc)$tTable[,2]
mortT_multi_Tmp$low.mort<-summary(mcstd_nbsp_Tmp_sc)$tTable[,1]-summary(mcstd_nbsp_Tmp_sc)$tTable[,2]

#lmer
mcstd_nbsp_lmer_sc<-lmer(AGBM~logSA_sc+Y_sc+Spstd_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:Spstd_nbsp_sc)+(Y_sc:Spstd_nbsp_sc)+
                            (1|Plotnumber),weights=wi,absk)
mortT_multi_lmer<-data.table(Source=c("Int","logSA","Y","Spstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                             mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_lmer$mean.mort<-summary(mcstd_nbsp_lmer_sc)$co[,1]
mortT_multi_lmer$up.mort<-summary(mcstd_nbsp_lmer_sc)$co[,1]+summary(mcstd_nbsp_lmer_sc)$co[,2]
mortT_multi_lmer$low.mort<-summary(mcstd_nbsp_lmer_sc)$co[,1]-summary(mcstd_nbsp_lmer_sc)$co[,2]

#nonpara
nmcstd_nbsp<-rfit(AGBM_corr~logSA+Y+Spstd_nbsp+logSI+SA_Y+Div_SA+Div_Y,
              weights=wi,data=glmnet.dat)
summary(nmcstd_nbsp)$co

mortT_multi_NP<-data.table(Source=c("Int","logSA","Y","Spstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_NP$mean.mort<-summary(nmcstd_nbsp)$co[,1]
mortT_multi_NP$up.mort<-summary(nmcstd_nbsp)$co[,1]+summary(nmcstd_nbsp)$co[,2]
mortT_multi_NP$low.mort<-summary(nmcstd_nbsp)$co[,1]-summary(nmcstd_nbsp)$co[,2]

#Sequential
mcstd_nbsp_resid1<-lm(resid(mc_seq_sc)~Y+Spstd_nbsp+(logSA:Y)+(logSA:Spstd_nbsp)+(Y:Spstd_nbsp),
                  weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(mcstd_nbsp_resid1))

mortT_multi_seq<-data.table(Source=c("Int","logSA","Y","Spstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"))

mortT_multi_seq[Source=="logSA",mean.mort:=mc_seq_sc_summary["logSA_sc",1]]
mortT_multi_seq[Source=="Y",mean.mort:=coef(summary(mcstd_nbsp_resid1))["Y",1]]
mortT_multi_seq[Source=="Spstd_nbsp",mean.mort:=coef(summary(mcstd_nbsp_resid1))["Spstd_nbsp",1]]
mortT_multi_seq[Source=="logSI",mean.mort:=mc_seq_sc_summary["logSI_sc",1]]
mortT_multi_seq[Source=="SA_Y",mean.mort:=coef(summary(mcstd_nbsp_resid1))["Y:logSA",1]]
mortT_multi_seq[Source=="Div_SA",mean.mort:=coef(summary(mcstd_nbsp_resid1))["Spstd_nbsp:logSA",1]]
mortT_multi_seq[Source=="Div_Y",mean.mort:=coef(summary(mcstd_nbsp_resid1))["Y:Spstd_nbsp",1]]

mortT_multi_seq[Source=="logSA",up.mort:=mc_seq_sc_summary["logSA_sc",1]+
                  mc_seq_sc_summary["logSA_sc",2]]
mortT_multi_seq[Source=="Y",up.mort:=coef(summary(mcstd_nbsp_resid1))["Y",1]+
                  coef(summary(mcstd_nbsp_resid1))["Y",2]]
mortT_multi_seq[Source=="Spstd_nbsp",up.mort:=coef(summary(mcstd_nbsp_resid1))["Spstd_nbsp",1]+
                  coef(summary(mcstd_nbsp_resid1))["Spstd_nbsp",2]]
mortT_multi_seq[Source=="logSI",up.mort:=mc_seq_sc_summary["logSI_sc",1]+
                  mc_seq_sc_summary["logSI_sc",2]]
mortT_multi_seq[Source=="SA_Y",up.mort:=coef(summary(mcstd_nbsp_resid1))["Y:logSA",1]+
                  coef(summary(mcstd_nbsp_resid1))["Y:logSA",2]]
mortT_multi_seq[Source=="Div_SA",up.mort:=coef(summary(mcstd_nbsp_resid1))["Spstd_nbsp:logSA",1]+
                  coef(summary(mcstd_nbsp_resid1))["Spstd_nbsp:logSA",2]]
mortT_multi_seq[Source=="Div_Y",up.mort:=coef(summary(mcstd_nbsp_resid1))["Y:Spstd_nbsp",1]+
                  coef(summary(mcstd_nbsp_resid1))["Y:Spstd_nbsp",2]]

mortT_multi_seq[Source=="logSA",low.mort:=mc_seq_sc_summary["logSA_sc",1]-
                  mc_seq_sc_summary["logSA_sc",2]]
mortT_multi_seq[Source=="Y",low.mort:=coef(summary(mcstd_nbsp_resid1))["Y",1]-
                  coef(summary(mcstd_nbsp_resid1))["Y",2]]
mortT_multi_seq[Source=="Spstd_nbsp",low.mort:=coef(summary(mcstd_nbsp_resid1))["Spstd_nbsp",1]-
                  coef(summary(mcstd_nbsp_resid1))["Spstd_nbsp",2]]
mortT_multi_seq[Source=="logSI",low.mort:=mc_seq_sc_summary["logSI_sc",1]-
                  mc_seq_sc_summary["logSI_sc",2]]
mortT_multi_seq[Source=="SA_Y",low.mort:=coef(summary(mcstd_nbsp_resid1))["Y:logSA",1]-
                  coef(summary(mcstd_nbsp_resid1))["Y:logSA",2]]
mortT_multi_seq[Source=="Div_SA",low.mort:=coef(summary(mcstd_nbsp_resid1))["Spstd_nbsp:logSA",1]-
                  coef(summary(mcstd_nbsp_resid1))["Spstd_nbsp:logSA",2]]
mortT_multi_seq[Source=="Div_Y",low.mort:=coef(summary(mcstd_nbsp_resid1))["Y:Spstd_nbsp",1]-
                  coef(summary(mcstd_nbsp_resid1))["Y:Spstd_nbsp",2]]

#Bind
mortT_multi_lmer$model<-"Linear mixed effects"
mortT_multi_Tmp$model<-"Temporal autoregressive"
mortT_multi$model<-"Spatial autoregressive"
mortT_1se$model<-"Ridge regression"
mortT_multi_NP$model<-"Nonparametric"
mortT_multi_seq$model<-"Sequential"

to_gg<-rbind(mortT_multi_lmer,mortT_multi_Tmp,mortT_multi,mortT_1se,mortT_multi_NP,mortT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="Spstd_nbsp",Source:="Sarea"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*Sarea"];to_gg[Source=="Div_Y",Source:="Y*Sarea"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","Sarea","logSA*Y","logSA*Sarea","Y*Sarea"))

MortSarea<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.mort,ymin=low.mort,ymax=up.mort,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.7),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+
  guides(col=FALSE)
MortSarea

################################## NBC ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,logstd_nbsp=logstd_nbsp,logSI=logSI,Div_SA=logstd_nbsp*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*logstd_nbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_NBC_Sarea_sc_HossfeldSI.R")
glmnet.dat[,AGB_corr:=residuals(mastd_nbsp_sc,type="response")+
             mastd_nbsp_sc$fixef[1]+
             (mastd_nbsp_sc$fixef[2]*logSA)+
             (mastd_nbsp_sc$fixef[3]*Y)+
             (mastd_nbsp_sc$fixef[4]*logstd_nbsp)+
             (mastd_nbsp_sc$fixef[5]*logSI)+
             (mastd_nbsp_sc$fixef[6]*logSA*Y)+
             (mastd_nbsp_sc$fixef[7]*logSA*logstd_nbsp)+
             (mastd_nbsp_sc$fixef[8]*Y*logstd_nbsp)]

mod_lm_corr<-lm(AGB_corr~logSA+Y+logstd_nbsp+logSI+
                  (logSA:Y)+(logSA:logstd_nbsp)+
                  (Y:logstd_nbsp),glmnet.dat,weights=wi)
summary(residuals(mastd_nbsp_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,logstd_nbsp,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGB_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

nbc.gl<-glmnet(AGB_corr~logSA+Y+logstd_nbsp+logSI+SA_Y+Div_SA+Div_Y,
               weights=wi,data=glmnet.dat,
               lambda=lambda_values,#covers range of no suppression to max of 1se
               alpha=0)#0=ridge regression
coef(nbc.gl)
check<-coef(nbc.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  nbc.gl2<-glmnet(AGB_corr~logSA+Y+logstd_nbsp+logSI+SA_Y+Div_SA+Div_Y,
                  weights=wi,data=newdat,
                  lambda=lambda_values,
                  alpha=0)
  coef(nbc.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          logstd_nbsp=unlist(apply(coeff.se[,grep("^logstd_nbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

nbcT_1se<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                     mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_1se$mean.nbc<-apply(coeff.se_tidy,2,mean)
nbcT_1se$up.nbc<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
nbcT_1se$low.nbc<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
mastd_nbsp_sc_summary<-summary(mastd_nbsp_sc)$beta
nbcT_multi<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                       mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi$mean.nbc<-mastd_nbsp_sc_summary[,1]
nbcT_multi$up.nbc<-mastd_nbsp_sc_summary[,1]+mastd_nbsp_sc_summary[,2]
nbcT_multi$low.nbc<-mastd_nbsp_sc_summary[,1]-mastd_nbsp_sc_summary[,2]

#Temporal autoregressive
mastd_nbsp_Tmp_sc<-lme(AGB~logSA_sc+Y_sc+logstd_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:logstd_nbsp_sc)+(Y_sc:logstd_nbsp_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
nbcT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_Tmp$mean.nbc<-summary(mastd_nbsp_Tmp_sc)$tTable[,1]
nbcT_multi_Tmp$up.nbc<-summary(mastd_nbsp_Tmp_sc)$tTable[,1]+summary(mastd_nbsp_Tmp_sc)$tTable[,2]
nbcT_multi_Tmp$low.nbc<-summary(mastd_nbsp_Tmp_sc)$tTable[,1]-summary(mastd_nbsp_Tmp_sc)$tTable[,2]

#lmer
mastd_nbsp_lmer_sc<-lmer(AGB~logSA_sc+Y_sc+logstd_nbsp_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:logstd_nbsp_sc)+(Y_sc:logstd_nbsp_sc)+
                            (1|Plotnumber),weights=wi,absk)
nbcT_multi_lmer<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_lmer$mean.nbc<-summary(mastd_nbsp_lmer_sc)$co[,1]
nbcT_multi_lmer$up.nbc<-summary(mastd_nbsp_lmer_sc)$co[,1]+summary(mastd_nbsp_lmer_sc)$co[,2]
nbcT_multi_lmer$low.nbc<-summary(mastd_nbsp_lmer_sc)$co[,1]-summary(mastd_nbsp_lmer_sc)$co[,2]

#nonpara
nmastd_nbsp<-rfit(AGB_corr~logSA+Y+logstd_nbsp+logSI+SA_Y+Div_SA+Div_Y,
              weights=wi,data=glmnet.dat)
summary(nmastd_nbsp)$co

nbcT_multi_NP<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"),
                          mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_NP$mean.nbc<-summary(nmastd_nbsp)$co[,1]
nbcT_multi_NP$up.nbc<-summary(nmastd_nbsp)$co[,1]+summary(nmastd_nbsp)$co[,2]
nbcT_multi_NP$low.nbc<-summary(nmastd_nbsp)$co[,1]-summary(nmastd_nbsp)$co[,2]

#Sequential
mastd_nbsp_resid1<-lm(resid(ma_seq_sc)~Y+logstd_nbsp+(logSA:Y)+(logSA:logstd_nbsp)+(Y:logstd_nbsp),
                  weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(mastd_nbsp_resid1))

nbcT_multi_seq<-data.table(Source=c("Int","logSA","Y","logstd_nbsp","logSI","SA_Y","Div_SA","Div_Y"))

nbcT_multi_seq[Source=="logSA",mean.nbc:=ma_seq_sc_summary["logSA_sc",1]]
nbcT_multi_seq[Source=="Y",mean.nbc:=coef(summary(mastd_nbsp_resid1))["Y",1]]
nbcT_multi_seq[Source=="logstd_nbsp",mean.nbc:=coef(summary(mastd_nbsp_resid1))["logstd_nbsp",1]]
nbcT_multi_seq[Source=="logSI",mean.nbc:=ma_seq_sc_summary["logSI_sc",1]]
nbcT_multi_seq[Source=="SA_Y",mean.nbc:=coef(summary(mastd_nbsp_resid1))["Y:logSA",1]]
nbcT_multi_seq[Source=="Div_SA",mean.nbc:=coef(summary(mastd_nbsp_resid1))["logstd_nbsp:logSA",1]]
nbcT_multi_seq[Source=="Div_Y",mean.nbc:=coef(summary(mastd_nbsp_resid1))["Y:logstd_nbsp",1]]

nbcT_multi_seq[Source=="logSA",up.nbc:=ma_seq_sc_summary["logSA_sc",1]+
                 ma_seq_sc_summary["logSA_sc",2]]
nbcT_multi_seq[Source=="Y",up.nbc:=coef(summary(mastd_nbsp_resid1))["Y",1]+
                 coef(summary(mastd_nbsp_resid1))["Y",2]]
nbcT_multi_seq[Source=="logstd_nbsp",up.nbc:=coef(summary(mastd_nbsp_resid1))["logstd_nbsp",1]+
                 coef(summary(mastd_nbsp_resid1))["logstd_nbsp",2]]
nbcT_multi_seq[Source=="logSI",up.nbc:=ma_seq_sc_summary["logSI_sc",1]+
                 ma_seq_sc_summary["logSI_sc",2]]
nbcT_multi_seq[Source=="SA_Y",up.nbc:=coef(summary(mastd_nbsp_resid1))["Y:logSA",1]+
                 coef(summary(mastd_nbsp_resid1))["Y:logSA",2]]
nbcT_multi_seq[Source=="Div_SA",up.nbc:=coef(summary(mastd_nbsp_resid1))["logstd_nbsp:logSA",1]+
                 coef(summary(mastd_nbsp_resid1))["logstd_nbsp:logSA",2]]
nbcT_multi_seq[Source=="Div_Y",up.nbc:=coef(summary(mastd_nbsp_resid1))["Y:logstd_nbsp",1]+
                 coef(summary(mastd_nbsp_resid1))["Y:logstd_nbsp",2]]

nbcT_multi_seq[Source=="logSA",low.nbc:=ma_seq_sc_summary["logSA_sc",1]-
                 ma_seq_sc_summary["logSA_sc",2]]
nbcT_multi_seq[Source=="Y",low.nbc:=coef(summary(mastd_nbsp_resid1))["Y",1]-
                 coef(summary(mastd_nbsp_resid1))["Y",2]]
nbcT_multi_seq[Source=="logstd_nbsp",low.nbc:=coef(summary(mastd_nbsp_resid1))["logstd_nbsp",1]-
                 coef(summary(mastd_nbsp_resid1))["logstd_nbsp",2]]
nbcT_multi_seq[Source=="logSI",low.nbc:=ma_seq_sc_summary["logSI_sc",1]-
                 ma_seq_sc_summary["logSI_sc",2]]
nbcT_multi_seq[Source=="SA_Y",low.nbc:=coef(summary(mastd_nbsp_resid1))["Y:logSA",1]-
                 coef(summary(mastd_nbsp_resid1))["Y:logSA",2]]
nbcT_multi_seq[Source=="Div_SA",low.nbc:=coef(summary(mastd_nbsp_resid1))["logstd_nbsp:logSA",1]-
                 coef(summary(mastd_nbsp_resid1))["logstd_nbsp:logSA",2]]
nbcT_multi_seq[Source=="Div_Y",low.nbc:=coef(summary(mastd_nbsp_resid1))["Y:logstd_nbsp",1]-
                 coef(summary(mastd_nbsp_resid1))["Y:logstd_nbsp",2]]

#Bind
nbcT_multi_lmer$model<-"Linear mixed effects"
nbcT_multi_Tmp$model<-"Temporal autoregressive"
nbcT_multi$model<-"Spatial autoregressive"
nbcT_1se$model<-"Ridge regression"
nbcT_multi_NP$model<-"Nonparametric"
nbcT_multi_seq$model<-"Sequential"

to_gg<-rbind(nbcT_multi_lmer,nbcT_multi_Tmp,nbcT_multi,nbcT_1se,nbcT_multi_NP,nbcT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="logstd_nbsp",Source:="logSarea"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*logSarea"];to_gg[Source=="Div_Y",Source:="Y*logSarea"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","logSarea","logSA*Y","logSA*logSarea","Y*logSarea"))

NBCSarea<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.nbc,ymin=low.nbc,ymax=up.nbc,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.7),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+
  guides(col=FALSE)
NBCSarea

## Shann (H')
################################## Grow ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,logShann=logShann,logSI=logSI,Div_SA=logShann*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*logShann)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_Grow_Shann_sc_HossfeldSI.R")
glmnet.dat[,AGBGI_corr:=residuals(mbShann_sc,type="response")+
             mbShann_sc$fixef[1]+
             (mbShann_sc$fixef[2]*logSA)+
             (mbShann_sc$fixef[3]*Y)+
             (mbShann_sc$fixef[4]*logShann)+
             (mbShann_sc$fixef[5]*logSI)+
             (mbShann_sc$fixef[6]*logSA*Y)+
             (mbShann_sc$fixef[7]*logSA*logShann)+
             (mbShann_sc$fixef[8]*Y*logShann)]

mod_lm_corr<-lm(AGBGI_corr~logSA+Y+logShann+logSI+
                  (logSA:Y)+(logSA:logShann)+
                  (Y:logShann),glmnet.dat,weights=wi)
summary(residuals(mbShann_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,logShann,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGBGI_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

grow.gl<-glmnet(AGBGI_corr~logSA+Y+logShann+logSI+SA_Y+Div_SA+Div_Y,
                weights=wi,data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(grow.gl)
check<-coef(grow.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  grow.gl2<-glmnet(AGBGI_corr~logSA+Y+logShann+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(grow.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          logShann=unlist(apply(coeff.se[,grep("^logShann$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

growT_1se<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),
                      mean.gr=NA,up.gr=NA,low.gr=NA)

growT_1se$mean.gr<-apply(coeff.se_tidy,2,mean)
growT_1se$up.gr<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
growT_1se$low.gr<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
mbShann_sc_summary<-summary(mbShann_sc)$beta
growT_multi<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),
                        mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi$mean.gr<-mbShann_sc_summary[,1]
growT_multi$up.gr<-mbShann_sc_summary[,1]+mbShann_sc_summary[,2]
growT_multi$low.gr<-mbShann_sc_summary[,1]-mbShann_sc_summary[,2]

#Temporal autoregressive
mbShann_Tmp_sc<-lme(AGBGI~logSA_sc+Y_sc+logShann_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:logShann_sc)+(Y_sc:logShann_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
growT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_Tmp$mean.gr<-summary(mbShann_Tmp_sc)$tTable[,1]
growT_multi_Tmp$up.gr<-summary(mbShann_Tmp_sc)$tTable[,1]+summary(mbShann_Tmp_sc)$tTable[,2]
growT_multi_Tmp$low.gr<-summary(mbShann_Tmp_sc)$tTable[,1]-summary(mbShann_Tmp_sc)$tTable[,2]

#lmer
mbShann_lmer_sc<-lmer(AGBGI~logSA_sc+Y_sc+logShann_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:logShann_sc)+(Y_sc:logShann_sc)+
                            (1|Plotnumber),weights=wi,absk)
growT_multi_lmer<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),
                             mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_lmer$mean.gr<-summary(mbShann_lmer_sc)$co[,1]
growT_multi_lmer$up.gr<-summary(mbShann_lmer_sc)$co[,1]+summary(mbShann_lmer_sc)$co[,2]
growT_multi_lmer$low.gr<-summary(mbShann_lmer_sc)$co[,1]-summary(mbShann_lmer_sc)$co[,2]

#nonpara
nmbShann<-rfit(AGBGI_corr~logSA+Y+logShann+logSI+SA_Y+Div_SA+Div_Y,
              weights=wi,data=glmnet.dat)
summary(nmbShann)$co

growT_multi_NP<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_NP$mean.gr<-summary(nmbShann)$co[,1]
growT_multi_NP$up.gr<-summary(nmbShann)$co[,1]+summary(nmbShann)$co[,2]
growT_multi_NP$low.gr<-summary(nmbShann)$co[,1]-summary(nmbShann)$co[,2]

#Sequential
mbShann_resid1<-lm(resid(mb_seq_sc)~Y+logShann+(logSA:Y)+(logSA:logShann)+(Y:logShann),
                  weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(mbShann_resid1))

growT_multi_seq<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"))

growT_multi_seq[Source=="logSA",mean.gr:=mb_seq_sc_summary["logSA_sc",1]]
growT_multi_seq[Source=="Y",mean.gr:=coef(summary(mbShann_resid1))["Y",1]]
growT_multi_seq[Source=="logShann",mean.gr:=coef(summary(mbShann_resid1))["logShann",1]]
growT_multi_seq[Source=="logSI",mean.gr:=mb_seq_sc_summary["logSI_sc",1]]
growT_multi_seq[Source=="SA_Y",mean.gr:=coef(summary(mbShann_resid1))["Y:logSA",1]]
growT_multi_seq[Source=="Div_SA",mean.gr:=coef(summary(mbShann_resid1))["logShann:logSA",1]]
growT_multi_seq[Source=="Div_Y",mean.gr:=coef(summary(mbShann_resid1))["Y:logShann",1]]

growT_multi_seq[Source=="logSA",up.gr:=mb_seq_sc_summary["logSA_sc",1]+
                  mb_seq_sc_summary["logSA_sc",2]]
growT_multi_seq[Source=="Y",up.gr:=coef(summary(mbShann_resid1))["Y",1]+
                  coef(summary(mbShann_resid1))["Y",2]]
growT_multi_seq[Source=="logShann",up.gr:=coef(summary(mbShann_resid1))["logShann",1]+
                  coef(summary(mbShann_resid1))["logShann",2]]
growT_multi_seq[Source=="logSI",up.gr:=mb_seq_sc_summary["logSI_sc",1]+
                  mb_seq_sc_summary["logSI_sc",2]]
growT_multi_seq[Source=="SA_Y",up.gr:=coef(summary(mbShann_resid1))["Y:logSA",1]+
                  coef(summary(mbShann_resid1))["Y:logSA",2]]
growT_multi_seq[Source=="Div_SA",up.gr:=coef(summary(mbShann_resid1))["logShann:logSA",1]+
                  coef(summary(mbShann_resid1))["logShann:logSA",2]]
growT_multi_seq[Source=="Div_Y",up.gr:=coef(summary(mbShann_resid1))["Y:logShann",1]+
                  coef(summary(mbShann_resid1))["Y:logShann",2]]

growT_multi_seq[Source=="logSA",low.gr:=mb_seq_sc_summary["logSA_sc",1]-
                  mb_seq_sc_summary["logSA_sc",2]]
growT_multi_seq[Source=="Y",low.gr:=coef(summary(mbShann_resid1))["Y",1]-
                  coef(summary(mbShann_resid1))["Y",2]]
growT_multi_seq[Source=="logShann",low.gr:=coef(summary(mbShann_resid1))["logShann",1]-
                  coef(summary(mbShann_resid1))["logShann",2]]
growT_multi_seq[Source=="logSI",low.gr:=mb_seq_sc_summary["logSI_sc",1]-
                  mb_seq_sc_summary["logSI_sc",2]]
growT_multi_seq[Source=="SA_Y",low.gr:=coef(summary(mbShann_resid1))["Y:logSA",1]-
                  coef(summary(mbShann_resid1))["Y:logSA",2]]
growT_multi_seq[Source=="Div_SA",low.gr:=coef(summary(mbShann_resid1))["logShann:logSA",1]-
                  coef(summary(mbShann_resid1))["logShann:logSA",2]]
growT_multi_seq[Source=="Div_Y",low.gr:=coef(summary(mbShann_resid1))["Y:logShann",1]-
                  coef(summary(mbShann_resid1))["Y:logShann",2]]

#Bind
growT_multi_lmer$model<-"Linear mixed effects"
growT_multi_Tmp$model<-"Temporal autoregressive"
growT_multi$model<-"Spatial autoregressive"
growT_1se$model<-"Ridge regression"
growT_multi_NP$model<-"Nonparametric"
growT_multi_seq$model<-"Sequential"

to_gg<-rbind(growT_multi_lmer,growT_multi_Tmp,growT_multi,growT_1se,growT_multi_NP,growT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="logShann",Source:="logShann"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*logShann"];to_gg[Source=="Div_Y",Source:="Y*logShann"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","logShann","logSA*Y","logSA*logShann","Y*logShann"))

GrowShann<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.gr,ymin=low.gr,ymax=up.gr,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.75,0.324),
        legend.title = element_text(size=11),legend.text = element_text(size=9),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+
  guides(col=FALSE)
GrowShann

################################## Mortality ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,SpShann=SpShann,logSI=logSI,Div_SA=SpShann*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*SpShann)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_Mort_Shann_sc_HossfeldSI.R")
glmnet.dat[,AGBM_corr:=residuals(mcShann_sc,type="response")+
             mcShann_sc$fixef[1]+
             (mcShann_sc$fixef[2]*logSA)+
             (mcShann_sc$fixef[3]*Y)+
             (mcShann_sc$fixef[4]*SpShann)+
             (mcShann_sc$fixef[5]*logSI)+
             (mcShann_sc$fixef[6]*logSA*Y)+
             (mcShann_sc$fixef[7]*logSA*SpShann)+
             (mcShann_sc$fixef[8]*Y*SpShann)]

mod_lm_corr<-lm(AGBM_corr~logSA+Y+SpShann+logSI+
                  (logSA:Y)+(logSA:SpShann)+
                  (Y:SpShann),glmnet.dat,weights=wi)
summary(residuals(mcShann_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,SpShann,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGBM_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

mort.gl<-glmnet(AGBM_corr~logSA+Y+SpShann+logSI+SA_Y+Div_SA+Div_Y,
                weights=wi,data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(mort.gl)
check<-coef(mort.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  mort.gl2<-glmnet(AGBM_corr~logSA+Y+SpShann+logSI+SA_Y+Div_SA+Div_Y,
                   weights=wi,data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(mort.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","SpShann","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          SpShann=unlist(apply(coeff.se[,grep("^SpShann$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

mortT_1se<-data.table(Source=c("Int","logSA","Y","SpShann","logSI","SA_Y","Div_SA","Div_Y"),
                      mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_1se$mean.mort<-apply(coeff.se_tidy,2,mean)
mortT_1se$up.mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
mortT_1se$low.mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
mcShann_sc_summary<-summary(mcShann_sc)$beta
mortT_multi<-data.table(Source=c("Int","logSA","Y","SpShann","logSI","SA_Y","Div_SA","Div_Y"),
                        mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi$mean.mort<-mcShann_sc_summary[,1]
mortT_multi$up.mort<-mcShann_sc_summary[,1]+mcShann_sc_summary[,2]
mortT_multi$low.mort<-mcShann_sc_summary[,1]-mcShann_sc_summary[,2]

#Temporal autoregressive
mcShann_Tmp_sc<-lme(AGBM~logSA_sc+Y_sc+SpShann_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:SpShann_sc)+(Y_sc:SpShann_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
mortT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","SpShann","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_Tmp$mean.mort<-summary(mcShann_Tmp_sc)$tTable[,1]
mortT_multi_Tmp$up.mort<-summary(mcShann_Tmp_sc)$tTable[,1]+summary(mcShann_Tmp_sc)$tTable[,2]
mortT_multi_Tmp$low.mort<-summary(mcShann_Tmp_sc)$tTable[,1]-summary(mcShann_Tmp_sc)$tTable[,2]

#lmer
mcShann_lmer_sc<-lmer(AGBM~logSA_sc+Y_sc+SpShann_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:SpShann_sc)+(Y_sc:SpShann_sc)+
                            (1|Plotnumber),weights=wi,absk)
mortT_multi_lmer<-data.table(Source=c("Int","logSA","Y","SpShann","logSI","SA_Y","Div_SA","Div_Y"),
                             mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_lmer$mean.mort<-summary(mcShann_lmer_sc)$co[,1]
mortT_multi_lmer$up.mort<-summary(mcShann_lmer_sc)$co[,1]+summary(mcShann_lmer_sc)$co[,2]
mortT_multi_lmer$low.mort<-summary(mcShann_lmer_sc)$co[,1]-summary(mcShann_lmer_sc)$co[,2]

#nonpara
nmcShann<-rfit(AGBM_corr~logSA+Y+SpShann+logSI+SA_Y+Div_SA+Div_Y,
              weights=wi,data=glmnet.dat)
summary(nmcShann)$co

mortT_multi_NP<-data.table(Source=c("Int","logSA","Y","SpShann","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_NP$mean.mort<-summary(nmcShann)$co[,1]
mortT_multi_NP$up.mort<-summary(nmcShann)$co[,1]+summary(nmcShann)$co[,2]
mortT_multi_NP$low.mort<-summary(nmcShann)$co[,1]-summary(nmcShann)$co[,2]

#Sequential
mcnbsp_resid1<-lm(resid(mc_seq_sc)~Y+SpShann+(logSA:Y)+(logSA:SpShann)+(Y:SpShann),
                  weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(mcnbsp_resid1))

mortT_multi_seq<-data.table(Source=c("Int","logSA","Y","SpShann","logSI","SA_Y","Div_SA","Div_Y"))

mortT_multi_seq[Source=="logSA",mean.mort:=mc_seq_sc_summary["logSA_sc",1]]
mortT_multi_seq[Source=="Y",mean.mort:=coef(summary(mcnbsp_resid1))["Y",1]]
mortT_multi_seq[Source=="SpShann",mean.mort:=coef(summary(mcnbsp_resid1))["SpShann",1]]
mortT_multi_seq[Source=="logSI",mean.mort:=mc_seq_sc_summary["logSI_sc",1]]
mortT_multi_seq[Source=="SA_Y",mean.mort:=coef(summary(mcnbsp_resid1))["Y:logSA",1]]
mortT_multi_seq[Source=="Div_SA",mean.mort:=coef(summary(mcnbsp_resid1))["SpShann:logSA",1]]
mortT_multi_seq[Source=="Div_Y",mean.mort:=coef(summary(mcnbsp_resid1))["Y:SpShann",1]]

mortT_multi_seq[Source=="logSA",up.mort:=mc_seq_sc_summary["logSA_sc",1]+
                  mc_seq_sc_summary["logSA_sc",2]]
mortT_multi_seq[Source=="Y",up.mort:=coef(summary(mcnbsp_resid1))["Y",1]+
                  coef(summary(mcnbsp_resid1))["Y",2]]
mortT_multi_seq[Source=="SpShann",up.mort:=coef(summary(mcnbsp_resid1))["SpShann",1]+
                  coef(summary(mcnbsp_resid1))["SpShann",2]]
mortT_multi_seq[Source=="logSI",up.mort:=mc_seq_sc_summary["logSI_sc",1]+
                  mc_seq_sc_summary["logSI_sc",2]]
mortT_multi_seq[Source=="SA_Y",up.mort:=coef(summary(mcnbsp_resid1))["Y:logSA",1]+
                  coef(summary(mcnbsp_resid1))["Y:logSA",2]]
mortT_multi_seq[Source=="Div_SA",up.mort:=coef(summary(mcnbsp_resid1))["SpShann:logSA",1]+
                  coef(summary(mcnbsp_resid1))["SpShann:logSA",2]]
mortT_multi_seq[Source=="Div_Y",up.mort:=coef(summary(mcnbsp_resid1))["Y:SpShann",1]+
                  coef(summary(mcnbsp_resid1))["Y:SpShann",2]]

mortT_multi_seq[Source=="logSA",low.mort:=mc_seq_sc_summary["logSA_sc",1]-
                  mc_seq_sc_summary["logSA_sc",2]]
mortT_multi_seq[Source=="Y",low.mort:=coef(summary(mcnbsp_resid1))["Y",1]-
                  coef(summary(mcnbsp_resid1))["Y",2]]
mortT_multi_seq[Source=="SpShann",low.mort:=coef(summary(mcnbsp_resid1))["SpShann",1]-
                  coef(summary(mcnbsp_resid1))["SpShann",2]]
mortT_multi_seq[Source=="logSI",low.mort:=mc_seq_sc_summary["logSI_sc",1]-
                  mc_seq_sc_summary["logSI_sc",2]]
mortT_multi_seq[Source=="SA_Y",low.mort:=coef(summary(mcnbsp_resid1))["Y:logSA",1]-
                  coef(summary(mcnbsp_resid1))["Y:logSA",2]]
mortT_multi_seq[Source=="Div_SA",low.mort:=coef(summary(mcnbsp_resid1))["SpShann:logSA",1]-
                  coef(summary(mcnbsp_resid1))["SpShann:logSA",2]]
mortT_multi_seq[Source=="Div_Y",low.mort:=coef(summary(mcnbsp_resid1))["Y:SpShann",1]-
                  coef(summary(mcnbsp_resid1))["Y:SpShann",2]]

#Bind
mortT_multi_lmer$model<-"Linear mixed effects"
mortT_multi_Tmp$model<-"Temporal autoregressive"
mortT_multi$model<-"Spatial autoregressive"
mortT_1se$model<-"Ridge regression"
mortT_multi_NP$model<-"Nonparametric"
mortT_multi_seq$model<-"Sequential"

to_gg<-rbind(mortT_multi_lmer,mortT_multi_Tmp,mortT_multi,mortT_1se,mortT_multi_NP,mortT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="SpShann",Source:="Shann"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*Shann"];to_gg[Source=="Div_Y",Source:="Y*Shann"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","Shann","logSA*Y","logSA*Shann","Y*Shann"))

MortShann<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.mort,ymin=low.mort,ymax=up.mort,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.75,0.65),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")#+
  #guides(col=FALSE)
MortShann

################################## NBC ################################## 
glmnet.dat<-absk[,.(Intercept=1,logSA=logSA,Y=Y,logShann=logShann,logSI=logSI,Div_SA=logShann*logSA,
                    SA_Y=logSA*Y,Div_Y=Y*logShann)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

load("fitme_Year_NBC_Shann_sc_HossfeldSI.R")
glmnet.dat[,AGB_corr:=residuals(maShann_sc,type="response")+
             maShann_sc$fixef[1]+
             (maShann_sc$fixef[2]*logSA)+
             (maShann_sc$fixef[3]*Y)+
             (maShann_sc$fixef[4]*logShann)+
             (maShann_sc$fixef[5]*logSI)+
             (maShann_sc$fixef[6]*logSA*Y)+
             (maShann_sc$fixef[7]*logSA*logShann)+
             (maShann_sc$fixef[8]*Y*logShann)]

mod_lm_corr<-lm(AGB_corr~logSA+Y+logShann+logSI+
                  (logSA:Y)+(logSA:logShann)+
                  (Y:logShann),glmnet.dat,weights=wi)
summary(residuals(maShann_sc,type="response")-residuals(mod_lm_corr))## same

lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSA,Y,logShann,logSI,SA_Y,Div_SA,Div_Y)]),
  y=as.matrix(glmnet.dat[,AGB_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

nbc.gl<-glmnet(AGB_corr~logSA+Y+logShann+logSI+SA_Y+Div_SA+Div_Y,
               weights=wi,data=glmnet.dat,
               lambda=lambda_values,#covers range of no suppression to max of 1se
               alpha=0)#0=ridge regression
coef(nbc.gl)
check<-coef(nbc.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  nbc.gl2<-glmnet(AGB_corr~logSA+Y+logShann+logSI+SA_Y+Div_SA+Div_Y,
                  weights=wi,data=newdat,
                  lambda=lambda_values,
                  alpha=0)
  coef(nbc.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),ncol(coeff.se)/8)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          Y=unlist(apply(coeff.se[,grep("^Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          logShann=unlist(apply(coeff.se[,grep("^logShann$",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("^logSI$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_Y=unlist(apply(coeff.se[,grep("^SA_Y$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_Y=unlist(apply(coeff.se[,grep("^Div_Y$",colnames(coeff.se)),with=FALSE],2,list)))

nbcT_1se<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),
                     mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_1se$mean.nbc<-apply(coeff.se_tidy,2,mean)
nbcT_1se$up.nbc<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
nbcT_1se$low.nbc<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme ##
maShann_sc_summary<-summary(maShann_sc)$beta
nbcT_multi<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),
                       mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi$mean.nbc<-maShann_sc_summary[,1]
nbcT_multi$up.nbc<-maShann_sc_summary[,1]+maShann_sc_summary[,2]
nbcT_multi$low.nbc<-maShann_sc_summary[,1]-maShann_sc_summary[,2]

#Temporal autoregressive
maShann_Tmp_sc<-lme(AGB~logSA_sc+Y_sc+logShann_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:logShann_sc)+(Y_sc:logShann_sc),
                        random=~1|Plotnumber,weights=~1/wi,cor=corCAR1(form= ~ Y | Plotnumber),absk)
nbcT_multi_Tmp<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),
                           mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_Tmp$mean.nbc<-summary(maShann_Tmp_sc)$tTable[,1]
nbcT_multi_Tmp$up.nbc<-summary(maShann_Tmp_sc)$tTable[,1]+summary(maShann_Tmp_sc)$tTable[,2]
nbcT_multi_Tmp$low.nbc<-summary(maShann_Tmp_sc)$tTable[,1]-summary(maShann_Tmp_sc)$tTable[,2]

#lmer
maShann_lmer_sc<-lmer(AGB~logSA_sc+Y_sc+logShann_sc+logSI_sc+(logSA_sc:Y_sc)+(logSA_sc:logShann_sc)+(Y_sc:logShann_sc)+
                            (1|Plotnumber),weights=wi,absk)
nbcT_multi_lmer<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),
                            mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_lmer$mean.nbc<-summary(maShann_lmer_sc)$co[,1]
nbcT_multi_lmer$up.nbc<-summary(maShann_lmer_sc)$co[,1]+summary(maShann_lmer_sc)$co[,2]
nbcT_multi_lmer$low.nbc<-summary(maShann_lmer_sc)$co[,1]-summary(maShann_lmer_sc)$co[,2]

#nonpara
nmaShann<-rfit(AGB_corr~logSA+Y+logShann+logSI+SA_Y+Div_SA+Div_Y,
              weights=wi,data=glmnet.dat)
summary(nmaShann)$co

nbcT_multi_NP<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"),
                          mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_NP$mean.nbc<-summary(nmaShann)$co[,1]
nbcT_multi_NP$up.nbc<-summary(nmaShann)$co[,1]+summary(nmaShann)$co[,2]
nbcT_multi_NP$low.nbc<-summary(nmaShann)$co[,1]-summary(nmaShann)$co[,2]

#Sequential
maShann_resid1<-lm(resid(ma_seq_sc)~Y+logShann+(logSA:Y)+(logSA:logShann)+(Y:logShann),
                  weights=wi,glmnet.dat)#Use residual, with SA interactions
coef(summary(maShann_resid1))

nbcT_multi_seq<-data.table(Source=c("Int","logSA","Y","logShann","logSI","SA_Y","Div_SA","Div_Y"))

nbcT_multi_seq[Source=="logSA",mean.nbc:=ma_seq_sc_summary["logSA_sc",1]]
nbcT_multi_seq[Source=="Y",mean.nbc:=coef(summary(maShann_resid1))["Y",1]]
nbcT_multi_seq[Source=="logShann",mean.nbc:=coef(summary(maShann_resid1))["logShann",1]]
nbcT_multi_seq[Source=="logSI",mean.nbc:=ma_seq_sc_summary["logSI_sc",1]]
nbcT_multi_seq[Source=="SA_Y",mean.nbc:=coef(summary(maShann_resid1))["Y:logSA",1]]
nbcT_multi_seq[Source=="Div_SA",mean.nbc:=coef(summary(maShann_resid1))["logShann:logSA",1]]
nbcT_multi_seq[Source=="Div_Y",mean.nbc:=coef(summary(maShann_resid1))["Y:logShann",1]]

nbcT_multi_seq[Source=="logSA",up.nbc:=ma_seq_sc_summary["logSA_sc",1]+
                 ma_seq_sc_summary["logSA_sc",2]]
nbcT_multi_seq[Source=="Y",up.nbc:=coef(summary(maShann_resid1))["Y",1]+
                 coef(summary(maShann_resid1))["Y",2]]
nbcT_multi_seq[Source=="logShann",up.nbc:=coef(summary(maShann_resid1))["logShann",1]+
                 coef(summary(maShann_resid1))["logShann",2]]
nbcT_multi_seq[Source=="logSI",up.nbc:=ma_seq_sc_summary["logSI_sc",1]+
                 ma_seq_sc_summary["logSI_sc",2]]
nbcT_multi_seq[Source=="SA_Y",up.nbc:=coef(summary(maShann_resid1))["Y:logSA",1]+
                 coef(summary(maShann_resid1))["Y:logSA",2]]
nbcT_multi_seq[Source=="Div_SA",up.nbc:=coef(summary(maShann_resid1))["logShann:logSA",1]+
                 coef(summary(maShann_resid1))["logShann:logSA",2]]
nbcT_multi_seq[Source=="Div_Y",up.nbc:=coef(summary(maShann_resid1))["Y:logShann",1]+
                 coef(summary(maShann_resid1))["Y:logShann",2]]

nbcT_multi_seq[Source=="logSA",low.nbc:=ma_seq_sc_summary["logSA_sc",1]-
                 ma_seq_sc_summary["logSA_sc",2]]
nbcT_multi_seq[Source=="Y",low.nbc:=coef(summary(maShann_resid1))["Y",1]-
                 coef(summary(maShann_resid1))["Y",2]]
nbcT_multi_seq[Source=="logShann",low.nbc:=coef(summary(maShann_resid1))["logShann",1]-
                 coef(summary(maShann_resid1))["logShann",2]]
nbcT_multi_seq[Source=="logSI",low.nbc:=ma_seq_sc_summary["logSI_sc",1]-
                 ma_seq_sc_summary["logSI_sc",2]]
nbcT_multi_seq[Source=="SA_Y",low.nbc:=coef(summary(maShann_resid1))["Y:logSA",1]-
                 coef(summary(maShann_resid1))["Y:logSA",2]]
nbcT_multi_seq[Source=="Div_SA",low.nbc:=coef(summary(maShann_resid1))["logShann:logSA",1]-
                 coef(summary(maShann_resid1))["logShann:logSA",2]]
nbcT_multi_seq[Source=="Div_Y",low.nbc:=coef(summary(maShann_resid1))["Y:logShann",1]-
                 coef(summary(maShann_resid1))["Y:logShann",2]]

#Bind
nbcT_multi_lmer$model<-"Linear mixed effects"
nbcT_multi_Tmp$model<-"Temporal autoregressive"
nbcT_multi$model<-"Spatial autoregressive"
nbcT_1se$model<-"Ridge regression"
nbcT_multi_NP$model<-"Nonparametric"
nbcT_multi_seq$model<-"Sequential"

to_gg<-rbind(nbcT_multi_lmer,nbcT_multi_Tmp,nbcT_multi,nbcT_1se,nbcT_multi_NP,nbcT_multi_seq)
to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects","Temporal autoregressive",
                                         "Spatial autoregressive",
                                         "Ridge regression","Nonparametric","Sequential"))

to_gg[Source=="Y",Source:="Y"];to_gg[Source=="logSI",Source:="logSI"]
to_gg[Source=="logShann",Source:="logShann"];to_gg[Source=="SA_Y",Source:="logSA*Y"]
to_gg[Source=="Div_SA",Source:="logSA*logShann"];to_gg[Source=="Div_Y",Source:="Y*logShann"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","Y","logShann","logSA*Y","logSA*logShann","Y*logShann"))

NBCShann<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.nbc,ymin=low.nbc,ymax=up.nbc,col=model))+
  geom_point(position=position_dodge(0.4))+
  geom_errorbar(position=position_dodge(0.4),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.7),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+
  guides(col=FALSE)
NBCShann

### Save Fig.S4
############## ############## Bind S, Sorg, Shann ############## ##############
rbind_gtable_max <- function(...){
  gtl <- list(...)
  stopifnot(all(sapply(gtl, is.gtable)))
  bind2 <- function (x, y) 
  {
    stopifnot(ncol(x) == ncol(y))
    if (nrow(x) == 0) 
      return(y)
    if (nrow(y) == 0) 
      return(x)
    y$layout$t <- y$layout$t + nrow(x)
    y$layout$b <- y$layout$b + nrow(x)
    x$layout <- rbind(x$layout, y$layout)
    x$heights <- gtable:::insert.unit(x$heights, y$heights)
    x$rownames <- c(x$rownames, y$rownames)
    x$widths <- grid::unit.pmax(x$widths, y$widths)
    x$grobs <- append(x$grobs, y$grobs)
    x
  }
  
  Reduce(bind2, gtl)
}

f1 <- ggplotGrob(Grow)
f2 <- ggplotGrob(Mort)
f3 <- ggplotGrob(NBC)
i1 <- ggplotGrob(GrowSarea)
i2 <- ggplotGrob(MortSarea)
i3 <- ggplotGrob(NBCSarea)
g1 <- ggplotGrob(GrowSorg)
g2 <- ggplotGrob(MortSorg)
g3 <- ggplotGrob(NBCSorg)
h1 <- ggplotGrob(GrowShann)
h2 <- ggplotGrob(MortShann)
h3 <- ggplotGrob(NBCShann)

A<-rbind_gtable_max(f1,f2,f3)
B<-rbind_gtable_max(i1,i2,i3)
C<-rbind_gtable_max(g1,g2,g3)
D<-rbind_gtable_max(h1,h2,h3)

tiff("FigS4_Bind_YEAR_Ridge_regression_fitme_Hossfeld.tiff",width=4200,height=3000,res=300,compression="lzw")
grid.arrange(A,B,C,D, ncol=4)

grid.text("A",x=unit(0.01,"npc"),y=unit(0.99,"npc"),gp=gpar(fontsize=14,font=2),just="left")
grid.text("Growth",x=unit(0.08,"npc"),y=unit(0.99,"npc"),gp=gpar(fontsize=12),just="left")
grid.text("Mortality",x=unit(0.08,"npc"),y=unit(0.662,"npc"),gp=gpar(fontsize=12),just="left")
grid.text("Net biomass change",x=unit(0.08,"npc"),y=unit(0.33,"npc"),gp=gpar(fontsize=12),just="left")

grid.text("B",x=unit(0.255,"npc"),y=unit(0.99,"npc"),gp=gpar(fontsize=14,font=2),just="left")
grid.text("Growth",x=unit(0.255+0.07,"npc"),y=unit(0.99,"npc"),gp=gpar(fontsize=12),just="left")
grid.text("Mortality",x=unit(0.255+0.07,"npc"),y=unit(0.662,"npc"),gp=gpar(fontsize=12),just="left")
grid.text("Net biomass change",x=unit(0.255+0.07,"npc"),y=unit(0.33,"npc"),gp=gpar(fontsize=12),just="left")

grid.text("C",x=unit(0.506,"npc"),y=unit(0.99,"npc"),gp=gpar(fontsize=14,font=2),just="left")
grid.text("Growth",x=unit(0.506+0.07,"npc"),y=unit(0.99,"npc"),gp=gpar(fontsize=12),just="left")
grid.text("Mortality",x=unit(0.506+0.07,"npc"),y=unit(0.662,"npc"),gp=gpar(fontsize=12),just="left")
grid.text("Net biomass change",x=unit(0.506+0.07,"npc"),y=unit(0.33,"npc"),gp=gpar(fontsize=12),just="left")

grid.text("D",x=unit(0.755,"npc"),y=unit(0.99,"npc"),gp=gpar(fontsize=14,font=2),just="left")
grid.text("Growth",x=unit(0.755+0.07,"npc"),y=unit(0.99,"npc"),gp=gpar(fontsize=12),just="left")
grid.text("Mortality",x=unit(0.755+0.07,"npc"),y=unit(0.662,"npc"),gp=gpar(fontsize=12),just="left")
grid.text("Net biomass change",x=unit(0.755+0.07,"npc"),y=unit(0.33,"npc"),gp=gpar(fontsize=12),just="left")

dev.off()

### Extended Data Fig.S2 ###s
## Climate change drivers
### Growth ###
glmnet.dat<-absk[,.(Intercept=1,
                    logSI=logSI,logSA=logSA,
                    CO21=CO21,ATA1=ATA1,CMI1=CMI1,
                    lograre_nbsp=lograre_nbsp,
                    Div_SA=lograre_nbsp*logSA,
                    SA_CO2=logSA*CO21,SA_ATA=logSA*ATA1,SA_CMI=logSA*CMI1,
                    Div_CO2=CO21*lograre_nbsp,Div_ATA=ATA1*lograre_nbsp,Div_CMI=CMI1*lograre_nbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Intercept<-1
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

#Multi lmer
load("fitme_MULTI_Grow_sc_HossfeldSI.R")
glmnet.dat[,AGBGI_corr:=residuals(mbrare_nbspCAC_sc,type="response")+
             mbrare_nbspCAC_sc$fixef[1]+
             (mbrare_nbspCAC_sc$fixef[2]*logSI)+
             (mbrare_nbspCAC_sc$fixef[3]*logSA)+
             (mbrare_nbspCAC_sc$fixef[4]*CO21)+
             (mbrare_nbspCAC_sc$fixef[5]*ATA1)+
             (mbrare_nbspCAC_sc$fixef[6]*CMI1)+
             (mbrare_nbspCAC_sc$fixef[7]*lograre_nbsp)+
             (mbrare_nbspCAC_sc$fixef[8]*SA_CO2)+
             (mbrare_nbspCAC_sc$fixef[9]*SA_ATA)+
             (mbrare_nbspCAC_sc$fixef[10]*SA_CMI)+
             (mbrare_nbspCAC_sc$fixef[11]*Div_SA)+
             (mbrare_nbspCAC_sc$fixef[12]*Div_CO2)+
             (mbrare_nbspCAC_sc$fixef[13]*Div_ATA)+
             (mbrare_nbspCAC_sc$fixef[14]*Div_CMI)]

mod_lm_corr<-lm(AGBGI_corr~logSI+logSA+CO21+ATA1+CMI1+lograre_nbsp+
                  SA_CO2+SA_ATA+SA_CMI+
                  Div_SA+Div_CO2+Div_ATA+Div_CMI,glmnet.dat,weights=wi)

summary(residuals(mbrare_nbspCAC_sc,type="response")-residuals(mod_lm_corr))## same

###### Multi Ridge regression ######
lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSI,logSA,CO21,ATA1,CMI1,
                            lograre_nbsp,
                            SA_CO2,SA_ATA,SA_CMI,
                            Div_SA,
                            Div_CO2,Div_ATA,Div_CMI)]),
  y=as.matrix(glmnet.dat[,AGBGI_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

grow.gl<-glmnet(AGBGI_corr~logSI+logSA+CO21+ATA1+CMI1+lograre_nbsp+Div_SA+
                  SA_CO2+SA_ATA+SA_CMI+
                  Div_CO2+Div_ATA+Div_CMI,
                weights=wi,
                data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(grow.gl)
check<-coef(grow.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  grow.gl2<-glmnet(AGBGI_corr~logSI+logSA+CO21+ATA1+CMI1+lograre_nbsp+
                     SA_CO2+SA_ATA+SA_CMI+
                     Div_SA+
                     Div_CO2+Div_ATA+Div_CMI,
                   weights=wi,
                   data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(grow.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSI","logSA","CO21","ATA1","CMI1","lograre_nbsp",
                          "SA_CO2","SA_ATA","SA_CMI","Div_SA",
                          "Div_CO2","Div_ATA","Div_CMI"),ncol(coeff.se)/14)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("logSI",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          CO21=unlist(apply(coeff.se[,grep("^CO21$",colnames(coeff.se)),with=FALSE],2,list)),
                          ATA1=unlist(apply(coeff.se[,grep("^ATA1$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMI1=unlist(apply(coeff.se[,grep("^CMI1$",colnames(coeff.se)),with=FALSE],2,list)),
                          lograre_nbsp=unlist(apply(coeff.se[,grep("^lograre_nbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_CO2=unlist(apply(coeff.se[,grep("^SA_CO2$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_ATA=unlist(apply(coeff.se[,grep("^SA_ATA$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_CMI=unlist(apply(coeff.se[,grep("^SA_CMI$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_CO2=unlist(apply(coeff.se[,grep("^Div_CO2$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_ATA=unlist(apply(coeff.se[,grep("^Div_ATA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_CMI=unlist(apply(coeff.se[,grep("^Div_CMI$",colnames(coeff.se)),with=FALSE],2,list)))

growT_1se<-data.table(Source=c("Int","logSI","logSA","CO21","ATA1","CMI1","lograre_nbsp",
                               "SA_CO2","SA_ATA","SA_CMI",
                               "Div_SA",
                               "Div_CO2","Div_ATA","Div_CMI"),
                      mean.gr=NA,up.gr=NA,low.gr=NA)

growT_1se$mean.gr<-apply(coeff.se_tidy,2,mean)
growT_1se$up.gr<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
growT_1se$low.gr<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme MULTI ##
mbrare_nbspCAC_sc_summary<-summary(mbrare_nbspCAC_sc)$beta
growT_multi<-data.table(Source=c("Int","logSI","logSA","CO21","ATA1","CMI1","lograre_nbsp",
                                 "SA_CO2","SA_ATA","SA_CMI",
                                 "Div_SA",
                                 "Div_CO2","Div_ATA","Div_CMI"),
                        mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi$mean.gr<-mbrare_nbspCAC_sc_summary[,1]
growT_multi$up.gr<-mbrare_nbspCAC_sc_summary[,1]+mbrare_nbspCAC_sc_summary[,2]
growT_multi$low.gr<-mbrare_nbspCAC_sc_summary[,1]-mbrare_nbspCAC_sc_summary[,2]

## fitme single CO2 ##
load("fitme_CO2_Grow_sc_HossfeldSI.R")
mbrare_nbspCO2_sc_summary<-summary(mbrare_nbspCO2_sc)$beta
growT_CO2<-data.table(Source=c("Int","logSI","logSA","CO21","lograre_nbsp","SA_CO2","Div_SA","Div_CO2"),
                      mean.gr=NA,up.gr=NA,low.gr=NA)

growT_CO2$mean.gr<-mbrare_nbspCO2_sc_summary[,1]
growT_CO2$up.gr<-mbrare_nbspCO2_sc_summary[,1]+mbrare_nbspCO2_sc_summary[,2]
growT_CO2$low.gr<-mbrare_nbspCO2_sc_summary[,1]-mbrare_nbspCO2_sc_summary[,2]

## fitme single ATA ##
load("fitme_ATA_Grow_sc_HossfeldSI.R")
mbrare_nbspATA_sc_summary<-summary(mbrare_nbspATA_sc)$beta
growT_ATA<-data.table(Source=c("Int","logSI","logSA","ATA1","lograre_nbsp","SA_ATA","Div_SA","Div_ATA"),
                      mean.gr=NA,up.gr=NA,low.gr=NA)

growT_ATA$mean.gr<-mbrare_nbspATA_sc_summary[,1]
growT_ATA$up.gr<-mbrare_nbspATA_sc_summary[,1]+mbrare_nbspATA_sc_summary[,2]
growT_ATA$low.gr<-mbrare_nbspATA_sc_summary[,1]-mbrare_nbspATA_sc_summary[,2]

## fitme single CMI ##
load("fitme_ACMIA_Grow_sc_HossfeldSI.R")
mbrare_nbspCMI_sc_summary<-summary(mbrare_nbspCMI_sc)$beta
growT_CMI<-data.table(Source=c("Int","logSI","logSA","CMI1","lograre_nbsp","SA_CMI","Div_SA","Div_CMI"),
                      mean.gr=NA,up.gr=NA,low.gr=NA)

growT_CMI$mean.gr<-mbrare_nbspCMI_sc_summary[,1]
growT_CMI$up.gr<-mbrare_nbspCMI_sc_summary[,1]+mbrare_nbspCMI_sc_summary[,2]
growT_CMI$low.gr<-mbrare_nbspCMI_sc_summary[,1]-mbrare_nbspCMI_sc_summary[,2]

### Multi nonpara ###
nmbrare_nbspCAC<-rfit(AGBGI_corr~logSI+logSA+CO21+ATA1+CMI1+lograre_nbsp+
                        SA_CO2+SA_ATA+SA_CMI+Div_SA+
                        Div_CO2+Div_ATA+Div_CMI,
                      weights=wi,data=glmnet.dat)
summary(nmbrare_nbspCAC)$co

growT_multi_NP<-data.table(Source=c("Int","logSI","logSA","CO21","ATA1","CMI1","lograre_nbsp",
                                    "SA_CO2","SA_ATA","SA_CMI",
                                    "Div_SA",
                                    "Div_CO2","Div_ATA","Div_CMI"),
                           mean.gr=NA,up.gr=NA,low.gr=NA)

growT_multi_NP$mean.gr<-summary(nmbrare_nbspCAC)$co[,1]
growT_multi_NP$up.gr<-summary(nmbrare_nbspCAC)$co[,1]+summary(nmbrare_nbspCAC)$co[,2]
growT_multi_NP$low.gr<-summary(nmbrare_nbspCAC)$co[,1]-summary(nmbrare_nbspCAC)$co[,2]

#Bind Multi, CO2, ATA, CMI
growT_multi$model<-"Linear mixed effects (modelled with three drivers simultaneously)"
growT_1se$model<-"Ridge regression (modelled with three drivers simultaneously)"
growT_multi_NP$model<-"Nonparametric (modelled with three drivers simultaneously)"
growT_CO2$model<-"Linear mixed effects (modelled with CO2)"
growT_ATA$model<-"Linear mixed effects (modelled with ATA)"
growT_CMI$model<-"Linear mixed effects (modelled with ACMIA)"

to_gg<-rbind(growT_multi,growT_1se,growT_multi_NP,growT_CO2,growT_ATA,growT_CMI)

to_gg[Source=="logSI",Source:="logSI"];to_gg[Source=="CO21",Source:="CO2"]
to_gg[Source=="ATA1",Source:="ATA"];to_gg[Source=="CMI1",Source:="ACMIA"];
to_gg[Source=="lograre_nbsp",Source:="logS"];to_gg[Source=="SA_CO2",Source:="logSA*CO2"]
to_gg[Source=="SA_ATA",Source:="logSA*ATA"];to_gg[Source=="SA_CMI",Source:="logSA*ACMIA"]
to_gg[Source=="Div_SA",Source:="logSA*logS"];to_gg[Source=="Div_CO2",Source:="CO2*logS"]
to_gg[Source=="Div_ATA",Source:="ATA*logS"];to_gg[Source=="Div_CMI",Source:="ACMIA*logS"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","CO2","ATA","ACMIA","logS",
                                           "logSA*CO2","logSA*ATA","logSA*ACMIA",
                                           "logSA*logS",
                                           "CO2*logS","ATA*logS","ACMIA*logS"))

to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects (modelled with three drivers simultaneously)",
                                         "Ridge regression (modelled with three drivers simultaneously)",
                                         "Nonparametric (modelled with three drivers simultaneously)",
                                         "Linear mixed effects (modelled with CO2)",
                                         "Linear mixed effects (modelled with ATA)",
                                         "Linear mixed effects (modelled with ACMIA)"))

Growth<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.gr,ymin=low.gr,ymax=up.gr,col=model))+
  geom_point(position=position_dodge(0.6))+
  geom_errorbar(position=position_dodge(0.6),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.65,0.28),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")
Growth

### Mortality ###
glmnet.dat<-absk[,.(Intercept=1,
                    logSI=logSI,logSA=logSA,
                    CO21=CO21,ATA1=ATA1,CMI1=CMI1,
                    Sprare_nbsp=Sprare_nbsp,
                    Div_SA=Sprare_nbsp*logSA,
                    SA_CO2=logSA*CO21,SA_ATA=logSA*ATA1,SA_CMI=logSA*CMI1,
                    Div_CO2=CO21*Sprare_nbsp,Div_ATA=ATA1*Sprare_nbsp,Div_CMI=CMI1*Sprare_nbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Intercept<-1
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

#Multi lmer
load("fitme_MULTI_Mort_sc_HossfeldSI.R")
glmnet.dat[,AGBM_corr:=residuals(mcrare_nbspCAC_sc,type="response")+
             mcrare_nbspCAC_sc$fixef[1]+
             (mcrare_nbspCAC_sc$fixef[2]*logSI)+
             (mcrare_nbspCAC_sc$fixef[3]*logSA)+
             (mcrare_nbspCAC_sc$fixef[4]*CO21)+
             (mcrare_nbspCAC_sc$fixef[5]*ATA1)+
             (mcrare_nbspCAC_sc$fixef[6]*CMI1)+
             (mcrare_nbspCAC_sc$fixef[7]*Sprare_nbsp)+
             (mcrare_nbspCAC_sc$fixef[8]*SA_CO2)+
             (mcrare_nbspCAC_sc$fixef[9]*SA_ATA)+
             (mcrare_nbspCAC_sc$fixef[10]*SA_CMI)+
             (mcrare_nbspCAC_sc$fixef[11]*Div_SA)+
             (mcrare_nbspCAC_sc$fixef[12]*Div_CO2)+
             (mcrare_nbspCAC_sc$fixef[13]*Div_ATA)+
             (mcrare_nbspCAC_sc$fixef[14]*Div_CMI)]

mod_lm_corr<-lm(AGBM_corr~logSI+logSA+CO21+ATA1+CMI1+Sprare_nbsp+
                  SA_CO2+SA_ATA+SA_CMI+
                  Div_SA+Div_CO2+Div_ATA+Div_CMI,glmnet.dat,weights=wi)

summary(residuals(mcrare_nbspCAC_sc,type="response")-residuals(mod_lm_corr))## same

###### Multi Ridge regression ######
lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSI,logSA,CO21,ATA1,CMI1,
                            Sprare_nbsp,
                            SA_CO2,SA_ATA,SA_CMI,
                            Div_SA,
                            Div_CO2,Div_ATA,Div_CMI)]),
  y=as.matrix(glmnet.dat[,AGBM_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

mort.gl<-glmnet(AGBM_corr~logSI+logSA+CO21+ATA1+CMI1+Sprare_nbsp+Div_SA+
                  SA_CO2+SA_ATA+SA_CMI+
                  Div_CO2+Div_ATA+Div_CMI,
                weights=wi,
                data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(mort.gl)
check<-coef(mort.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  mort.gl2<-glmnet(AGBM_corr~logSI+logSA+CO21+ATA1+CMI1+Sprare_nbsp+
                     SA_CO2+SA_ATA+SA_CMI+
                     Div_SA+
                     Div_CO2+Div_ATA+Div_CMI,
                   weights=wi,
                   data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(mort.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSI","logSA","CO21","ATA1","CMI1","Sprare_nbsp",
                          "SA_CO2","SA_ATA","SA_CMI","Div_SA",
                          "Div_CO2","Div_ATA","Div_CMI"),ncol(coeff.se)/14)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("logSI",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          CO21=unlist(apply(coeff.se[,grep("^CO21$",colnames(coeff.se)),with=FALSE],2,list)),
                          ATA1=unlist(apply(coeff.se[,grep("^ATA1$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMI1=unlist(apply(coeff.se[,grep("^CMI1$",colnames(coeff.se)),with=FALSE],2,list)),
                          Sprare_nbsp=unlist(apply(coeff.se[,grep("^Sprare_nbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_CO2=unlist(apply(coeff.se[,grep("^SA_CO2$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_ATA=unlist(apply(coeff.se[,grep("^SA_ATA$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_CMI=unlist(apply(coeff.se[,grep("^SA_CMI$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_CO2=unlist(apply(coeff.se[,grep("^Div_CO2$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_ATA=unlist(apply(coeff.se[,grep("^Div_ATA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_CMI=unlist(apply(coeff.se[,grep("^Div_CMI$",colnames(coeff.se)),with=FALSE],2,list)))

mortT_1se<-data.table(Source=c("Int","logSI","logSA","CO21","ATA1","CMI1","Sprare_nbsp",
                               "SA_CO2","SA_ATA","SA_CMI",
                               "Div_SA",
                               "Div_CO2","Div_ATA","Div_CMI"),
                      mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_1se$mean.mort<-apply(coeff.se_tidy,2,mean)
mortT_1se$up.mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
mortT_1se$low.mort<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme MULTI ##
mcrare_nbspCAC_sc_summary<-summary(mcrare_nbspCAC_sc)$beta
mortT_multi<-data.table(Source=c("Int","logSI","logSA","CO21","ATA1","CMI1","Sprare_nbsp",
                                 "SA_CO2","SA_ATA","SA_CMI",
                                 "Div_SA",
                                 "Div_CO2","Div_ATA","Div_CMI"),
                        mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi$mean.mort<-mcrare_nbspCAC_sc_summary[,1]
mortT_multi$up.mort<-mcrare_nbspCAC_sc_summary[,1]+mcrare_nbspCAC_sc_summary[,2]
mortT_multi$low.mort<-mcrare_nbspCAC_sc_summary[,1]-mcrare_nbspCAC_sc_summary[,2]

## fitme single CO2 ##
load("fitme_CO2_Mort_sc_HossfeldSI.R")
mcrare_nbspCO2_sc_summary<-summary(mcrare_nbspCO2_sc)$beta
mortT_CO2<-data.table(Source=c("Int","logSI","logSA","CO21","Sprare_nbsp","SA_CO2","Div_SA","Div_CO2"),
                      mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_CO2$mean.mort<-mcrare_nbspCO2_sc_summary[,1]
mortT_CO2$up.mort<-mcrare_nbspCO2_sc_summary[,1]+mcrare_nbspCO2_sc_summary[,2]
mortT_CO2$low.mort<-mcrare_nbspCO2_sc_summary[,1]-mcrare_nbspCO2_sc_summary[,2]

## fitme single ATA ##
load("fitme_ATA_Mort_sc_HossfeldSI.R")
mcrare_nbspATA_sc_summary<-summary(mcrare_nbspATA_sc)$beta
mortT_ATA<-data.table(Source=c("Int","logSI","logSA","ATA1","Sprare_nbsp","SA_ATA","Div_SA","Div_ATA"),
                      mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_ATA$mean.mort<-mcrare_nbspATA_sc_summary[,1]
mortT_ATA$up.mort<-mcrare_nbspATA_sc_summary[,1]+mcrare_nbspATA_sc_summary[,2]
mortT_ATA$low.mort<-mcrare_nbspATA_sc_summary[,1]-mcrare_nbspATA_sc_summary[,2]

## fitme single CMI ##
load("fitme_ACMIA_Mort_sc_HossfeldSI.R")
mcrare_nbspCMI_sc_summary<-summary(mcrare_nbspCMI_sc)$beta
mortT_CMI<-data.table(Source=c("Int","logSI","logSA","CMI1","Sprare_nbsp","SA_CMI","Div_SA","Div_CMI"),
                      mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_CMI$mean.mort<-mcrare_nbspCMI_sc_summary[,1]
mortT_CMI$up.mort<-mcrare_nbspCMI_sc_summary[,1]+mcrare_nbspCMI_sc_summary[,2]
mortT_CMI$low.mort<-mcrare_nbspCMI_sc_summary[,1]-mcrare_nbspCMI_sc_summary[,2]

### Multi nonpara ###
nmcrare_nbspCAC<-rfit(AGBM_corr~logSI+logSA+CO21+ATA1+CMI1+Sprare_nbsp+
                        SA_CO2+SA_ATA+SA_CMI+Div_SA+
                        Div_CO2+Div_ATA+Div_CMI,
                      weights=wi,data=glmnet.dat)
summary(nmcrare_nbspCAC)$co

mortT_multi_NP<-data.table(Source=c("Int","logSI","logSA","CO21","ATA1","CMI1","Sprare_nbsp",
                                    "SA_CO2","SA_ATA","SA_CMI",
                                    "Div_SA",
                                    "Div_CO2","Div_ATA","Div_CMI"),
                           mean.mort=NA,up.mort=NA,low.mort=NA)

mortT_multi_NP$mean.mort<-summary(nmcrare_nbspCAC)$co[,1]
mortT_multi_NP$up.mort<-summary(nmcrare_nbspCAC)$co[,1]+summary(nmcrare_nbspCAC)$co[,2]
mortT_multi_NP$low.mort<-summary(nmcrare_nbspCAC)$co[,1]-summary(nmcrare_nbspCAC)$co[,2]

#Bind Multi, CO2, ATA, CMI
mortT_multi$model<-"Linear mixed effects (modelled with three drivers simultaneously)"
mortT_1se$model<-"Ridge regression (modelled with three drivers simultaneously)"
mortT_multi_NP$model<-"Nonparametric (modelled with three drivers simultaneously)"
mortT_CO2$model<-"Linear mixed effects (modelled with CO2)"
mortT_ATA$model<-"Linear mixed effects (modelled with ATA)"
mortT_CMI$model<-"Linear mixed effects (modelled with ACMIA)"

to_gg<-rbind(mortT_multi,mortT_1se,mortT_multi_NP,mortT_CO2,mortT_ATA,mortT_CMI)

to_gg[Source=="logSI",Source:="logSI"];to_gg[Source=="CO21",Source:="CO2"]
to_gg[Source=="ATA1",Source:="ATA"];to_gg[Source=="CMI1",Source:="ACMIA"];
to_gg[Source=="Sprare_nbsp",Source:="S"];to_gg[Source=="SA_CO2",Source:="logSA*CO2"]
to_gg[Source=="SA_ATA",Source:="logSA*ATA"];to_gg[Source=="SA_CMI",Source:="logSA*ACMIA"]
to_gg[Source=="Div_SA",Source:="logSA*S"];to_gg[Source=="Div_CO2",Source:="CO2*S"]
to_gg[Source=="Div_ATA",Source:="ATA*S"];to_gg[Source=="Div_CMI",Source:="ACMIA*S"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","CO2","ATA","ACMIA","S",
                                           "logSA*CO2","logSA*ATA","logSA*ACMIA",
                                           "logSA*S",
                                           "CO2*S","ATA*S","ACMIA*S"))

to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects (modelled with three drivers simultaneously)",
                                         "Ridge regression (modelled with three drivers simultaneously)",
                                         "Nonparametric (modelled with three drivers simultaneously)",
                                         "Linear mixed effects (modelled with CO2)",
                                         "Linear mixed effects (modelled with ATA)",
                                         "Linear mixed effects (modelled with ACMIA)"))

Mortality<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.mort,ymin=low.mort,ymax=up.mort,col=model))+
  geom_point(position=position_dodge(0.6))+
  geom_errorbar(position=position_dodge(0.6),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.8),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+guides(col=FALSE)
Mortality

### NetBiomChange ###
glmnet.dat<-absk[,.(Intercept=1,
                    logSI=logSI,logSA=logSA,
                    CO21=CO21,ATA1=ATA1,CMI1=CMI1,
                    lograre_nbsp=lograre_nbsp,
                    Div_SA=lograre_nbsp*logSA,
                    SA_CO2=logSA*CO21,SA_ATA=logSA*ATA1,SA_CMI=logSA*CMI1,
                    Div_CO2=CO21*lograre_nbsp,Div_ATA=ATA1*lograre_nbsp,Div_CMI=CMI1*lograre_nbsp)]##data table for ridge regression

glmnet.dat<-as.data.table(scale(glmnet.dat))##scale everything
glmnet.dat$Intercept<-1
glmnet.dat$Plotnumber<-as.factor(absk$Plotnumber)
glmnet.dat$wi<-absk$wi

#Multi lmer
load("fitme_MULTI_NBC_sc_HossfeldSI.R")
glmnet.dat[,AGB_corr:=residuals(marare_nbspCAC_sc,type="response")+
             marare_nbspCAC_sc$fixef[1]+
             (marare_nbspCAC_sc$fixef[2]*logSI)+
             (marare_nbspCAC_sc$fixef[3]*logSA)+
             (marare_nbspCAC_sc$fixef[4]*CO21)+
             (marare_nbspCAC_sc$fixef[5]*ATA1)+
             (marare_nbspCAC_sc$fixef[6]*CMI1)+
             (marare_nbspCAC_sc$fixef[7]*lograre_nbsp)+
             (marare_nbspCAC_sc$fixef[8]*SA_CO2)+
             (marare_nbspCAC_sc$fixef[9]*SA_ATA)+
             (marare_nbspCAC_sc$fixef[10]*SA_CMI)+
             (marare_nbspCAC_sc$fixef[11]*Div_SA)+
             (marare_nbspCAC_sc$fixef[12]*Div_CO2)+
             (marare_nbspCAC_sc$fixef[13]*Div_ATA)+
             (marare_nbspCAC_sc$fixef[14]*Div_CMI)]

mod_lm_corr<-lm(AGB_corr~logSI+logSA+CO21+ATA1+CMI1+lograre_nbsp+
                  SA_CO2+SA_ATA+SA_CMI+
                  Div_SA+Div_CO2+Div_ATA+Div_CMI,glmnet.dat,weights=wi)

summary(residuals(marare_nbspCAC_sc,type="response")-residuals(mod_lm_corr))## same

###### Multi Ridge regression ######
lambda_values=summary(sapply(1:100,function(i)cv.glmnet(
  x=as.matrix(glmnet.dat[,.(logSI,logSA,CO21,ATA1,CMI1,
                            lograre_nbsp,
                            SA_CO2,SA_ATA,SA_CMI,
                            Div_SA,
                            Div_CO2,Div_ATA,Div_CMI)]),
  y=as.matrix(glmnet.dat[,AGB_corr]),
  weights=as.vector(glmnet.dat[,wi]))
  $lambda.1se))

lambda_values=seq(max(lambda_values),min(lambda_values),length=100)

nbc.gl<-glmnet(AGB_corr~logSI+logSA+CO21+ATA1+CMI1+lograre_nbsp+Div_SA+
                  SA_CO2+SA_ATA+SA_CMI+
                  Div_CO2+Div_ATA+Div_CMI,
                weights=wi,
                data=glmnet.dat,
                lambda=lambda_values,#covers range of no suppression to max of 1se
                alpha=0)#0=ridge regression
coef(nbc.gl)
check<-coef(nbc.gl)

#bootstrap [lambda=1se]
coeff.se<-ldply(1:1000, function(i){
  too_boot<-sample(unique(glmnet.dat[,Plotnumber]),replace=TRUE)
  newdat<-glmnet.dat[Plotnumber%in%too_boot]
  nbc.gl2<-glmnet(AGB_corr~logSI+logSA+CO21+ATA1+CMI1+lograre_nbsp+
                     SA_CO2+SA_ATA+SA_CMI+
                     Div_SA+
                     Div_CO2+Div_ATA+Div_CMI,
                   weights=wi,
                   data=newdat,
                   lambda=lambda_values,
                   alpha=0)
  coef(nbc.gl2)@x},.progress="win"
)%>%as.data.table

colnames(coeff.se)<-rep(c("Int","logSI","logSA","CO21","ATA1","CMI1","lograre_nbsp",
                          "SA_CO2","SA_ATA","SA_CMI","Div_SA",
                          "Div_CO2","Div_ATA","Div_CMI"),ncol(coeff.se)/14)

coeff.se_tidy<-data.table(Int=unlist(apply(coeff.se[,grep("Int",colnames(coeff.se)),with=FALSE],2,list)),
                          logSI=unlist(apply(coeff.se[,grep("logSI",colnames(coeff.se)),with=FALSE],2,list)),
                          logSA=unlist(apply(coeff.se[,grep("logSA",colnames(coeff.se)),with=FALSE],2,list)),
                          CO21=unlist(apply(coeff.se[,grep("^CO21$",colnames(coeff.se)),with=FALSE],2,list)),
                          ATA1=unlist(apply(coeff.se[,grep("^ATA1$",colnames(coeff.se)),with=FALSE],2,list)),
                          CMI1=unlist(apply(coeff.se[,grep("^CMI1$",colnames(coeff.se)),with=FALSE],2,list)),
                          lograre_nbsp=unlist(apply(coeff.se[,grep("^lograre_nbsp$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_CO2=unlist(apply(coeff.se[,grep("^SA_CO2$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_ATA=unlist(apply(coeff.se[,grep("^SA_ATA$",colnames(coeff.se)),with=FALSE],2,list)),
                          SA_CMI=unlist(apply(coeff.se[,grep("^SA_CMI$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_SA=unlist(apply(coeff.se[,grep("^Div_SA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_CO2=unlist(apply(coeff.se[,grep("^Div_CO2$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_ATA=unlist(apply(coeff.se[,grep("^Div_ATA$",colnames(coeff.se)),with=FALSE],2,list)),
                          Div_CMI=unlist(apply(coeff.se[,grep("^Div_CMI$",colnames(coeff.se)),with=FALSE],2,list)))

nbcT_1se<-data.table(Source=c("Int","logSI","logSA","CO21","ATA1","CMI1","lograre_nbsp",
                               "SA_CO2","SA_ATA","SA_CMI",
                               "Div_SA",
                               "Div_CO2","Div_ATA","Div_CMI"),
                      mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_1se$mean.nbc<-apply(coeff.se_tidy,2,mean)
nbcT_1se$up.nbc<-apply(coeff.se_tidy,2,function(x){quantile(x,0.975)})
nbcT_1se$low.nbc<-apply(coeff.se_tidy,2,function(x){quantile(x,0.025)})

## fitme MULTI ##
marare_nbspCAC_sc_summary<-summary(marare_nbspCAC_sc)$beta
nbcT_multi<-data.table(Source=c("Int","logSI","logSA","CO21","ATA1","CMI1","lograre_nbsp",
                                 "SA_CO2","SA_ATA","SA_CMI",
                                 "Div_SA",
                                 "Div_CO2","Div_ATA","Div_CMI"),
                        mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi$mean.nbc<-marare_nbspCAC_sc_summary[,1]
nbcT_multi$up.nbc<-marare_nbspCAC_sc_summary[,1]+marare_nbspCAC_sc_summary[,2]
nbcT_multi$low.nbc<-marare_nbspCAC_sc_summary[,1]-marare_nbspCAC_sc_summary[,2]

## fitme single CO2 ##
load("fitme_CO2_NBC_sc_HossfeldSI.R")
marare_nbspCO2_sc_summary<-summary(marare_nbspCO2_sc)$beta
nbcT_CO2<-data.table(Source=c("Int","logSI","logSA","CO21","lograre_nbsp","SA_CO2","Div_SA","Div_CO2"),
                      mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_CO2$mean.nbc<-marare_nbspCO2_sc_summary[,1]
nbcT_CO2$up.nbc<-marare_nbspCO2_sc_summary[,1]+marare_nbspCO2_sc_summary[,2]
nbcT_CO2$low.nbc<-marare_nbspCO2_sc_summary[,1]-marare_nbspCO2_sc_summary[,2]

## fitme single ATA ##
load("fitme_ATA_NBC_sc_HossfeldSI.R")
marare_nbspATA_sc_summary<-summary(marare_nbspATA_sc)$beta
nbcT_ATA<-data.table(Source=c("Int","logSI","logSA","ATA1","lograre_nbsp","SA_ATA","Div_SA","Div_ATA"),
                      mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_ATA$mean.nbc<-marare_nbspATA_sc_summary[,1]
nbcT_ATA$up.nbc<-marare_nbspATA_sc_summary[,1]+marare_nbspATA_sc_summary[,2]
nbcT_ATA$low.nbc<-marare_nbspATA_sc_summary[,1]-marare_nbspATA_sc_summary[,2]

## fitme single CMI ##
load("fitme_ACMIA_NBC_sc_HossfeldSI.R")
marare_nbspCMI_sc_summary<-summary(marare_nbspCMI_sc)$beta
nbcT_CMI<-data.table(Source=c("Int","logSI","logSA","CMI1","lograre_nbsp","SA_CMI","Div_SA","Div_CMI"),
                      mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_CMI$mean.nbc<-marare_nbspCMI_sc_summary[,1]
nbcT_CMI$up.nbc<-marare_nbspCMI_sc_summary[,1]+marare_nbspCMI_sc_summary[,2]
nbcT_CMI$low.nbc<-marare_nbspCMI_sc_summary[,1]-marare_nbspCMI_sc_summary[,2]

### Multi nonpara ###
nmarare_nbspCAC<-rfit(AGB_corr~logSI+logSA+CO21+ATA1+CMI1+lograre_nbsp+
                        SA_CO2+SA_ATA+SA_CMI+Div_SA+
                        Div_CO2+Div_ATA+Div_CMI,
                      weights=wi,data=glmnet.dat)
summary(nmarare_nbspCAC)$co

nbcT_multi_NP<-data.table(Source=c("Int","logSI","logSA","CO21","ATA1","CMI1","lograre_nbsp",
                                    "SA_CO2","SA_ATA","SA_CMI",
                                    "Div_SA",
                                    "Div_CO2","Div_ATA","Div_CMI"),
                           mean.nbc=NA,up.nbc=NA,low.nbc=NA)

nbcT_multi_NP$mean.nbc<-summary(nmarare_nbspCAC)$co[,1]
nbcT_multi_NP$up.nbc<-summary(nmarare_nbspCAC)$co[,1]+summary(nmarare_nbspCAC)$co[,2]
nbcT_multi_NP$low.nbc<-summary(nmarare_nbspCAC)$co[,1]-summary(nmarare_nbspCAC)$co[,2]

#Bind Multi, CO2, ATA, CMI
nbcT_multi$model<-"Linear mixed effects (modelled with three drivers simultaneously)"
nbcT_1se$model<-"Ridge regression (modelled with three drivers simultaneously)"
nbcT_multi_NP$model<-"Nonparametric (modelled with three drivers simultaneously)"
nbcT_CO2$model<-"Linear mixed effects (modelled with CO2)"
nbcT_ATA$model<-"Linear mixed effects (modelled with ATA)"
nbcT_CMI$model<-"Linear mixed effects (modelled with ACMIA)"

to_gg<-rbind(nbcT_multi,nbcT_1se,nbcT_multi_NP,nbcT_CO2,nbcT_ATA,nbcT_CMI)

to_gg[Source=="logSI",Source:="logSI"];to_gg[Source=="CO21",Source:="CO2"]
to_gg[Source=="ATA1",Source:="ATA"];to_gg[Source=="CMI1",Source:="ACMIA"];
to_gg[Source=="lograre_nbsp",Source:="logS"];to_gg[Source=="SA_CO2",Source:="logSA*CO2"]
to_gg[Source=="SA_ATA",Source:="logSA*ATA"];to_gg[Source=="SA_CMI",Source:="logSA*ACMIA"]
to_gg[Source=="Div_SA",Source:="logSA*logS"];to_gg[Source=="Div_CO2",Source:="CO2*logS"]
to_gg[Source=="Div_ATA",Source:="ATA*logS"];to_gg[Source=="Div_CMI",Source:="ACMIA*logS"]

to_gg$Source<-as.factor(to_gg$Source)
to_gg$Source<-factor(to_gg$Source,levels=c("logSI","logSA","CO2","ATA","ACMIA","logS",
                                           "logSA*CO2","logSA*ATA","logSA*ACMIA",
                                           "logSA*logS",
                                           "CO2*logS","ATA*logS","ACMIA*logS"))

to_gg$model<-factor(to_gg$model,levels=c("Linear mixed effects (modelled with three drivers simultaneously)",
                                         "Ridge regression (modelled with three drivers simultaneously)",
                                         "Nonparametric (modelled with three drivers simultaneously)",
                                         "Linear mixed effects (modelled with CO2)",
                                         "Linear mixed effects (modelled with ATA)",
                                         "Linear mixed effects (modelled with ACMIA)"))

NetBiomChange<-ggplot(to_gg[to_gg$Source!="Int"],aes(x=Source,y=mean.nbc,ymin=low.nbc,ymax=up.nbc,col=model))+
  geom_point(position=position_dodge(0.6))+
  geom_errorbar(position=position_dodge(0.6),width=0.3)+
  theme_classic()+
  geom_hline(aes(yintercept=0),linetype="dotted")+
  scale_color_discrete(name="Model")+
  theme(legend.position=c(0.7,0.8),
        axis.text.x=element_text(angle=30,vjust=0.5,size=10))+
  ylab("Coefficient estimate")+xlab("")+guides(col=FALSE)
NetBiomChange

## to save Fig.S2
############## Bind Gr, M, NBC ##############
p1<-ggplot_gtable(ggplot_build(Growth))
p2<-ggplot_gtable(ggplot_build(Mortality))
p3<-ggplot_gtable(ggplot_build(NetBiomChange))

maxWidth = unit.pmax(p1$widths[2:3], p2$widths[2:3], p3$widths[2:3])

p1$widths[2:3] <- maxWidth
p2$widths[2:3] <- maxWidth
p3$widths[2:3] <- maxWidth

maxheight = unit.pmax(p1$heights[2:3], p2$heights[2:3], p3$heights[2:3])

p1$heights[2:3] <- maxheight
p2$heights[2:3] <- maxheight
p3$heights[2:3] <- maxheight

tiff("FigS2_Bind_Climate_MULTI_EACH_Ridge_regression_fitme_Hossfeld.tiff",width=2200,height=4000,res=300,compression="lzw")
grid.draw(rbind(p1,p2,p3,size="last"))
grid.text("Growth",x=unit(0.12,"npc"),y=unit(0.99,"npc"),gp=gpar(fontsize=14),just="left")
grid.text("Mortality",x=unit(0.12,"npc"),y=unit(0.66,"npc"),gp=gpar(fontsize=14),just="left")
grid.text("Net biomass change",x=unit(0.12,"npc"),y=unit(0.32,"npc"),gp=gpar(fontsize=14),just="left")

dev.off()

